import QtQuick 2.4
import "." // QTBUG-34418, singletons require explicit import to load qmldir file

MouseArea {
    id: idButton

    property string dstLink: ""                     // Destination link when Clicked
    property var dstExtra                           // Extra data passed to next page

    property string helpTitle: qsTr("Help") + config.autoTr                   // Text to display as help title
    property string helpText: qsTr("No quick help available") + config.autoTr // Text to display as help message

    property alias srcImage: idImage.source         // Source image to display on button
    property alias rectVisible: idRectangleOut.visible // Is outer rectangle visible

    property alias backColor: idRectangleOut.color  // Background color
    property alias radius: idRectangleOut.radius    // Radius
    property alias border: idRectangleOut.border    // Border

    property alias text: idText.text                // Text content
    property alias label: idText                    // Text element
    property int textMargin: 20                     // Margin around text
    property alias textColor: idText.color          // Text color
    property alias font: idText.font                // Text font
    property alias style: idText.style              // Text style

    property var btnMsg: null
    property bool startRelated: false

    implicitWidth: (srcImage != "") ? Math.max(idImage.width, 60) : idTextMetrics.width + 2 * textMargin
    implicitHeight: (srcImage != "") ? Math.max(idImage.height, 50) : 40

    Rectangle {
        id: idRectangleOut

        anchors.fill: parent

        color: idButton.enabled ? (idButton.pressed ? UiConfig.colors.bg_pressed : UiConfig.colors.bg_active) : UiConfig.colors.bg_inactive
        radius: 10
        border.width: 1
        border.color: UiConfig.colors.border

        TextMetrics {
            id: idTextMetrics
            text: idText.text
        }

        Text {
            id: idText

            anchors.fill: parent
            anchors.margins: 5
            fontSizeMode: Text.Fit
            elide: Text.ElideRight

            color: idButton.enabled ? (idButton.pressed ? UiConfig.colors.fg_pressed : UiConfig.colors.fg_active) : UiConfig.colors.fg_inactive
            text: ""
            visible: (idImage.source == "")
            style: Text.Normal
            font.pixelSize: 20
            verticalAlignment: Text.AlignVCenter
            horizontalAlignment: Text.AlignHCenter
            wrapMode: Text.WordWrap

            Behavior on color { ColorAnimation {} }
        }

        Behavior on color { ColorAnimation {} }
    }

    Image {
        id: idImage

        anchors.centerIn: parent

        source: ""
        fillMode: Image.PreserveAspectFit
        visible: (source != "")
    }

    onClicked: {
        UiConfig.sound.play_click();
        if (idButton.dstLink !== "") {
            change_page (idButton.dstLink, idButton.dstExtra);
        }
    }

    onPressAndHold: {
        if (helpText != "") {
            UiConfig.sound.play_click();
            disableButtons();
            idButton.btnMsg= popup().msg(helpTitle, helpText, [qsTr("Ok")], function(nr) {
                if (nr === 0) {
                    return true;
                }
            });
        }
    }
    Connections {
        target: btnMsg
        onClose: {
            if (popupmgr.get(2)) {
                btnMsg = popupmgr.get(1);
                return;
            }
            else {
                //Dans le cas d'une double popup la condition popup.isOpened pose problème, on la contourne ici sachant qu'elle n'est qu'une sécurité
                hal.setStartLight(!remoteaccess.interfaceIsConnected && hal.safetyLoop /*&& !popup().isOpened()*/ && startRelated);
                hal.setStopLight(false);
            }
        }
    }

    function disableButtons(){
        hal.setStartLight(false);
        hal.setStopLight(false);
    }
}
