import QtQuick 2.2
import "." // QTBUG-34418, singletons require explicit import to load qmldir file

Item {
    id: idList

    property alias model: idListView.model

    property int maxElementToDisplay: 6
    property int elementHeight: 40

    property alias currentElement: idListView.currentIndex

    property alias backcolor: idRectangleOut.color
    property alias radius: idRectangleOut.radius
    property alias border: idRectangleOut.border

    property alias highlight: idListView.highlight

    property color textcolor: UiConfig.colors.fg_active

    property bool validated: false

    width: 300
    height: idRectangleOut.height

    ListModel {
        id: idDefaultModel
    }

    Rectangle {
        id: idRectangleOut

        color: UiConfig.colors.bg_active
        radius: 10
        border.color: UiConfig.colors.border
        border.width: 2
        width: parent.width
        height: (idList.maxElementToDisplay * idList.elementHeight) + 8

        VScrollBar {
            id: vscoll
            anchors {
                top: parent.top
                left: parent.left
                leftMargin: 8
                bottom: parent.bottom
                margins: 6
            }
            scrollArea: idListView
        }

        ListView {
            id: idListView

            anchors.right: parent.right
            anchors.bottom: parent.bottom
            anchors.left: vscoll.right
            anchors.top: parent.top
            anchors.rightMargin: 4
            anchors.leftMargin: 4
            anchors.bottomMargin: 4
            anchors.topMargin: 4

            snapMode: ListView.SnapToItem
            boundsBehavior: Flickable.StopAtBounds
            clip: true
            currentIndex: 0
            model: idDefaultModel
            highlightMoveDuration: 0

            delegate: Item {
                x: 5
                width: parent.width
                height: idList.elementHeight

                Text {
                    id: idText

                    anchors.fill: parent

                    color: idList.textcolor
                    text: modelData
                    font.pixelSize: 24
                    verticalAlignment: Text.AlignVCenter
                    horizontalAlignment: Text.AlignHCenter

                    MouseArea {
                        anchors.fill: parent

                        onClicked: {
                            idListView.currentIndex = index
                            UiConfig.sound.play_click()
                            idList.validated |= true
                        }
                    }
                }
            }

            highlight: Rectangle {
                radius:10
                border.color: "#ffffff"
                border.width: 2
                color: "transparent"
            }
        }
    }
}
