import QtQuick 2.0
import "../HorusComponents"

Item {
    id: component

    property string u: ""
    property string ir: ""
    property string it: ""
    property string uunit: ""
    property string irunit: ""
    property string itunit: ""
    property string umax: ""
    property string irmax: ""
    property string itmax: ""
    property string udisj: ""
    property string irdisj: ""
    property string itdisj: ""
    property int ulength: 3
    property int irlength: 3
    property int itlength: 3
    property bool uenabled: true
    property bool irenabled: true
    property bool itenabled: true
    property string filter: ""
    property string errorText: ""
    property string chargeText: ""
//    property string disabledLabel: ""
    property bool currentLimitation: false


    property var _first

//    property var _txtSizeFirst

    /*
        Version modifiée par LN le 04/05/2017
        Modification:  * Ajout des paramètres de TextLength afin de figer la taille des caractères des mesures
                       * Modification de la fonction _resize_text et ajout de _resize_botMargin afin de centrer au mieux le texte après redimensionnement
    */

    property bool _firstOpen : true

    onUChanged: uIrItModel.set(0, {measureText: u});
    onIrChanged: uIrItModel.set(2, {measureText: ir});
    onItChanged: uIrItModel.set(1, {measureText: it});

    onUunitChanged: uIrItModel.set(0, {measureUnit: uunit});
    onIrunitChanged: uIrItModel.set(2, {measureUnit: irunit});
    onItunitChanged: uIrItModel.set(1, {measureUnit: itunit});

    //DavidTest
    onUmaxChanged: uIrItModel.set(0, {maxText: umax});
//    onUmaxChanged: uIrItModel.set(0, {maxText: errorText});
    onIrmaxChanged: uIrItModel.set(2, {maxText: irmax});
    onItmaxChanged: uIrItModel.set(1, {maxText: itmax});

    onUdisjChanged: uIrItModel.set(0, {disjText: udisj});
    onIrdisjChanged: uIrItModel.set(2, {disjText: irdisj});
    onItdisjChanged: uIrItModel.set(1, {disjText: itdisj});

    onUlengthChanged: uIrItModel.set(0, {textLength: ulength});
    onIrlengthChanged: uIrItModel.set(2, {textLength: irlength});
    onItlengthChanged: uIrItModel.set(1, {textLength: itlength});

    onUenabledChanged: uIrItModel.set(0, {enablevis: uenabled});
    onIrenabledChanged: uIrItModel.set(2, {enablevis: irenabled});
    onItenabledChanged: uIrItModel.set(1, {enablevis: itenabled});

//    onChargeTextChanged: {
//        console.log("Caroussel onChargeTextChanged :  chargeText = ", chargeText);
//        console.log("Caroussel onChargeTextChanged : (errorText && (index === 0)) || maxText || chargeText ? ", (errorText && (index === 0)) || maxText || chargeText);
//        console.log("Caroussel onChargeTextChanged :  errorText != 0 ? ", chargeText !== "", " maxText != 0 ? ",maxText !== "", " et errorText != 0 ? ", errorText !== "");

//    }


    /** Function to resize the font.pixelSize of the first measure of the caroussel **/
    function _resize_text (txtLength) {

            if (txtLength >= 7) {
                return 53;
                }

            else if (txtLength >= 6) {
                return 55;
                }

            else if (txtLength >= 5) {
                return 60;
                }

            else if (txtLength >= 4) {
                return 70;
                }

            else return 80;
    }

    /** Function to resize the bottomMargin of the first measure of the caroussel **/
    function _resize_botMargin (txtLength) {

            if (txtLength >= 7) {
                return 20;
                }

            else if (txtLength >= 6) {
                return 20;
                }

            else if (txtLength >= 5) {
                return 20;
                }

            else if (txtLength >= 4) {
                return 10;
                }

            else return 10;
    }

    ListModel {
        id: uIrItModel
        ListElement { measureText: ""; measureUnit: ""; maxText: ""; disjText: ""; textLength: 3; label: qsTr("Voltage"); enablevis: true }
        ListElement { measureText: ""; measureUnit: ""; maxText: ""; disjText: ""; textLength: 3; label: qsTr("I total"); enablevis: true  }
        ListElement { measureText: ""; measureUnit: ""; maxText: ""; disjText: ""; textLength: 3; label: qsTr("I real"); enablevis: true  }

    }

    Component {
        id: dragDelegate

        MouseArea {
            id: dragArea

            property bool held: false
            property bool moving: false
            property int boxNumber: index

            anchors { left: parent.left; right: parent.right }
            height: content.height

            y: ((boxNumber == 0 ? 0 : 0.1) + (boxNumber * 0.3)) * component.height

            drag {
                target: held ? content : undefined
                axis: Drag.YAxis
                minimumY: 0
                maximumY: component.height - content.height
            }

            onPressed: held = true
            onReleased: held = false
            onClicked: {
                if (_first) {
                    var swap = _first.boxNumber;
                    _first.boxNumber = dragArea.boxNumber;
                    dragArea.boxNumber = swap;
                    _first = dragArea;
                }
            }

            Item {
                id: content

                anchors {
                    horizontalCenter: parent.horizontalCenter
                    verticalCenter: parent.verticalCenter
                }

                width: dragArea.width;
                height: (boxNumber == 0 ? 0.4 : 0.3) * component.height

                opacity: dragArea.held ? 0.5 : 1

                Drag.active: dragArea.held
                Drag.source: dragArea
                Drag.hotSpot.x: width / 2
                Drag.hotSpot.y: height / 2
                Drag.keys: ["horus/caroussel"]

                states: State {
                    when: dragArea.held
                    ParentChange {
                        target: content;
                        parent: component
                    }
                    AnchorChanges {
                        target: content
                        anchors { horizontalCenter: undefined; verticalCenter: undefined }
                    }
                }

                Image {
                    anchors {
                        top: parent.top
                        right: parent.right
                    }
                    source: "MeasureCaroussel_label.png"
                    visible: enablevis

                    Text {
                        anchors {
                            left: parent.left
                            leftMargin: 25
                            right: parent.right
                            rightMargin: 15
                        }
                        text: enablevis ? label : ""
                        fontSizeMode: Text.Fit
                        font.pixelSize: 20
                        horizontalAlignment: Text.AlignHCenter
                        verticalAlignment: Text.AlignVCenter
                        color: "#272737"
                    }
                }


                    Text {
                        id: measure

                        anchors.fill: parent
                        anchors.bottomMargin:  boxNumber == 0 ? _resize_botMargin(length) : 20
                        anchors.margins: 10
                        anchors.rightMargin: unitbox.width + 10

                        text: disjText ? disjText : measureText

                        property var length : text.length > textLength ? text.length : textLength

                        font.pixelSize: boxNumber == 0 ? _resize_text(length) : 30
//                        font.pixelSize: boxNumber == 0 ? 50 : 30
                        horizontalAlignment: Text.AlignRight

                        //Modification importante car Text.AlignBottom seul provoque un bug d'affichage à l'ouverture du carrousel : parent.baseline de unitbox est erronné et pointe au dessus de measure.
                        verticalAlignment: _firstOpen ? Text.AlignTop : Text.AlignBottom

                        color: "#ffffff"

                        Behavior on font.pixelSize {
                            SmoothedAnimation  { duration: 1500; velocity: 200 }
                        }


                            Text {
                                id:unitbox
                                anchors.left: parent.right
                                anchors.leftMargin: 5
                                anchors.baseline: parent.baseline

                                height: parent.height

                                text: enablevis ? measureUnit : ""
                                font.pixelSize: boxNumber == 0 ? 35 : 20

                                color: "#fff"
                                }
                    }

                Text {
                    id: max
                    anchors {
                        left: parent.left
                        bottom: parent.bottom
                        leftMargin: 10
                        bottomMargin: 2
                    }
                    text: {
//                        console.log("measureCaroussel : chgargeText = ", chargeText);
//                        console.log("measureCaroussel : maxText  = ", maxText);
//                        console.log("measureCaroussel : errorText = ", errorText);

//                        console.log("measureCaroussel : errorText != 0 ? ", chargeText !== "", " maxText != 0 ? ",maxText !== "", " et errorText != 0 ? ", errorText !== "");

//                        console.log("measureCaroussel: visible ? ", ((errorText && (index === 0)) || maxText || chargeText));

                        if (chargeText !== "") {
//                            console.log("measureCaroussel : chgargeText = ", chargeText);

                            return '<font color="' + UiConfig.colors.fg_active  + '">' + chargeText + '</font>';
                        }
                        //DavidTest
                        else if (maxText !== ""){
                            return '<font color="' + UiConfig.colors.fg_active  + '">max: </font> ' + maxText;
                        }

                        else if(errorText !== "") {
                            return '<font color="' + UiConfig.colors.fg_active  + '">' + errorText + '</font>';

                        }

                        else return "";
                    }

                    color: "#fff"
                    font.pixelSize: 18
                    visible: ((errorText && (index === 0)) || maxText || (chargeText && (index === 0))) && enablevis
                }

                Rectangle {
                    anchors {
                        right: parent.right
                        bottom: parent.bottom
                        rightMargin: 8
                        bottomMargin: (boxNumber == 0 ? 4 : 5)
                    }
                    width: (boxNumber == 0 ? 55 : 45)
                    height: 15
                    color: "#fff"
                    visible: component.currentLimitation && (index != 0) && enablevis
                    Text {
                        anchors.centerIn: parent
                        text: "< 3mA"
                        color: "#2a2939"
                        font.pixelSize: (boxNumber == 0 ? 15 : 12)
                    }
                }
            }

            DropArea {
                anchors.verticalCenter: parent.verticalCenter
                keys: ["horus/caroussel"]
                width: parent.width
                height: parent.height
                onPositionChanged: {
                    if (!moving) {
                        var swap = drag.source.boxNumber;
                        drag.source.boxNumber = dragArea.boxNumber;
                        dragArea.boxNumber = swap;
                        if (dragArea.boxNumber == 0)
                            _first = dragArea;
                        if (drag.source.boxNumber == 0)
                            _first = drag.source;
                    }
                }
            }

            Behavior on y {
                enabled: !held && component.height > 0
                SequentialAnimation {
                    PropertyAction { target: dragArea; property: "moving"; value: "true" }
                    SmoothedAnimation { duration: 200; velocity: 200; }
                    PropertyAction { target: dragArea; property: "moving"; value: "false" }
                }
            }

            Component.onCompleted: if (index == 0) _first = this
        }
    }

    Repeater {
        anchors.fill: parent
        model: uIrItModel
        delegate: dragDelegate

        Component.onCompleted: {_firstOpen = false;}
    }

    Image {
        id: imgFilter
        anchors {
            left: parent.left
            top: parent.top
            topMargin: 8
        }
        source: filter
        width: 40
        height: 40
    }
    Component.onCompleted: {
//        console.log("MeasureCaroussel created: currentLimitation = ", currentLimitation, " itenabled = ", itenabled, " et irenabled = ", irenabled);
    }
}
