import QtQuick 2.0
import "../HorusComponents"

Item {
    id: component

    property string u: ""
    property string r: ""
    property string i: ""
    property string uunit: ""
    property string runit: ""
    property string iunit: ""
    property string ulast: ""
    property string rlast: ""
    property string ilast: ""
    property int ulength: 3
    property int rlength: 3
    property int ilength: 3
    property var order:[]
    property string filter: ""
    property bool currentLimitation: false

    property var _first

//    property int _txtSizeFirst: 50

    property bool _firstOpen : true

    onRChanged: uIrItModel.set(0, {measureText: r});
    onUChanged: uIrItModel.set(1, {measureText: u});
    onIChanged: uIrItModel.set(2, {measureText: i});

    onRunitChanged: uIrItModel.set(0, {measureUnit: runit});
    onUunitChanged: uIrItModel.set(1, {measureUnit: uunit});
    onIunitChanged: uIrItModel.set(2, {measureUnit: iunit});

    onRlastChanged: uIrItModel.set(0, {lastText: rlast});
    onUlastChanged: uIrItModel.set(1, {lastText: ulast});
    onIlastChanged: uIrItModel.set(2, {lastText: ilast});

    /*
        Version modifiée par LN le 04/05/2017
        Modification:  * Ajout des paramètres de TextLength afin de figer la taille des caractères des mesures
                       * Modification de la fonction _resize_text et ajout de _resize_botMargin afin de centrer au mieux le texte après redimensionnement
    */

    onRlengthChanged: uIrItModel.set(0, {textLength: rlength});
    onUlengthChanged: uIrItModel.set(1, {textLength: ulength});
    onIlengthChanged: uIrItModel.set(2, {textLength: ilength});

    /** Function to resize the font.pixelSize of the first measure of the caroussel **/
    function _resize_text (txtLength) {
//        //console.log("Caroussel: _resize_text: textLength = ", txtLength);

//            if (txtLength >= 7) {
//                return 53;
//                }

//            else if (txtLength >= 6) {
//                return 55;
//                }

//            else if (txtLength >= 5) {
//                return 60;
//                }

//            else if (txtLength >= 4) {
//                return 70;
//                }

//        console.log("resizeText : text length = ",txtLength);
        if (txtLength >= 6) {
            return 60;
        }

        else return 70
    }

    /** Function to resize the bottomMargin of the first measure of the caroussel **/
    function _resize_botMargin (txtLength) {

            if (txtLength >= 7) {
                return 20;
                }

            else if (txtLength >= 6) {
                return 20;
                }

            else if (txtLength >= 5) {
                return 20;
                }

            else if (txtLength >= 4) {
                return 20;
                }

            else if (txtLength >= 3) {
                return 10;
                }

            else return 10;
    }

    ListModel {
        id: uIrItModel
        ListElement { measureText: ""; measureUnit: ""; lastText: ""; textLength: 3; label: qsTr("Resistance")  }
        ListElement { measureText: ""; measureUnit: ""; lastText: ""; textLength: 3; label: qsTr("Voltage") }
        ListElement { measureText: ""; measureUnit: ""; lastText: ""; textLength: 3; label: qsTr("Current")  }
    }

    Component {
        id: dragDelegate

        MouseArea {
            id: dragArea

            property bool held: false
            property bool moving: false
            property int boxNumber: order[index] ? order[index] - 1 : index

            anchors { left: parent.left; right: parent.right }
            height: content.height

            y: ((boxNumber == 0 ? 0 : 0.1) + (boxNumber * 0.3)) * component.height

            drag {
                target: held ? content : undefined
                axis: Drag.YAxis
                minimumY: 0
                maximumY: component.height - content.height
            }

            onPressed: held = true
            onReleased: held = false
            onClicked: {
                if (_first) {
                    var swap = _first.boxNumber;
                    _first.boxNumber = dragArea.boxNumber;
                    dragArea.boxNumber = swap;
                    _first = dragArea;
                }
            }

            Item {
                id: content

                anchors {
                    horizontalCenter: parent.horizontalCenter
                    verticalCenter: parent.verticalCenter
                }

                width: dragArea.width;
                height: (boxNumber == 0 ? 0.4 : 0.3) * component.height

                opacity: dragArea.held ? 0.5 : 1

                Drag.active: dragArea.held
                Drag.source: dragArea
                Drag.hotSpot.x: width / 2
                Drag.hotSpot.y: height / 2
                Drag.keys: ["horus/caroussel"]

                states: State {
                    when: dragArea.held
                    ParentChange {
                        target: content;
                        parent: component
                    }
                    AnchorChanges {
                        target: content
                        anchors { horizontalCenter: undefined; verticalCenter: undefined }
                    }
                }

                Image {
                    id:meas_label
                    anchors {
                        top: parent.top
                        right: parent.right
                    }
                    source: "MeasureCaroussel_label.png"

                    Text {
                        anchors {
                            left: parent.left
                            leftMargin: 25
                            right: parent.right
                            rightMargin: 15
                        }
                        text: label
                        fontSizeMode: Text.Fit
                        font.pixelSize: 20
                        horizontalAlignment: Text.AlignHCenter
                        verticalAlignment: Text.AlignVCenter
                        color: "#272737"
                    }
                }


                Text {
                    id: measure

                    anchors.fill: parent
                    anchors.bottomMargin: boxNumber == 0 ? _resize_botMargin(length) : 20
                    anchors.margins: 10
                    anchors.rightMargin: unitbox.width + 10

                    text: measureText

                    property var length : text.length > textLength ? text.length : textLength

                    font.pixelSize: boxNumber == 0 ? _resize_text(length) : 40

//                    font.pixelSize: boxNumber == 0 ? 50 : 30
                    horizontalAlignment: Text.AlignRight

                    //Modification importante car Text.AlignBottom seul provoque un bug d'affichage à l'ouverture du carrousel : parent.baseline de unitbox est erronné et pointe au dessus de measure.
                    verticalAlignment: _firstOpen ? Text.AlignTop : Text.AlignBottom

                    color: "#ffffff"

                    Behavior on font.pixelSize {
                        SmoothedAnimation  { duration: 1500; velocity: 200 }
                    }


                        Text {
                            id:unitbox
                            anchors.left: parent.right
                            anchors.leftMargin: 5
                            anchors.baseline: parent.baseline

                            height: parent.height

                            text: measureUnit
                            font.pixelSize: text.length > 4 ? 18 : (boxNumber == 0 ? 35 : 20)

                            color: "#fff"
                            }
                }

                Text {
                    anchors {
                        left: parent.left
                        bottom: parent.bottom
                        leftMargin: 10
                        bottomMargin: 2
                    }
                    text: '<font color="' + config.resultErrorColor  + '">' + lastText +' </font> '
//                    text: '<font color="' + UiConfig.colors.fg_active  + '">max: </font> ' + lastText
//                    shadow: config.resultErrorColor
                    color: "#fff"
                    font.pixelSize: 18
                    visible: true
                }
                Rectangle {
                    anchors {
                        right: parent.right
                        bottom: parent.bottom
                        rightMargin: 8
                        bottomMargin: (boxNumber == 0 ? 4 : 5)
                    }
                    width: (boxNumber == 0 ? 55 : 45)
                    height: 15
                    color: "#fff"
                    visible: component.currentLimitation && label === qsTr("Current")
                    Text {
                        anchors.centerIn: parent
                        text: "< 3mA"
                        color: "#2a2939"
                        font.pixelSize: (boxNumber == 0 ? 15 : 12)
                    }
                }
            }

            DropArea {
                anchors.verticalCenter: parent.verticalCenter
                keys: ["horus/caroussel"]
                width: parent.width
                height: parent.height
                onPositionChanged: {
                    if (!moving) {
                        var swap = drag.source.boxNumber;
                        drag.source.boxNumber = dragArea.boxNumber;
                        dragArea.boxNumber = swap;
                        if (dragArea.boxNumber == 0) {
                            _first = dragArea;
                        }
                        if (drag.source.boxNumber == 0) {
                            _first = drag.source;
                        }
                    }
                }
            }

            Behavior on y {
                enabled: !held && component.height > 0
                SequentialAnimation {
                    PropertyAction { target: dragArea; property: "moving"; value: "true" }
                    SmoothedAnimation { duration: 200; velocity: 200; }
                    PropertyAction { target: dragArea; property: "moving"; value: "false" }
                }
            }

            Component.onCompleted: if (order[index] ? order[index] - 1 === 0 : index === 0) _first = this;
        }
    }

    Repeater {
        anchors.fill: parent
        model: uIrItModel
        delegate: dragDelegate

        Component.onCompleted: _firstOpen = false;
    }

    Image {
        id: imgFilter
        anchors {
            left: parent.left
            top: parent.top
            topMargin: 8
        }
        source: filter
        width: 40
        height: 40
    }
}
