import QtQuick 2.0
import "." // QTBUG-34418, singletons require explicit import to load qmldir file

Rectangle {
    id: page
    default property alias data: content.data

    property string title: ""                // Title
    property bool navigationBtnVisible: true // Display navigation buttons
    property bool navigationBtnEnable: true  // Enable navigation buttons
    property bool saveImgVisible:true        // Display result saving image
    property bool remoteActive: remoteaccess.interfaceIsConnected // Mode remote
    property bool remoteLocked: remoteaccess.screenIsLocked // Mode remote
    property alias customHeaderComponent: customHeaderContent.sourceComponent
    property alias headerButton: headerButton
    property var extra
    property var msg: null
    property bool authenticationEnabled: true
    property int pwdAttempts: 1

    property int titleMargin: {
        // On créé cette variable afin de limiter la taille du titre en fonction des éléments affichés dans le header
        var margin = 0;
        if (saveImg.visible) margin = saveImg.width;
        if (headerButton.visible) margin += 60;
        return margin;
    }

    signal change_page(string page, var extra)
    signal back_page()
    signal home_page()

    width: 800
    height: 480

    gradient: Gradient {
        GradientStop { position: 0.0; color: "#4a4962" }
        GradientStop { position: 0.63; color: "#1d1f33" }
        GradientStop { position: 1.0; color: "#080b1d" }
    }

    Rectangle {
        id: header

        anchors {
            top: parent.top
            left: parent.left
            right: parent.right
        }

        height: 62

        color: "#e4e3eb"

        Rectangle {
            id: hour
            anchors {
                top: parent.top
                right: parent.right
                bottom: parent.bottom
            }
            width: 90
            color: "#d1d1da"
            visible: navigationBtnVisible

            Text {
                anchors.centerIn: parent
                text: "00:45"
                color: "#6b6d7e"
                font.pixelSize: 20

                Timer {
                    interval: 1000
                    running: true
                    repeat: true
                    triggeredOnStart: true

                    onTriggered: {
                        parent.text = Qt.formatTime(new Date(), "hh:mm")
                    }
                }
            }
        }

        Row {
            id: rowleft
            anchors.left: parent.left
            anchors.leftMargin: 10
            anchors.verticalCenter: parent.verticalCenter

            spacing: 10

            Rectangle {
                anchors.verticalCenter: parent.verticalCenter

                color: (navigationBtnEnable || remoteActive) && !remoteLocked ? (backMouseArea.pressed ? "#69b5e1" : "#007bc1") : "#6b6d7e"
                width: 48
                height: 48
                visible: navigationBtnVisible || remoteActive

                Behavior on color { ColorAnimation { } }

                Image {
                    source: remoteActive ? "Page_remote.png" : "Page_back.png"
                }

                MouseArea {
                    id: backMouseArea
                    anchors.fill: parent
                    enabled: (navigationBtnEnable || remoteActive) && !remoteLocked
                    onClicked: {
                        UiConfig.sound.play_click();
                        remoteActive ? remoteaccess.disconnectInterface() : back_page();
                    }
                }
            }
            Text {
                id: headertitle
                anchors.verticalCenter: parent.verticalCenter
                anchors.verticalCenterOffset: -2
                //On impose une width max pour le titre afin qu'il n'écrase pas les autres éléments du header de la page
                width: Math.min(570 - titleMargin, implicitWidth)
                verticalAlignment: Text.AlignVCenter
                horizontalAlignment: Text.AlignLeft
                //Si le texte dépasse la largeur fixée on le tronque
                elide: Text.ElideRight

                text: title
                color: "#6b6d7e"
                //Afin de tronquer le moins possible les titres on réduit dans un premier temps la font si le texte est long
                font.pixelSize: title.length > 21 ? 43 : 48
            }
        }

        Item {
            anchors {
                verticalCenter: parent.verticalCenter
                left: rowleft.right
                right: rowright.left
                margins: 10
            }
            Button {
                id: headerButton
                width: Math.min(parent.width, implicitWidth)
                text: ""
                anchors.centerIn: parent
                visible: navigationBtnVisible && text != ""
                enabled: navigationBtnEnable && !remoteActive
            }
        }

        Row {
            id: rowright
            anchors.verticalCenter: parent.verticalCenter
            anchors.right: hour.left
            anchors.rightMargin: 10

            spacing: 10

            Image {
                id: saveImg
                anchors.verticalCenter: parent.verticalCenter
                source: "Page_save.png"
                visible: config.resultsStore && navigationBtnVisible && saveImgVisible
            }

            Rectangle {
                id:homeBtn
                anchors.verticalCenter: parent.verticalCenter

                color: navigationBtnEnable ? (homeMouseArea.pressed ? "#69b5e1" : "#007bc1")  : "#6b6d7e"
                width: 48
                height: 48
                visible: navigationBtnVisible && !remoteActive

                Behavior on color { ColorAnimation { } }

                Image {
                    source: "Page_home.png"
                }
                MouseArea {
                    id: homeMouseArea
                    anchors.fill: parent
                    enabled: navigationBtnEnable || remoteActive
                    onClicked: {
                        UiConfig.sound.play_click();
                        home_page();
                    }
                }
            }
        }

        Loader {
            anchors.fill: parent
            id: customHeaderContent
        }
    }

    Item {
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.top: header.bottom
        anchors.bottom: parent.bottom
        anchors.topMargin: 10

        Item {
            id: content
            anchors.fill: parent
            anchors.margins: 10
        }
    }

    Timer {
        id: pwdTimer
        interval: 10000
        running: false
        repeat: false
        triggeredOnStart: false

        onTriggered: {
            console.log("C'est bon on peut réessayer");
            authenticationEnabled = true;
        }
    }

    Connections {
        target: remoteaccess
        onConnectedChanged: {
            //console.log("onConnectedChanged");
            if (remoteaccess.interfaceIsConnected){
                //console.log("onConnectedChanged: home_page()");
                home_page();
            }
        }
        onErrorDialog: {
            if (page.visible) {
                //console.log("error on cmd: ", remoteaccess.errorDiagCmd);
                disableButtons();
                page.msg = popup().msg(qsTr("Error %1").arg(remoteaccess.errorDiagType), qsTr("Error Dialog occured on command:\n%1").arg(remoteaccess.errorDiagCmd), [qsTr("Ok")], function(nr) {if (nr ===0) return true;}, popupmgr.get(1) ? true : false);
            }
        }

        onConnectionError: {
            var i = 0;
//            console.log("page.visible = ", page.visible);

            if (page.visible) {
//                console.log("error on cmd: ", remoteaccess.errorDiagCmd);
                disableButtons();
//                console.log("Page.qml: onConnectionError: authenticationEnabled = ",authenticationEnabled);
                    page.msg = popup().msg(qsTr("New connection"), qsTr("New Ip address tries to connect.\n%1\nAuthorize the connection and register the adress in white list?").arg(remoteaccess.newIpAddress()),  [qsTr("Yes"), qsTr("No")], function(nr) {
                        if (nr === 0){

                            //i est le nombre de tentative à partir du moment ou la première demande de pwd a été formulé
                            // i = 0 si authenticationEnabled est faux

                            //pwdAttempts est le nombre de fois que le nombre de tentatives autorisées a été dépassé (+1 car commence à 1)

                            if(!authenticationEnabled) {
//                                console.log("!authenticationEnabled car timer en route donc pop-up");
                                popup().msg(qsTr("Too many attempts"), qsTr("Please wait %1s before trying another attempt").arg(pwdTimer.interval/1000), [qsTr("Ok")], function(nr) {
                                    if (nr === 0) {
                                        remoteaccess.registerIp(false);
                                        return true;
                                    }
                                }, true);
                                return true;
                            }

                            console.log("config.adminPwdEmpty ? ",config.adminPwdEmpty);
                            if(config.adminPwdEmpty()) {
                                pwdAttempts = 1;
                                authenticationEnabled = true;
                                remoteaccess.registerIp(true);
                                return true;
                            }

                            else {
                                popup().msg(qsTr("Administrator password"), qsTr("Please enter administrator password to proceed"), [qsTr("Ok")], function(nr) {
                                    popup().editText(qsTr("Please enter admin password"), "", function(pass) {
                                    if (pass === undefined) {
//                                        console.log("pass === undefined donc on a appuyé à côté");
                                        remoteaccess.registerIp(false);
                                        return true;
                                    }

                                    else if (config.checkPassword(1, pass)) {
//                                        console.log("password BON !!");
                                        pwdAttempts = 1;
                                        authenticationEnabled = true;
                                        remoteaccess.registerIp(true);
                                        return true;
                                    }

                                    if((i>1) || (pwdAttempts > 1 && i===0)) {
//                                        console.log("password PAS BON et TOO MANY ATTEMPTS !!");

                                        var timerVal = pwdTimer.interval * pwdAttempts;
                                        pwdTimer.interval = timerVal;
                                        pwdTimer.start();
                                        pwdAttempts++;
                                        authenticationEnabled = false;
                                        popup().msg(qsTr("Too many attempts"), qsTr("Please wait %1s before trying another attempt").arg(timerVal/1000), [qsTr("Ok")], function(nr) {
                                            if (nr === 0) {
                                                return true;
                                            }
                                        }, true);
                                    }

                                    if (!config.checkPassword(1, pass)){
//                                        console.log("password PAS BON !!");

                                        popup().msg(qsTr("Wrong password"), qsTr("The password is invalid"), [qsTr("Ok")], function(nr) {
                                            if (nr === 0) {
                                                remoteaccess.registerIp(false);
                                                return true;
                                            }
                                            });
                                        }

//                                    console.log("i ++");
                                        i++;
                                        return false ;
                                     }, true);

                                return true;

                                }, true);
                            }



                        }
                        else if (nr === 1 ) {
//                            console.log("remoteaccess.registerIp(false); ");
                            remoteaccess.registerIp(false);
                            return true;
                        }
                            }
                    ,popupmgr.get(1) ? true : false);
            }
        }

        onRegisterIpSucceded: {
            console.log("onRegisterIpSucceded");
            if (page.visible) {
                console.log("onRegisterIpSucceded");
                disableButtons();
                page.msg = popup().msg(qsTr("Ip registered"), qsTr("Ip address successfully registered"), [qsTr("Ok")], function(nr) {if (nr ===0) return true;}, popupmgr.get(1) ? true : false);
            }
        }
        onRegisterIpFailed: {
            if (page.visible) {
                console.log("onRegisterIpFailed");
                disableButtons();
                page.msg = popup().msg(qsTr("Error"), qsTr("Ip address registration failed"), [qsTr("Ok")], function(nr) {if (nr ===0) return true;}, popupmgr.get(1) ? true : false);            }
        }
        onEsrCleared: {
            if (page.msg) {
                page.msg.close();
            }
        }
    }

    function disableButtons(){
        hal.setStartLight(false);
        hal.setStopLight(false);
    }
}
