import QtQuick 2.0
import "." // QTBUG-34418, singletons require explicit import to load qmldir file

import "../HorusComponents"

Item {
    id:idSliderColor

    property alias border: idSliderMainRectangle.border
    property alias radius: idSliderMainRectangle.radius

    property alias cursorBorder: idCurrentColor.border
    property alias cursorRadius: idCurrentColor.radius

    property real value: privates.colorHue(color)
    property real colorHSV_Saturation: 0.8
    property real colorHSV_Value: 0.5
    property color color: Qt.hsla(value, colorHSV_Saturation, colorHSV_Value, 1)

    Item {
        id: privates
        function colorHue(color) {
            var cmax = Math.max(color.r, color.g, color.b);
            var cmin = Math.min(color.r, color.g, color.b);
            var delta = cmax - cmin;
            if (delta == 0)
                return 0;
            if (color.r == cmax)
                return (((color.g - color.b) % 6) / delta) / 6;
            if (color.g == cmax)
                return ((color.b - color.r) / delta + 2) / 6;
            return ((color.r - color.g) / delta + 4) / 6;
        }
    }

    signal released()

    width: 410
    height: 40

    Rectangle {
        id: idSliderMainRectangle

        anchors.verticalCenter: parent.verticalCenter
        anchors.horizontalCenter: parent.horizontalCenter

        width: 30
        height: parent.width
        border.width: 2
        radius: 10

        gradient: Gradient {
            GradientStop { position: 0.0; color: Qt.hsla(0.0, colorHSV_Saturation, colorHSV_Value, 1) }
            GradientStop { position: 0.2; color: Qt.hsla(0.2, colorHSV_Saturation, colorHSV_Value, 1) }
            GradientStop { position: 0.4; color: Qt.hsla(0.4, colorHSV_Saturation, colorHSV_Value, 1) }
            GradientStop { position: 0.6; color: Qt.hsla(0.6, colorHSV_Saturation, colorHSV_Value, 1) }
            GradientStop { position: 0.8; color: Qt.hsla(0.8, colorHSV_Saturation, colorHSV_Value, 1) }
            GradientStop { position: 1.0; color: Qt.hsla(1.0, colorHSV_Saturation, colorHSV_Value, 1) }
        }
        rotation: -90

        Rectangle {
            id: idCurrentColor

            x: 10
            y: (idSliderMainRectangle.height-10) * value - 15

            width: idMouseArea.pressed ? 40 : 10
            height: 40
            color: idSliderColor.color
            rotation: 90
            border.width: 1
            radius: 10
        }
    }

    MouseArea {
        id: idMouseArea
        anchors.fill: parent

        onMouseXChanged: {
            if (idMouseArea.mouseX < 5) {
                idSliderColor.value = 0;
            } else if (idMouseArea.mouseX > (idMouseArea.width - 5)) {
                idSliderColor.value = 1;
            } else {
                idSliderColor.value = ((idMouseArea.mouseX - (idCurrentColor.height/2)) + 15)/(width - 10)
            }
            idSliderColor.color = Qt.hsla(idSliderColor.value, colorHSV_Saturation, colorHSV_Value, 1)
        }

        onReleased: {
            UiConfig.sound.play_click()
            idSliderColor.released()
        }
    }
}
