import QtQuick 2.0
import "." // QTBUG-34418, singletons require explicit import to load qmldir file

Item {
    id: idSlider

    property int step: 0
    property real value: 0.5

    property alias backColor: idSliderBackground.color

    property alias sliderColor: idSliderCurrent.color
    property alias sliderRadius: idSliderCurrent.radius
    property alias sliderBorder: idSliderCurrent.border

    property alias cursorSrcImage: idSliderImage.source

    width: 400
    height: idSliderImage.height

    MouseArea {
        id: idSliderMouseArea

        anchors.bottom: parent.bottom
        anchors.top: parent.top
        anchors.right: parent.right
        anchors.rightMargin: idSliderImage.width / 2
        anchors.left: parent.left
        anchors.leftMargin: idSliderImage.width / 2

        onMouseXChanged: {
            if (mouseX < 0)
                value = 0;
            else if (mouseX > width)
                value = 1;
            else if (step > 1)
                value = Math.round(mouseX / width * step) / step
            else
                value = mouseX / width
        }

        onReleased: {
            UiConfig.sound.play_click()
        }
    }

    Rectangle {
        id: idSliderBackground

        anchors.bottom: parent.bottom
        anchors.bottomMargin: 10
        anchors.top: parent.top
        anchors.topMargin: 10
        anchors.right: parent.right
        anchors.left: parent.left

        color: "#ffffff"
        radius: 10
        border.width: 2

        Rectangle {
            id: idSliderCurrent

            anchors.bottom: parent.bottom
            anchors.top: parent.top

            width: value * (parent.width - idSliderImage.width) + idSliderImage.width/2
            color: "#0080ff"
            radius: idSliderBackground.radius
            border.width: idSliderBackground.border.width
        }

        Image {
            id: idSliderImage

            anchors.verticalCenter: parent.verticalCenter

            x: idSliderCurrent.width - width/2
            fillMode: Image.PreserveAspectFit
            source: "SliderCursor.png"
        }
    }
}
