import QtQuick 2.0
import "../HorusComponents"

Popup {
    id: choosepopup

    property string title: ""       // Box title
    property int currentElement: 0  // Initial selected element
    property var model: 0           // Model for ListView
    property var callback: null     // Callback called with the index of
                                    // selected element or undefined if clicked
                                    // on background. The callback should return
                                    // true to let the popup close itself

    /** Function to wrap call to user's callback **/
    function _msg_callback_wrapper(nr) {
        if (!callback || callback(nr) === true) {
            close();
        }
    }

    Rectangle {
        id: rectangleOut

        anchors.centerIn: parent

        color: UiConfig.colors.popup_bg
        radius: 10
        border.color: UiConfig.colors.popup_border

        width: 400
        height: column.height + 20

        MouseArea {
            anchors.fill: parent
            onClicked: {
                // Nothing to do
                // This MouseArea is present to catch click signals, to prevent
                // triggering the backgound MouseArea
            }
        }

        Column {
            id: column

            anchors.centerIn: parent

            width: parent.width - 20
            spacing: 10

            Text {
                width: parent.width
                text: title
                wrapMode: Text.Wrap
                color: UiConfig.colors.popup_fg_title
                horizontalAlignment: Text.AlignHCenter
                font.pixelSize: 35
                visible: text // Hide if text evaluates to false
            }

            List {
                id:list
                anchors.horizontalCenter: parent.horizontalCenter

                width: parent.width - 20
                height: 166
                maxElementToDisplay: 4

                model: choosepopup.model
                currentElement: choosepopup.currentElement

                onValidatedChanged: {
                    if (validated){
                        list.validated = false;
                        _msg_callback_wrapper(currentElement);
                    }
                }
            }
        }
    }

    onClickedOut: {
        _msg_callback_wrapper();
    }
}
