import QtQuick 2.0
import "../HorusComponents"

Popup {
    id: filepopup

    property string title: ""       // Box title
    property int currentElement: 0  // Initial selected element
    property var model: 0           // Model for ListView
    property var loader: null       // Loader to handle files
    property var testConfig: null
    property var callback: null     // Callback called with the index of
                                    // selected element or undefined if clicked
                                    // on background. The callback should return
                                    // true to let the popup close itself

    /** Function to wrap call to user's callback **/
    function _msg_callback_wrapper(nr) {
        if (!callback || callback(nr) === true) {
            close();
        }
    }

    Rectangle {
        id: rectangleOut

        anchors.centerIn: parent

        color: UiConfig.colors.popup_bg
        radius: 10
        border.color: UiConfig.colors.popup_border

        width: 400
        height: column.height + 20

        MouseArea {
            anchors.fill: parent
            onClicked: {
                // Nothing to do
                // This MouseArea is present to catch click signals, to prevent
                // triggering the backgound MouseArea
            }
        }

        MouseArea {
            width: actions.width
            height: actions.height
            anchors.left: actions.left
            onClicked: {
                // Nothing to do
                // This MouseArea is present to catch click signals, to prevent
                // triggering the backgound MouseArea when clicking on the buttons
                // on the left side (when disabled)
            }
        }

        Column {
            id: column

            anchors.centerIn: parent

            width: parent.width - 20
            spacing: 10

            Text {
                width: parent.width
                text: title
                wrapMode: Text.Wrap
                color: UiConfig.colors.popup_fg_title
                horizontalAlignment: Text.AlignHCenter
                font.pixelSize: 35
                visible: text // Hide if text evaluates to false
            }

            List {
                id:list
                anchors.horizontalCenter: parent.horizontalCenter

                width: parent.width - 20
                height: 166
                maxElementToDisplay: 4

                model: filepopup.model
                currentElement: filepopup.currentElement

                onValidatedChanged: {
                    if (validated){
                        list.validated = false;
//                        _msg_callback_wrapper(currentElement);
                    }
                }
            }
        }

        Column {
            id: actions
            anchors.right: parent.left
            anchors.top:parent.top
            anchors.topMargin: 20

            spacing: 10

                ButtonAddFile {
                    enabled: true
                    onClicked: {
                        var nbf = loader.filesListCount;
                        var nb = nbf;
//                        //console.log("list.currentElement = ", list.currentElement, " nb = ", nb, " megohmmeterConfig = ", loader.filesList[list.currentElement]);
//                        config.megohmmeterConfig =  loader.filesList[list.currentElement];
//                        for (nb in loader.filesList) {
//                            nb++;
//                        }

                        //Cas du multiHipot
                        if(loader.multiFlag) {
                            while (loader.multiExists("file" + nbf.toString())) {
    //                            //console.log("file", nbf, " exists" );
                                nbf++
                            }
                        }
                        else {
                            while (loader.exists("file" + nbf.toString())) {
    //                            //console.log("file", nbf, " exists" );
                                nbf++
                            }
                        }

//                        loader.data.copyToStorage("file" + nbf.toString());
                        loader.setFilename("file" + nbf.toString());
                        testConfig("file" + nbf.toString());
                        model = loader.filesList;

                        for (nb in model) {

                            console.log("FilePopUp: buttonAddFile: nb = ", nb, " model[nb] = ",model [nb], " et config.insulationConfig = ",config.insulationConfig);
                            if (model[nb] === loader.filename)
                                break;
                            nb++;
                        }

                        list.currentElement = nb;
                        btnSub.enabled = true;
                        console.log("FilePopUp: buttonAddFile: list.currentElement = ",list.currentElement, " et nb = ", nb);

                    }
                }
                ButtonDelete {
                    id: btnSub
                    enabled: loader.filesListCount > 1
                    onClicked: {
                        popup().msg(qsTr("Delete file"), qsTr("Do you really want to delete %1 ?").arg(loader.filesList[list.currentElement]), [qsTr("Yes"), qsTr("Cancel")], function(nr) {
                                        if (nr === 0) {
//                                            console.log("FilePopUp: buttonRmFile: loader.filesListCount = ", loader.filesListCount);
                                            var nrm = list.currentElement;
                                            loader.remove(loader.filesList[list.currentElement]);
                                            if (loader.filesListCount <= 1) enabled = false;
                                            loader.setFilename(loader.filesList[nrm - 1]);
                                            testConfig(loader.filesList[nrm - 1]);
                                            model = loader.filesList;
//                                            console.log("FilePopUp: buttonRmFile: apres RM loader.filesListCount = ", loader.filesListCount);
                                            list.currentElement = nrm - 1;
                                        }
                                        return true;
                                    });
                    }
                }
                ButtonPlay {
                    enabled: true
                    onClicked:  {
                        testConfig(loader.filesList[list.currentElement]);
                        _msg_callback_wrapper(list.currentElement);
                    }
                }
        }
    }


    onClickedOut: {
        testConfig(loader.filesList[list.currentElement]);
        _msg_callback_wrapper(list.currentElement);
    }
}
