import QtQuick 2.0
import "../HorusComponents"
import "keys_private"

Popup {
    id: textEdit

    property string title: ""    // Popup title
    property string value: ""    // Initial value
    property string regex        // Validation regex
    property var callback: null  // Callback called with the edited value or
                                 // undefined if clicked on background
                                 // The callback should return true to let the
                                 // popup close itself

    /** Function to wrap call to user's callback **/
    function _msg_callback_wrapper(nr) {
        if (!callback || callback(nr) === true)
            close();
    }

    Text {
        anchors {
            top: rectangleOut.top
            left: rectangleOut.left
            leftMargin: 480
            right: rectangleOut.right
            bottom: rectangleOut.top
            bottomMargin: -65
        }
        text: title
        color: UiConfig.colors.popup_fg_title
        font.pixelSize: 40
        fontSizeMode: Text.Fit
        horizontalAlignment: Text.AlignHCenter
        verticalAlignment: Text.AlignVCenter
    }

    Image {
        id: rectangleOut

        anchors.centerIn: parent

        source: "keys_private/Keyboard_bg.png"

        MouseArea {
            anchors.fill: parent
            onClicked: {
                // Nothing to do
                // This MouseArea is present to catch click signals, to prevent
                // triggering the backgound MouseArea
            }
        }

        Rectangle {
            anchors {
                top: parent.top
                topMargin: 11
                left: parent.left
                leftMargin: 13
            }

            height: 59
            width: 422

            border.color: textInput.valid ? (textInput.activeFocus ? "transparent" : "#000000") : UiConfig.colors.popup_bg_edit_ko
            border.width: 5
            radius: 8
            color: "transparent"

            TextInput {
                id: textInput
                property var _regexp
                property bool valid: true

                anchors.fill: parent
                anchors.leftMargin: 5
                anchors.rightMargin: 5

                focus: true
                clip: true

                text: textEdit.value

                color: textInput.valid ? UiConfig.colors.fg_active : UiConfig.colors.popup_bg_edit_ko
                selectionColor: "#66ffffff"
                selectByMouse: true
                cursorVisible: true
                horizontalAlignment: Text.AlignHCenter
                verticalAlignment: Text.AlignVCenter
                font.pixelSize: 26

                onTextChanged: {
                    if (!_regexp)
                        _regexp = new RegExp(regex);
                    valid = _regexp.test(text);
                }

                onAccepted: {
                    if (valid)
                        _msg_callback_wrapper (textInput.text)
                    else
                        popup().msg(qsTr("Value error"), qsTr("Written value is not valid for this field"), [qsTr("Ok")], function(nr) {
                            if (nr === 0) {
                                return true;
                            }
                        });
                }
            }
        }
        Keyboard {
            anchors {
                left: parent.left
                right: parent.right
                top: parent.top
                topMargin: 68
                bottom: parent.bottom
            }
            id: keyboard
            onValidated: textInput.accepted()
        }
    }

    onClickedOut: {
        _msg_callback_wrapper();
    }

    Component.onCompleted: {
        textInput.forceActiveFocus(Qt.MouseFocusReason);
    }
}
