import QtQuick 2.0
import "keys_private"
import "../HorusComponents"

Popup {
    id: numberEdit

    property string title: ""    // Popup title
    property string value: ""    // Initial value
    property real min: 0         // Minimal allowed
    property real max: 10        // Maximal allowed
    property int precision: 0    // Float precision (number of digits after
                                 // decimal point)
    property string unit: ""     // Displayed unit
    property var callback: null  // Callback called with the edited value or
                                 // undefined if clicked on background
                                 // The callback should return true to let the
                                 // popup close itself

    /** Function to wrap call to user's callback **/
    function _msg_callback_wrapper(nr) {
        // Ici soit l'utilisateur a validé sa saisie et celle-ci est correcte soit a appuyé en dehors de la pop up

        // Si l'utilisateur appui en dehors de la pop up alors on la ferme
        if (!callback)
            close();

        // Si l'utilisteur a validé sa saisie alors on ferme la pop up et on actualise la valeur
        else {

            close();
            callback(nr);
        }
    }

    function validate_popup() {
        var locale = Qt.locale();

        // Set local decimal point to "."
        var validedNumber = numberInput.text/*.replace(locale.decimalPoint, ".")*/;
        var userValue = parseFloat(validedNumber);

        if ((userValue < min) || isNaN(userValue) || userValue > max) {
            var minstr = min + unit;
            var maxstr = max + unit;
            popup().msg(qsTr("Value error"), qsTr("Value must be between %1 and %2").arg(minstr).arg(maxstr), [qsTr("Ok")], function(nr) {
                if (nr === 0) {
                    numberInput.selectAll();
                    return true;
                }
            });
            return;
        }

        _msg_callback_wrapper(userValue);
    }

    Text {
        anchors {
            top: rectangleOut.top
            left: rectangleOut.left
            leftMargin: 250
            right: rectangleOut.right
            bottom: rectangleOut.top
            bottomMargin: -82
        }
        text: title
        color: UiConfig.colors.popup_fg_title
        font.pixelSize: 40
        fontSizeMode: Text.Fit
        horizontalAlignment: Text.AlignHCenter
        verticalAlignment: Text.AlignVCenter
        visible: text // Hide if text evaluates to false
    }

    Image {
        id: rectangleOut

        anchors.centerIn: parent

        source: "keys_private/Keypad_bg.png"

        MouseArea {
            anchors.fill: parent
            onClicked: {
                // Nothing to do
                // This MouseArea is present to catch click signals, to prevent
                // triggering the backgound MouseArea
            }
        }

        Rectangle {
            id: numberZone

            anchors {
                top: parent.top
                topMargin: 11
                left: parent.left
                leftMargin: 25
            }

            height: 50
            width: 187

            border.color: numberInput.valid ? (numberInput.activeFocus ? "transparent" : "#000000") : UiConfig.colors.popup_bg_edit_ko
            border.width: 5
            radius: 8
            color: "transparent"

            TextInput {
                id: numberInput
                property bool _first_text_update: true
                property int _precision: -1
                property bool valid: true

                function evaluateNumber () {
                    var locale = Qt.locale();
                    var number = numberInput.text/*.replace(locale.decimalPoint, ".")*/;

                    valid = ((number >= numberEdit.min) && (number <= numberEdit.max));

                    if (_precision != numberEdit.precision) {
                        _precision = numberEdit.precision;
                        _first_text_update = false;
                        numberInput.selectAll();
                    } else if (numberEdit.value == number && _first_text_update) {
                        _first_text_update = false;
                        numberInput.selectAll();
                    }

                    return number;
                }

                anchors.fill: parent

                focus: true

                text: {
                    var locale = Qt.locale();
                        Number(numberEdit.value).toFixed(precision)/*.replace(".", locale.decimalPoint)*/
                    }
                inputMethodHints: Qt.ImhDigitsOnly
                maximumLength: 10

                color: numberInput.valid ? UiConfig.colors.fg_active : UiConfig.colors.popup_bg_edit_ko
                selectionColor: "#66ffffff"
                selectByMouse: true
                cursorVisible: true
                horizontalAlignment: Text.AlignHCenter
                verticalAlignment: Text.AlignVCenter
                font.pixelSize: 26

                onTextChanged: evaluateNumber()
                onAccepted: numberEdit.validate_popup()
            }
        }
        Keypad {
            id: keypad

            anchors {
                left: parent.left
                leftMargin: 17
                top: parent.top
                topMargin: 95
            }

            commaEnabled: numberEdit.precision > 0
            minusEnabled: numberEdit.min < 0

            onValidated: numberEdit.validate_popup()

            KeyLargeNr {
                x: 431
                height: 210
                keyImage: "KeyReturn.png"
                onClicked: keypad.keypressed(12)
            }
        }
    }

    onClickedOut: {
        _msg_callback_wrapper();
    }

    Component.onCompleted: {
        numberInput.forceActiveFocus(Qt.MouseFocusReason);
    }
}
