import QtQuick 2.0
import "../HorusComponents"

Popup {
    id: messagebox

    property string title: ""    // Box title
    property string message: ""  // Box message
    property variant answers: [] // List of choices to display
    property var callback: null  // Callback called with the index of selected
                                 // answer or undefined if clicked on background
                                 // The callback should return true to let the
                                 // popup close itself

    /** Function to wrap call to user's callback **/
    function _msg_callback_wrapper(nr) {
        if (!callback || callback(nr) === true)
            close();
    }

    Rectangle {
        id: rectangleOut

        anchors.centerIn: parent

        color: UiConfig.colors.popup_bg
        radius: 10
        border.color: UiConfig.colors.popup_border

        width: 450
        height: column.height + 20

        MouseArea {
            anchors.fill: parent
            onClicked: {
                // Nothing to do
                // This MouseArea is present to catch click signals, to prevent
                // triggering the backgound MouseArea
            }
        }

        Column {
            id: column

            anchors.centerIn: parent

            width: parent.width - 20
            spacing: 10

            Text {
                width: parent.width
                text: title
                wrapMode: Text.Wrap
                color: UiConfig.colors.popup_fg_title
                horizontalAlignment: Text.AlignHCenter
                font.pixelSize: 35
                visible: text // Hide if text evaluates to false
            }

            Text {
                width: parent.width
                text: message
                wrapMode: Text.Wrap
                color: "#ffffff"
                font.pixelSize: 20
                visible: text // Hide if text evaluates to false
            }

            Repeater {
                id: btnlst
                width: parent.width
                clip: true

                model: answers

                delegate: Button {
                    width: btnlst.width
                    height: txt.height + 20
                    onClicked: _msg_callback_wrapper(index)
                    text: ""

                    Text {
                        id: txt
                        anchors.centerIn: parent
                        width: parent.width - 20
                        text: answers[index]
                        color: "#ffffff"
                        wrapMode: Text.Wrap
                        font.bold: true
                        font.pixelSize: 20
                        horizontalAlignment: Text.AlignHCenter
                    }
                }
            }
        }
    }

    onClickedOut: {
        _msg_callback_wrapper();
    }
}
