import QtQuick 2.0
import QtQuick.Controls 1.3

Item {
    id: component
    property bool opened: state == "opened"

    function push(arg) {
        return stackview.push(arg);
    }

    function get(arg) {
        return stackview.get(arg);
    }

    visible: false

    states : [
        State {
            name: "opened"
            when: stackview.depth > 1
        }
    ]

    transitions: [
        Transition {
            to: ""
            SequentialAnimation {
                NumberAnimation {
                    target: bgrectangle
                    property: "opacity"
                    to: 0
                    duration: 200
                }
                PropertyAction {
                    target: component
                    property: "visible"
                    value: false
                }
            }
        },

        Transition {
            to: "opened"
            SequentialAnimation {
                PropertyAction {
                    target: component
                    property: "visible"
                    value: true
                }
                NumberAnimation {
                    target: bgrectangle
                    property: "opacity"
                    to: 0.8
                    duration: 200
                }
            }
        }
    ]

    Rectangle {
        id: bgrectangle
        anchors.fill: parent
        color: "black"
        opacity: 0
    }

    MouseArea {
        id: bgmousearea
        anchors.fill: parent
        onClicked: stackview.currentItem.clickedOut()
        onWheel: stackview.currentItem.clickedOut()
    }

    StackView {
        id: stackview
        anchors.fill: parent

        initialItem: Popup {} // Empty item that will never be popped out

        delegate: StackViewDelegate {
            pushTransition: StackViewTransition {
                PropertyAnimation {
                    target: enterItem
                    property: "y"
                    from: -exitItem.height
                    to: 0
                }
                PropertyAnimation {
                    target: exitItem
                    property: "y"
                    from: 0
                    to: enterItem.height
                }
            }
            popTransition: StackViewTransition {
                PropertyAnimation {
                    target: enterItem
                    property: "y"
                    from: exitItem.height
                    to: 0
                }
                PropertyAnimation {
                    target: exitItem
                    property: "y"
                    from: 0
                    to: -enterItem.height
                }
            }
        }
    }

    Connections {
        target: stackview.currentItem
        onClose: stackview.pop()
    }
}
