import QtQuick 2.0
import "keys_private"
import "../HorusComponents"

Popup {
    id: numberEdit

    property string title: ""    // Popup title
    property real value: 0    // Initial value
    property string compvalue: ""    // Value to compare
    property bool isMax: true
    property real min: 0         // Minimal allowed
    property real max: 10        // Maximal allowed
    property var units: []       // List of units (first is base, second is
                                 // ×1000, third is ×1000×1000 and so on)
    property var callback: null  // Callback called with the edited value or
                                 // undefined if clicked on background
                                 // The callback should return true to let the
                                 // popup close itself

    property int _unitNb: 0

    /** Function to wrap call to user's callback **/
    function _msg_callback_wrapper(nr) {
        if (!callback || callback(nr) === true)
            close();
    }

    function validate_popup() {

        // Toute cette opération sert à afficher les bonnes bornes dans le message d'erreur

//        console.log("validate_popup 1: numberEdit.compvalue = ", numberEdit.compvalue);
        var userValue = numberInput.evaluateNumber();
        var comp = numberEdit.compvalue*1000/1000;
//        console.log("validate_popup 2: comp = ", comp);

        if ((userValue < min) || isNaN(userValue) || userValue > max) {
            var unitlen = units.length - 1;
            var p = 0;
            while (p < unitlen) {
                p++;
            }

            var minstr = numberEdit.min;
            var minunit = 0;
            while (minstr > 1000 && minunit < unitlen) {
                minstr /= 1000;
                minunit += 1;
            }
            minstr = minstr/*.toFixed(0)*/ + units[minunit];

            var maxstr = numberEdit.max ;
            var maxunit = 0;
            while (maxstr > 1000 && maxunit < unitlen) {
                maxstr /= 1000;
                maxunit += 1;
            }
            if(maxunit > units.length - 1) maxunit = units.length - 1;
            maxstr = maxstr/*.toFixed(0)*/ + units[maxunit];

            popup().msg(qsTr("Value error"), qsTr("Value must be between %1 and %2").arg(minstr).arg(maxstr), [qsTr("Ok")], function(nr) {
                if (nr === 0) {
                    numberInput.selectAll();
                    return true;
                }
            });
            return;
        }
        if (comp !== "") {
//            console.log("validate_popup 3: comp != __", comp);
            if (isMax === true) {
//                console.log("validate_popup 4: isMax userValue = ", userValue, " comp = ", comp);
                if(userValue <= comp) {
//                    console.log("validate_popup 5: isMax userValue <= comp");
                    popup().msg(qsTr("Value error"), qsTr("High limit must be higher than low limit"), [qsTr("Ok")], function(nr) {
                        if (nr === 0) {
                            numberInput.selectAll();
                            return true;
                        }
                    });
                    return;
                }
            }
            else if (isMax === false) {
//                console.log("validate_popup 4: !isMax userValue = ", userValue, " comp = ", comp);
                if(userValue >= comp) {
//                    console.log("validate_popup 5: isMax userValue >= comp");

                    popup().msg(qsTr("Value error"), qsTr("High limit must be higher than low limit"), [qsTr("Ok")], function(nr) {
                        if (nr === 0) {
                            numberInput.selectAll();
                            return true;
                        }
                    });
                    return;
                }
            }
        }
        _msg_callback_wrapper(userValue);
    }

    Text {
        anchors {
            top: rectangleOut.top
            left: rectangleOut.left
            leftMargin: 250
            right: rectangleOut.right
            rightMargin: 75
            bottom: rectangleOut.top
            bottomMargin: -82
        }
        text: title
        color: UiConfig.colors.popup_fg_title
        font.pixelSize: 40
        fontSizeMode: Text.Fit
        horizontalAlignment: Text.AlignHCenter
        verticalAlignment: Text.AlignVCenter
        visible: text // Hide if text evaluates to false
    }

    Image {
        id: rectangleOut

        anchors.centerIn: parent

        source: "keys_private/KeypadUnits_bg.png"

        MouseArea {
            anchors.fill: parent
            onClicked: {
                // Nothing to do
                // This MouseArea is present to catch click signals, to prevent
                // triggering the backgound MouseArea
            }
        }

        Rectangle {
            id: numberZone

            anchors {
                top: parent.top
                topMargin: 11
                left: parent.left
                leftMargin: 25
            }

            height: 50
            width: 187

            border.color: numberInput.valid ? (numberInput.activeFocus ? "transparent" : "#000000") : UiConfig.colors.popup_bg_edit_ko
            border.width: 5
            radius: 8
            color: "transparent"

            TextInput {
                id: numberInput
                property bool _first_text_update: true
                property int _precision: -1
                property bool valid: true

                function evaluateNumber () {
                    var locale = Qt.locale();
                    var number = numberInput.text/*.replace(locale.groupSeparator, "").replace(locale.decimalPoint, ".")*/;
                    if (_unitNb) {
                        var i = _unitNb;
                        //On récupère la valeur en uA
                        //On récupère la valeur en kOhm
                        while (i) {
                            number *= 1000;
                            i -= 1;
                        }
                    }


                    valid = ((number >= numberEdit.min) && (number <= numberEdit.max));


                    if (_first_text_update) {
                        _first_text_update = false;
                        numberInput.selectAll();
                    }
                    return number;
                }

                anchors.fill: parent

                focus: true

                text: {
                    var locale = Qt.locale();
                    var number = numberEdit.value;
                    if (_unitNb > 0) {
                        var i = _unitNb;
                        // number est en uA mais le texte affiché doit lui correspondre à l'unité (/1000)
                        while (i) {
                            number /= 1000.0;
                            i -= 1;
                        }
                    }

                    // Pour chaque unité les nombre de chiffres significatif pouvant être entrés varient
                    // Pour la première on autorise pas les chiffres après la virgule, pour la deuxième on en autorise 3 et pour les suivantes on en autorise 5
                    /*var fix = 1_unitNb > 1 ? 5 : (_unitNb > 0 ? 3 : 0);*/

//                    //console.log("text: number = ", number);
//                    //console.log("text: number.toString = ", number.toString());
                      number.toString()/*.replace(locale.decimalPoint, ".")*/;

                    /*return Number(number);*//*.toFixed(fix)*/
                }
                inputMethodHints: Qt.ImhDigitsOnly
                maximumLength: 10

                color: numberInput.valid ? UiConfig.colors.fg_active : UiConfig.colors.popup_bg_edit_ko
                selectionColor: "#66ffffff"
                selectByMouse: true
                cursorVisible: true
                horizontalAlignment: Text.AlignHCenter
                verticalAlignment: Text.AlignVCenter
                font.pixelSize: 26

                onTextChanged: evaluateNumber();
                onAccepted: numberEdit.validate_popup()
            }
        }
        MouseArea {
            anchors {
                top: parent.top
                bottom: parent.bottom
                right: parent.right
            }
            width: 74
            onClicked: clickedOut()
        }
        Keypad {
            id: keypad

            anchors {
                left: parent.left
                leftMargin: 17
                top: parent.top
                topMargin: 95
            }

            commaEnabled: ((min !==0 && min < 1) || _unitNb > 0)
            minusEnabled: numberEdit.min < 0

            onValidated: numberEdit.validate_popup()

            PathView {
                id: unitsbox
                x: 432
                height: 100
                width: 130
                clip: true
                pathItemCount: 3
                currentIndex: _unitNb
                model: units

                function clicked(nr) {
                    if (nr === _unitNb)
                        return;

                    var v = numberInput.evaluateNumber();
                    var unitdiff = nr - _unitNb;
                    while (unitdiff != 0) {
                        if (unitdiff > 0) {
                            v = v * 1000.0;
                            unitdiff -= 1;
                        } else {
                            v = v / 1000.0;
                            unitdiff += 1;
                        }
                    }


                    //Dans la plus petite unité les chiffres à virgules ne sont pas permis donc on arrondi à la valeur entière la plus proche
                    numberEdit.value = nr === 0 ? Number(v).toFixed(0) : v;

                    numberInput.evaluateNumber();

                    _unitNb = nr;
                    if (currentIndex != _unitNb) currentIndex = _unitNb;
                }

                preferredHighlightBegin: 0.5
                preferredHighlightEnd: 0.5
                highlightRangeMode: PathView.StrictlyEnforceRange

                //Destiné à ralentir le mouvement du scroll pour faciliter la sélection
                highlightMoveDuration: 700

                delegate: Text {
                    width: unitsbox.width
                    horizontalAlignment: Text.AlignHCenter
                    text: modelData
                    color: PathView.isCurrentItem ? UiConfig.colors.fg_active : "#c5c5cc"
                    MouseArea {
                        anchors.fill: parent
                        onClicked: unitsbox.clicked(index)
                    }
                }

                path: Path {
                    startX: unitsbox.width/2
                    startY: 0
                    PathLine { x: unitsbox.width/2; y: unitsbox.height; }
                }

                onMovementEnded: unitsbox.clicked(currentIndex)
                onModelChanged: if (currentIndex != _unitNb) currentIndex = _unitNb
                visible: units.length > 2
            }
            Item {
                x: 432
                height: 100
                width: 130
                visible: units.length <= 2
                Text {
                    y: 20
                    width: parent.width
                    visible: units.length >= 1
                    horizontalAlignment: Text.AlignHCenter
                    text: units[0]
                    color: _unitNb == 0 ? UiConfig.colors.fg_active : "#c5c5cc"
                    MouseArea {
                        anchors.fill: parent
                        onClicked: unitsbox.clicked(0)
                    }
                }
                Text {
                    y: 55
                    width: parent.width
                    visible: units.length == 2
                    horizontalAlignment: Text.AlignHCenter
                    text: units[1]
                    color: _unitNb == 1 ? UiConfig.colors.fg_active : "#c5c5cc"
                    MouseArea {
                        anchors.fill: parent
                        onClicked: unitsbox.clicked(1)
                    }
                }
            }
            KeyLargeNr {
                x: 431
                y: 110
                height: 100
                keyImage: "KeyReturn.png"
                onClicked: keypad.keypressed(12)
            }
        }
    }

    onClickedOut: {
        _msg_callback_wrapper();
    }

    Component.onCompleted: {
        if (value >= 1000) {
            var nb = value;
            var maxnb = units.length - 1;
            while (nb >= 1000 && _unitNb < maxnb) {
                nb /= 1000;
                _unitNb += 1;
          }
        }
        numberInput._first_text_update = true;
        numberInput.evaluateNumber();
        numberInput.forceActiveFocus(Qt.MouseFocusReason);
    }
}
