import QtQuick 2.2
import "../../HorusComponents"
import "."

Item {
    signal validated()

    property int mode: 0 // bit0 => ABC(0) or 123(1) ; bit1 => upper ; bit2 => symbol alt
    property int line: 0 // keys line
    property var keys: [
        "azertyuiopqsdfghjklmwxcvbn?,.",
        "AZERTYUIOPQSDFGHJKLMWXCVBN?,.",
        "1234567890@#€%&-+()/*\"':;!?,.",
        "1234567890$£_~Ω=±{}\\µ[]§°|Δ<>",
    ]

    onModeChanged: {
        if (mode & 1)
            if (mode & 4)
                line = 3;
            else
                line = 2;
        else
            if (mode & 2)
                line = 1;
            else
                line = 0;
    }

    function keypressed(nr) {
        UiConfig.sound.play_click()

        if (nr == 29) { // Shift
            if (mode & 1)
                mode ^= 4;
            else
                mode ^= 2;

        } else if (nr == 30) { // Backspace
            kbed.sendCharacter(Qt.Key_Backspace, "", false, false);

        } else if (nr == 31) { // 123\ABC
            mode ^= 1;

        } else if (nr == 32) { // Enter
            validated();

        } else if (nr == 33) { // Space
            kbed.sendCharacter(Qt.Key_Space, " ", false, false);

        } else {
            var character = keys[line][nr];
            kbed.sendCharacter(character, character, false, false);
        }
    }

    Timer {
        id: keyRepeater
        property int keynr: -1
        interval: 100;
        running: keynr != -1;
        repeat: true
        onTriggered: keypressed(keynr)
    }

    Grid {
        id: toprows
        anchors {
            top: parent.top
            topMargin: 14
            left: parent.left
            leftMargin: 14
        }
        columns: 10
        spacing: 14
        Repeater {
            model: 20
            delegate: KeySmall {
                text: keys[line][index]
                onReleased: keyRepeater.keynr = -1
                onPressAndHold: keyRepeater.keynr = index
                onClicked: keypressed(index)
            }
        }
    }
    Row {
        anchors {
            top: toprows.bottom
            topMargin: 14
            left: parent.left
            leftMargin: 119
        }
        spacing: 14
        Repeater {
            model: 7
            delegate: KeySmall {
                text: keys[line][index + 20]
                onReleased: keyRepeater.keynr = -1
                onPressAndHold: keyRepeater.keynr = index + 20
                onClicked: keypressed(index + 20)
            }
        }
    }
    KeyLarge {
        id: largetoprow
        anchors {
            top: toprows.bottom
            topMargin: 14
            left: parent.left
            leftMargin: 14
        }
        keyImage: mode & 1 ? "" : (mode & 2 ? "KeyShift_on.png" : "KeyShift_off.png")
        text: mode & 4 ? "?123" : "=\\<"
        onClicked: keypressed(29)
    }
    KeyLarge {
        anchors {
            top: toprows.bottom
            topMargin: 14
            left: parent.left
            leftMargin: 609
        }
        keyImage: "KeyDel.png"
        onReleased: keyRepeater.keynr = -1
        onPressAndHold: keyRepeater.keynr = 30
        onClicked: keypressed(30)
    }
    KeyLarge {
        anchors {
            top: largetoprow.bottom
            topMargin: 14
            left: parent.left
            leftMargin: 14
        }
        text: mode & 1 ? "ABC" : "123"
        onClicked: keypressed(31)
    }
    KeyLarge {
        anchors {
            top: largetoprow.bottom
            topMargin: 14
            left: parent.left
            leftMargin: 609
        }
        keyImage: "KeyReturn.png"
        onClicked: keypressed(32)
    }
    KeySmall {
        anchors {
            top: largetoprow.bottom
            topMargin: 14
            left: parent.left
            leftMargin: 119
        }
        text: keys[line][27]
        onReleased: keyRepeater.keynr = -1
        onPressAndHold: keyRepeater.keynr = 27
        onClicked: keypressed(27)
    }
    KeySmall {
        anchors {
            top: largetoprow.bottom
            topMargin: 14
            left: parent.left
            leftMargin: 539
        }
        text: keys[line][28]
        onReleased: keyRepeater.keynr = -1
        onPressAndHold: keyRepeater.keynr = 28
        onClicked: keypressed(28)
    }
    KeySmall {
        anchors {
            top: largetoprow.bottom
            topMargin: 14
            left: parent.left
            leftMargin: 189
        }
        width: 336
        keyImage: "KeySpace.png"
        onReleased: keyRepeater.keynr = -1
        onPressAndHold: keyRepeater.keynr = 33
        onClicked: keypressed(33)
    }
}
