import QtQuick 2.0
import QtMultimedia 5.2
import "HorusComponents"
import "Popup"
import "Popup/functions.js" as PopupFcts


Item {
    id: root

    property bool firstON: false

    function popup() {
        return PopupFcts;
    }

    PageManager {
        focus: true
        anchors.fill: parent
        visible: canbus.connected



        Component.onCompleted: {
            if (config.language == "") {
                popup().choose(
                            qsTr("Language"),
                            config.languages,
                            config.languageToIndex(config.language),
                            function(nr) {
                                if (nr !== undefined) {
                                    config.language = config.languagesCodes[nr];
                                    return true;
                                }
                                return false;
                            });

                firstON = true;
            }




            if (watchdog.rebootStatus)
                popup().msg(qsTr("Watchdog"), qsTr("The device was restarted by watchdog."), [qsTr("Ok")], function(nr) {
                    watchdog.ack();
                    return true;
                });
        }

        Connections {
            target: config
            onLanguageChanged: {
//                console.log("main.qml: onLanguageChanged : config.language = ", config.language, " et qsTr(Accept) = ", qsTr("Accept"));
                if (firstON) {
                    firstON = false;
                    popup().legalDoc(qsTr("EULA"), [qsTr("Accept")], config.language , function(nr) {
                        if(config.adminPwdEmpty()) {
                            popup().msg(qsTr("Cybersecurity"), qsTr("The password of your administrator account is currently empty. Eaton recommends to set a new password for cybersecurity matters."), [qsTr("Ok")], function(nr) {
                                if(nr === 0) return true;
                            }, true);
                        }
                        return true;
                    }, true);
                }
        }
        }

//        Connections {
//            target: watchdog
//            onWatchdogError: {
//                popup().msg(qsTr("Restart the machine"), qsTr("Due to a software update the machine is about to restart. You can resart it manually."), [qsTr("Ok")], function(nr) {
//                    watchdog.ack();
//                    return true;
//                });
//        }
//        }
    }

    Rectangle {
        /* Qt uses double buffer to draw fluid animations, but VNC server send
           only one of them over network. To be sure the sent image is quite
           recent, we modify screen periodically with this pixel/rectangle. */
        anchors.bottom: root.bottom
        visible: config.wifiVnc
        width: 1
        height: 1
        Timer {
            property bool _alt
            interval: 2000
            running: parent.visible
            repeat: true
            triggeredOnStart: true
            onTriggered: {
                _alt = !_alt;
                parent.color = _alt ? "#080b1d" : "#080b1a";
            }
        }
    }

    PopupManager {
        id: popupmgr
        anchors.fill: parent
        focus: true
    }

    Page {
        anchors.fill: parent
        visible: !canbus.connected
        navigationBtnVisible: false
        title: "Disconnected"

        Text {
            anchors.centerIn: parent
            anchors.verticalCenterOffset: -50
            width: parent.width - 40
            wrapMode: Text.WordWrap
            horizontalAlignment: Text.AlignHCenter
            text: config.autoTr + qsTr("Another interface took control of the system.\nPress here to try to reconnect.")
            font.pixelSize: 22
            color: UiConfig.colors.fg_root
        }

        MouseArea {
            anchors.fill: parent
            onClicked: canbus.connect();
        }
    }

    Page {
        anchors.fill: parent
        visible: !config.model.ready
        navigationBtnVisible: false
        title: config.autoTr + qsTr("Not calibrated")

        Text {
            anchors.centerIn: parent
            anchors.verticalCenterOffset: -50
            width: parent.width - 40
            wrapMode: Text.WordWrap
            horizontalAlignment: Text.AlignHCenter
            text: config.autoTr + qsTr("The machine is not configured or lost its calibration.\nPlease contact support.")
            font.pixelSize: 22
            color: UiConfig.colors.fg_root
        }

        MouseArea {
            anchors.fill: parent
            onClicked: { /* Do nothing */ }
        }
    }


    // HORUS EVENT PHOTO


//            Row {
//                width: 800
//                height: 480
//                anchors {
//                    centerIn: parent
//                }

//                spacing: 1

//                Rectangle {
//                    width : 170
//                    height: 480
//                    color: "black"
//                        Text {
//                            id: txtEn
//                            width : 150
//                            color: "yellow"
//                            anchors {
//                                leftMargin: 5
//                                centerIn: parent
//        //                        left: parent.left
//        //                        verticalCenter: parent.Center
//                            }
//                            font.pointSize: 14
//                            textFormat: Text.RichText
//                            wrapMode: Text.WordWrap

//                            text: "<b>The guardians prevent Horus from becoming a Sefelec 5x. Bring them the key and restart the machine."
//                        }
//                }

//                Image {
//                    id: tof
//                    width: 458
//        //            anchors.top: parent.headerButton.bottom
////                    anchors.left: txtEn.right
////                    anchors.fill: parent
////                    fillMode: Image.PreserveAspectFit

//                    source: "GuardiansHorus.jpg"

//                }

//                Rectangle {
//                    width : 170
//                    height: 480
//                    color: "black"
//                        Text {
//                            id: txtFr
//                            width : 150
//                            color: "yellow"
//                            anchors {
//                                leftMargin: 5
//                                centerIn: parent
//        //                        left: parent.left
//        //                        verticalCenter: parent.Center
//                            }
//                            font.pointSize: 14
//                            textFormat: Text.RichText
//                            wrapMode: Text.WordWrap

//                            text: "<b>Les gardiens empêchent Horus de devenir Sefelec 5x. Amenez-leur la clef et redémarrez la machine."
//                        }
//                }

//        }
//            MouseArea {
//                anchors.fill: parent
//                onClicked: { /* Do nothing */ }
//            }


    Image {
        id: cursor
        source: "cursor.png"
        visible: false
        Connections {
            target: hal
            onMouseEvent: {
                cursor.opacity = 1;
                cursor.visible = true;
                cursor.x = mouseX;
                cursor.y = mouseY;
                cursorTimer.restart();
            }
        }
        Timer {
            id: cursorTimer
            repeat: false
            interval: 5000
        }
        SequentialAnimation {
            running: !cursorTimer.running
            NumberAnimation {
                target: cursor
                property: "opacity"
                from: 1
                to: 0
                duration: 1000
                easing.type: Easing.InOutQuad
            }
            PropertyAction {
                target: cursor;
                property: "visible"
                value: false
            }
        }
    }
}
