import QtQuick 2.2
import Horus 1.0
import "../HorusComponents"

Page {
    id: idAccueil

    title: ""
    navigationBtnVisible: false
    customHeaderComponent: Component {
        Item {
            anchors.fill: parent
            anchors.margins: 10
            anchors.leftMargin: remoteaccess.interfaceIsConnected ? 60 : undefined
            Row {
                anchors.baseline: parent.bottom
                anchors.baselineOffset: -5
                spacing: 10
                Text {
                    id: modelTitle
                    anchors.baseline: parent.baseline
                    width: Math.min(parent.parent.width - version.width - date.width - 40, implicitWidth)
                    text: config.model.model
                    color: "#007ac1"
                    font.pixelSize: 42
                    fontSizeMode: Text.Fit
                    wrapMode: Text.WordWrap
                }
                Text {
                    id: version
                    anchors.baseline: parent.baseline
                    text: "V" + (config.acl.value === ParamGlobal.SERVICE ? hal.softVersion : hal.lightSoftVersion())
                    color: "#6b6d7e"
                    font.pixelSize: 20
                }
            }
            Column {
                id: date
                anchors {
                    top: parent.top
                    topMargin: -7
                    right: parent.right
                    rightMargin: 20
                }
                property var date: new Date()

                Text {
                    anchors.horizontalCenter: parent.horizontalCenter
                    text: Qt.formatTime(parent.date, "hh:mm")
                    font.pixelSize: 30
                    color: "#6b6d7e"
                }
                Text {
                    anchors.horizontalCenter: parent.horizontalCenter
                    text: Qt.formatDate(parent.date, config.dateFormat)
                    font.pixelSize: 14
                    color: "#6b6d7e"
                }
                Timer {
                    interval: 1000
                    running: true
                    repeat: true
                    triggeredOnStart: true
                    onTriggered:parent.date = new Date()
                }
            }
        }
    }

    Text {
        anchors.bottom: parent.bottom
        anchors.left: parent.left
        text: config.currentInterfaceInfos
        font.pixelSize: 15
        color: "#6b6d7e"
        visible: remoteaccess.gpibIsChecked
    }

    Grid {
        anchors {
            top: parent.top
            left: parent.left
            leftMargin: 20
        }
        spacing: 20
        columns: 3

        AccueilButton { text: config.autoTr + qsTr("Hipot"); dstLink: "hipot_live" ; dstExtra: {"multi": false};
            onClicked: helpdisplayer.setDoc("hipot.html");/*{
                console.log("main.qml: onLanguageChanged : config.language = ", config.language, " et qsTr(Accept) = ", qsTr("Accept"));

                    popup().legalDoc(qsTr("EULA"), [qsTr("Accept")], config.language , function(nr) {
                        return true;
                    }, true);
        } */
            visible: config.model.optionHipot
        }
        AccueilButton { text: config.autoTr + qsTr("MΩ"); dstLink: "insulation_live" ;
            onClicked: helpdisplayer.setDoc("insulation.html");
            visible: config.model.optionInsulation
        }
        AccueilButton { text: config.autoTr + qsTr("Ground\nBond"); dstLink: "gndbond_live" ;
            onClicked: helpdisplayer.setDoc("gndbond.html");
            visible: config.model.optionGndBond
        }
        AccueilButton { text: config.autoTr + qsTr("Multi\nHipot"); dstLink: "hipot_live" ; dstExtra: {"multi": true};
            onClicked: helpdisplayer.setDoc("hipot.html");
            visible: config.model.optionHipot
        }

        //XSOU1500

        AccueilButton { text: config.autoTr + qsTr("MΩ"); dstLink: "megohmmeter_live" ;
            onClicked: helpdisplayer.setDoc("megohmmeter.html");
            visible: config.model.optionMOhm
        }
        AccueilButton { text: config.autoTr + qsTr("pA"); dstLink: "picoammeter_live" ;
            onClicked: helpdisplayer.setDoc("picoammeter.html");
            visible: config.model.optionPA
        }
//        AccueilButton { text: config.autoTr + qsTr("Leakage"); visible: hal.softType() === "XS"}
        AccueilButton { text: config.autoTr + qsTr("Sequence"); dstLink: "sequence"; visible: config.model.optionSequence ; onClicked:{ helpdisplayer.setDoc("sequence.html");}}
        AccueilButton { text: config.autoTr + qsTr("Calibration"); dstLink: "calibration"; onClicked: helpdisplayer.setDoc("calibration.html"); visible: false}
    }

    Timer {
        function checkspace() {
            var freespace = hal.getFreeSpacePercent();
            if (freespace < 0.2) {
                running = false;
                popup().msg(qsTr("Low memory"), qsTr("Storage is running out of space (%1% remaining)").arg(Math.round(freespace*100)), [qsTr("OK"), qsTr("Do not remember")], function(nr) {
                    if (nr !== 1) running = true;
                    return true;
                });
            }
        }
        interval: 1000 * 60 * 5
        repeat: true
        running: true
        onTriggered: checkspace()
        Component.onCompleted: checkspace()
    }

    Column {
        anchors {
            top: parent.top
            right: parent.right
            rightMargin: -10
        }

        spacing: 10

        ButtonSave {
            enabled: !remoteaccess.interfaceIsConnected
            dstLink: "save_menu"
        }
        ButtonHelp {
            //HelpDisable
//            enabled: !remoteaccess.interfaceIsConnected
            onClicked: /*helpdisplayer.setDoc("home.html")*/remoteaccess.cmdIDN
        }
        ButtonSettings {
            enabled: !remoteaccess.interfaceIsConnected
            dstLink: "settings_menu"
        }
    }

    Connections {
        target: remoteaccess
        onModeHipotChanged: {
            if (remoteaccess.modeHipot && idAccueil.visible)
                change_page("hipot_live", undefined)
        }
        onModeGndBondChanged: {
            if (remoteaccess.modeGndBond && idAccueil.visible)
                change_page("gndbond_live", undefined)
        }
        onModeInsulationChanged: {
            if (remoteaccess.modeInsulation && idAccueil.visible)
                change_page("insulation_live", undefined)
        }
        onModeMegohmmeterChanged: {
            if (remoteaccess.modeMegohmmeter && idAccueil.visible)
                change_page("megohmmeter_live", undefined)
        }
        onModePicoammeterChanged: {
            if (remoteaccess.modePicoammeter && idAccueil.visible)
                change_page("picoammeter_live", undefined)
        }
        onModeSequenceChanged: {
            if (remoteaccess.modeSequence && idAccueil.visible)
//                //console.log("change_page(sequence, undefined);");
                change_page("sequence", undefined);
        }
    }

//    onVisibleChanged: {
//        if (visible) {
//            remoteaccess.enableRemoteAccess();
//        } else {
//            remoteaccess.disableRemoteAccess();
//        }
//    }
    Component.onCompleted: {

        remoteaccess.enableRemoteAccess();

        if(watchdog.getErrorNo() === 16) {
            popup().msg(qsTr("Machine Reboot"), qsTr("Please restart the machine manually to complete last update. The machine will reboot automatically in few seconds."), [qsTr("OK")], function(nr) {
                if (nr === 0) {
                    return true;
                }
            });
        }
    }
}
