import QtQuick 2.5
import Horus 1.0
import "../HorusComponents"

Item {
    Connections {
        target: sequenceModel
        onIsPlayingChanged: lv.edited = -1;
    }

    /****************
    * Right buttons *
    ****************/
    Column {
        id: rightColumn

        anchors {
            top: parent.top
            right: parent.right
            rightMargin: -10
        }

        spacing: 10

        ButtonList {
            enabled: canChangeProgram
            onClicked: {
                var nb = 0;
                var list = sequenceLoader.filesList;
                for (nb in list) {
                    if (list[nb] == config.sequenceConfig)
                        break;
                    nb++;
                }
                popup().choose(qsTr("Load files"), list, nb, function(nr) {
                    if (nr !== undefined) {
                        changeConfigTimer.newConfig = list[nr];
                        changeConfigTimer.start();
                    }
                    return true;
                });
            }
        }
        Timer {
            id: changeConfigTimer
            property string newConfig
            interval: 200 // Let a little time for popup to close
            repeat: false
            onTriggered: config.sequenceConfig = newConfig;
        }
        ButtonAdd {
            enabled: sequenceModel && sequenceModel.count < 10000 && sequenceModel.selectionSize < 2 && canChangeParameters
            onClicked: {
                lv.edited = -1;
                popup().choose(qsTr("New step"), sequenceModel.availableSteps(), -1, function(nr) {
                    if (nr !== undefined) {
                        if (sequenceModel.selectionSize > 0)
                            sequenceModel.newStepBeforeFirstSelected(nr);
                        else
                            sequenceModel.newStep(nr, -1);
                    }
                    return true;
                });
            }
        }
//        ButtonPlay {
//            dontplay: true
//            enabled: sequenceModel && sequenceModel.selectionSize > 0 && canChangeParameters
//            onClicked: {
//                lv.edited = -1;
//                popup().msg(qsTr("Inhibition (%1 steps)").arg(sequenceModel.selectionSize), undefined, [qsTr("Skip selected steps"), qsTr("Activate selected steps")], function(nr) {
//                    if (nr !== undefined)
//                        sequenceModel.inhibSelected(nr === 0);
//                    sequenceModel.selectionClear();
//                    return true;
//                });
//            }
//        }
//        ButtonSub {
//            enabled: sequenceModel && sequenceModel.selectionSize > 0 && canChangeParameters
//            onClicked: {
//                lv.edited = -1;
//                popup().msg(qsTr("Suppression (%1 steps)").arg(sequenceModel.selectionSize), qsTr("Do you really want to delete steps ") + sequenceModel.selectionIndexes + " ?", [qsTr("Delete"), qsTr("Cancel")], function(nr) {
//                    if (nr === 0)
//                        sequenceModel.deleteSelected();
//                    sequenceModel.selectionClear();
//                    return true;
//                });
//            }
//        }
        ButtonHelp {
        }
    }

    /*********
    * Waiter *
    *********/
    Image {
        id: waiter
        anchors.centerIn: lv
        source: Qt.resolvedUrl("../page_help/wait.png")
        visible: sequenceLoader.loading

        RotationAnimator {
            target: waiter
            from: 0
            to: -360/13
            duration: 1000
            running: waiter.visible
            loops: Animation.Infinite
        }
    }

    /*******
    * View *
    *******/
    ListView {
        id: lv
        property int edited: -1
        anchors {
            top: parent.top
            bottom: parent.bottom
            left: parent.left
            leftMargin: 10
            right: rightColumn.left
            rightMargin: 10
        }

        visible: !sequenceLoader.loading

        cacheBuffer: 800
        clip: true

        currentIndex: edited
        highlightFollowsCurrentItem: true
        highlightMoveDuration: 200

        model: sequenceModel

        delegate: MouseArea {
            id: dragArea

            property bool held: false
            property int myIndex: index

            anchors {
                left: parent.left
                right: parent.right
            }
            height: content.height + 4

            drag.target: held ? content : undefined
            drag.axis: Drag.YAxis
            drag.minimumY: lv.mapToItem(page, 0, 0, 0, 0).y
            drag.maximumY: drag.minimumY + lv.height - content.height

            onPressAndHold: {
                if (canChangeParameters) {
                    held = true;
                    lv.edited = -1;
                }
            }
            onReleased: {
                held = false;
                autoscrollTimer.stop();
            }
            onCanceled: {
                held = false;
                autoscrollTimer.stop();
            }
            onClicked: {
                if (sequenceModel.isPlaying)
                    return;
                if (model.selected)
                    sequenceModel.selectionRm(index);
                else
                    sequenceModel.selectionAdd(index);
            }

            Item {
                id: content

                anchors {
                    horizontalCenter: parent.horizontalCenter
                    verticalCenter: parent.verticalCenter
                }

                width: dragArea.width;
                height: inner.height + edit.height + 4

                opacity: dragArea.held ? 0.4 : 1

                Drag.active: dragArea.held
                Drag.source: dragArea
                Drag.hotSpot.x: width / 2
                Drag.hotSpot.y: height / 2
                Drag.keys: ["horus/sequence/step"]

                onYChanged: {
                    if (dragArea.held) {
                        var sensiblezone = 5;
                        var absy = lv.mapToItem(page, 0, 0, 0, 0).y;
                        if (y <= absy + sensiblezone) {
                            autoscrollTimer.startUp();
                        } else if (y + height >= absy + lv.height - sensiblezone) {
                            autoscrollTimer.startDown();
                        } else {
                            autoscrollTimer.stop();
                        }
                    }
                }

                states: State {
                    when: dragArea.held

                    ParentChange {
                        target: content;
                        parent: page
                    }
                    AnchorChanges {
                        target: content
                        anchors {
                            horizontalCenter: undefined;
                            verticalCenter: undefined }
                    }
                }

                Rectangle {
                    anchors {
                        fill: inner
                        margins: 1
                    }
                    opacity: 0.1
                    visible: model.selected
                    radius: 14
                }
//                Rectangle {
//                    anchors {
//                        fill: inner
//                        margins: 1
//                    }
//                    opacity: 0.4
//                    color: "#fc0000"
//                    visible: !model.step.valid
//                    radius: 14
//                }

                Item {
                    id: inner

                    height: Math.max(nameBox.height, summaryBox.height)
                    width: parent.width

                    /***********
                    * Checkbox *
                    ***********/
                    Item {
                        id: checkbox
                        width: 40
                        height: parent.height
                        Rectangle {
                            anchors.centerIn: parent

                            width: 27
                            height: width
                            radius: 5

                            border.width: 3
                            border.color: "#bfbfc5"
                            color: "#2a2a2e"

                            Rectangle {
                                anchors.fill: parent
                                anchors.margins: 6
                                radius: 3
                                visible: model.selected
                            }
                        }
                    }

                    /*********
                    * Number *
                    *********/
                    Text {
                        id: indexBox
                        anchors {
                            left: checkbox.right
                            leftMargin: 10
                            verticalCenter: parent.verticalCenter
                        }
                        width: 80
                        height: 65

                        color: model.step.inhib ? "#707173" : "#b0b0b9"
                        text: (index + 1) + " /" + sequenceModel.count
                        font.bold: true
                        verticalAlignment: Text.AlignVCenter
                        horizontalAlignment: Text.AlignHCenter
                        font.pixelSize: 24
                        fontSizeMode: Text.Fit
                        wrapMode: Text.Wrap

                        MouseArea {
                            anchors.fill: parent
                            onClicked: popup().editNumber(qsTr("Change position"), index+1, 1, sequenceModel.count, "", 0, function(nr) {
                                if (nr !== undefined) {
                                    sequenceModel.move(dragArea.myIndex, nr - 1, 1);
                                }
                                return true;
                            })
                        }
                    }

                    /*******
                    * Name *
                    *******/
                    Item {
                        id: nameBox
                        anchors {
                            left: indexBox.right
                            leftMargin: 10
                            verticalCenter: parent.verticalCenter
                        }
                        width: 180
                        height: 65
                        Rectangle {
                            anchors.fill: parent
                            radius: 14
                            color: "#fff"
                            opacity: 0.1
                        }
                        Text {
                            anchors {
                                fill: parent
                                margins: 10
                            }

                            color: model.step.inhib ? "#707173" : "#fff"
                            text: model.name
                            horizontalAlignment: Text.AlignLeft
                            verticalAlignment: Text.AlignVCenter
                            font.pixelSize: 24
                            fontSizeMode: Text.Fit
                            wrapMode: Text.Wrap
                        }
                    }

                    /**********
                    * Summary *
                    **********/
                    Loader {
                        id: summaryBox
                        anchors {
                            left: nameBox.right
                            leftMargin: 10
                            right: disabledBox.left
                            verticalCenter: parent.verticalCenter
                        }
                        source: "steps/" + model.codename + "_summary.qml"
                        MouseArea {
                            anchors.fill: parent
                            enabled: canChangeParameters
                            onClicked: lv.edited = (lv.edited == index ? -1 : index)
                        }
                    }

                    /***************
                    * Disabled box *
                    ***************/
                    Item {
                        id: disabledBox
                        anchors {
                            right: parent.right
                            verticalCenter: parent.verticalCenter
                        }
                        width: model.step.inhib ? 40 : 0
                        Image {
                            anchors.centerIn: parent
                            source: "disabled.png"
                            visible: model.step.inhib
                        }
                    }
                }
                Item {
                    id: edit
                    anchors {
                        top: inner.bottom
                        left: parent.left
                        right: parent.right
                    }
                    height: editLoader.height
                    Loader {
                        id: editLoader
                        source: model.codename ? "steps/" + model.codename + "_edit.qml" : ""
                        visible: lv.edited == index
                        height: implicitHeight * visible
                        width: parent.width
                        onStatusChanged: {
                            if (status == Loader.Error) {
                                visible = false;
                            }
                        }
                    }
                }
            }

            Rectangle {
                anchors {
                    top: content.bottom
                    topMargin: -1
                    horizontalCenter: parent.horizontalCenter
                }
                height: 2
                width: parent.width * 0.95
                color: "#fff"
                opacity: 0.4
                visible: (index + 1) != sequenceModel.count
            }

            DropArea {
                anchors { fill: parent; margins: 10 }
                keys: ["horus/sequence/step"]

                onEntered: {
                    sequenceModel.move(drag.source.myIndex, dragArea.myIndex, 1)
                }
            }
        }
    }
    Timer {
        id: autoscrollTimer
        property bool _up: false
        property int _absy: lv.mapToItem(page, 0, 0, 0, 0).y;
        function startUp() {
            _up = true;
            start();
        }
        function startDown() {
            _up = false;
            start();
        }
        interval: 20
        repeat: true
        onTriggered: {
            var speed = 10;
            if (_up) {
                if (lv.contentY > speed) {
                    lv.contentY -= speed;
                } else {
                    stop();
                }
            } else {
                if (lv.contentY < lv.contentHeight - speed) {
                    lv.contentY += speed;
                    lv.returnToBounds();
                } else {
                    stop();
                }
            }
        }
    }
    VScrollBar {
        anchors {
            top: lv.top
            bottom: lv.bottom
            right: lv.left
            rightMargin: 5
        }
        scrollArea: lv
    }
}

