import QtQuick 2.0
import Horus 1.0
import "../../HorusComponents"

Item {
    width: if (parent) parent.width
    implicitHeight: 285

    /*******
    * View *
    *******/

    ListView {
        id: lv

        clip: true

        orientation: ListView.Vertical

        property int edited: -1
        anchors {
            top: parent.top
            bottom: parent.bottom
            left: parent.left
            leftMargin: 10
            right: parent.right
            rightMargin: 10
            topMargin: 10

        }

        model: sequenceModel

        delegate:
            MouseArea {
                id: dragArea
                height: content.height + 4
                anchors {
                    left: parent.left
                    right: parent.right
                }

                Item{
                    id : content

                    anchors {
                        horizontalCenter: parent.horizontalCenter
                        verticalCenter: parent.verticalCenter
                    }

                    width: dragArea.width;
                    height: inner.height + 4

                    Item {
                        id: inner

                        height: Math.max(nameBox.height, summaryBox.height)
                        width: parent.width

                        /***********
                        * Checkbox *
                        ***********/
                        Item {
                            id: checkbox
                            width: 40
                            height: parent.height
                            Rectangle {
                                anchors.centerIn: parent

                                width: 27
                                height: width
                                radius: 5

                                color: {
                                    switch (model.result) {
                                    case SequenceStep.StatusOK:
                                        return config.resultPassColor;
                                    case SequenceStep.StatusFAIL:
                                        return config.resultFailColor;
                                    case SequenceStep.StatusERROR:
                                        return config.resultErrorColor;
                                    case SequenceStep.StatusRunning:
                                        return "#fff";
                                    case SequenceStep.StatusUnknown:
                                    default:
                                        return "#2a2a2e";
                                    }
                                }
                            }
                        }

                        /*********
                        * Number *
                        *********/
                        Text {
                            id: indexBox
                            anchors {
                                left: checkbox.right
                                leftMargin: 10
                                verticalCenter: parent.verticalCenter
                            }
                            width: 80
                            height: 65

                            color: /*model.step.inhib ? "#707173" :*/ "#b0b0b9"
                            text: (index + 1) + " /" + sequenceModel.count
                            font.bold: true
                            verticalAlignment: Text.AlignVCenter
                            horizontalAlignment: Text.AlignHCenter
                            font.pixelSize: 24
                            fontSizeMode: Text.Fit
                            wrapMode: Text.Wrap
                        }

                        /*******
                        * Name *
                        *******/
                        Item {
                            id: nameBox
                            anchors {
                                left: indexBox.right
                                leftMargin: 10
                                verticalCenter: parent.verticalCenter
                            }
                            width: 180
                            height: 65
                            Rectangle {
                                anchors.fill: parent
                                radius: 14
                                color: "#fff"
                                opacity: 0.1
                            }
                            Text {
                                anchors {
                                    fill: parent
                                    margins: 10
                                }

                                color:/* model.step.inhib ? "#707173" :*/ "#fff"
                                text: model.name
                                horizontalAlignment: Text.AlignLeft
                                verticalAlignment: Text.AlignVCenter
                                font.pixelSize: 24
                                fontSizeMode: Text.Fit
                                wrapMode: Text.Wrap
                            }
                        }

                        /**********
                        * Summary *
                        **********/
                        Loader {
                            id: summaryBox
                            anchors {
                                left: nameBox.right
                                leftMargin: 10
                                right: disabledBox.left
                                verticalCenter: parent.verticalCenter
                            }
                            source: model.codename + "_summary.qml"

                        }

                        /***************
                        * Disabled box *
                        ***************/
                        Item {
                            id: disabledBox
                            anchors {
                                right: parent.right
                                verticalCenter: parent.verticalCenter
                            }
                            width: /*model.step.inhib ? 40 :*/ 0
                            Image {
                                anchors.centerIn: parent
                                source: ""
                                visible: false
                            }
                        }
                    }
                }

                Rectangle {
                    id:rectou
                    anchors {
                        top: content.bottom
                        topMargin: -1
                        horizontalCenter: parent.horizontalCenter
                    }
                    height: 2
                    width: parent.width * 0.95
                    color: "#fff"
                    opacity: 0.4
                    visible: (index + 1) !== sequenceModel.count
                }
            }
    }

    VScrollBar {
        id:scroll
        anchors {
            top: parent.top
            bottom: parent.bottom
            right: parent.left
            topMargin: 10
            rightMargin: 5
        }
        scrollArea: lv
    }

}




