import QtQuick 2.2
import Horus 1.0

Canvas {
    id: idCanvas

    property int nbPhases: 3

    property int mode: ParamGndBond.Auto

    property int currentPhase: 1
    property real phasePercent: 0

    property int valuePhase1: 0
    property int valuePhase2: 0
    property int valuePhase3: 0

    property variant stepColor: [neutralColor, neutralColor, neutralColor]
    property color neutralColor: "#e8e8f0"
    property color fadedColor: "#807c90"

    property int stepStatus1: GndBondProcessPhaseReport.NORMAL
    property int stepStatus2: GndBondProcessPhaseReport.NORMAL
    property int stepStatus3: GndBondProcessPhaseReport.NORMAL

    property int lineWidth: 8
    property int margins: 10

    property int _max: 1
    property variant _points: [0,0,0]

    antialiasing: true

    function recalcPoints() {
        var max = 0;
        max = Math.max(max, valuePhase1);
        max = Math.max(max, valuePhase2);
        max = Math.max(max, valuePhase3);
        if (!max) max = 1;
        _max = max;

        _points = [
                    0,
                    valuePhase1 / _max * (height - 2 * margins),
                    valuePhase2 / _max * (height - 2 * margins),
                    valuePhase3 / _max * (height - 2 * margins),
                ];
    }

    function drawpath(ctx, phase, percent) {
        if (percent === undefined)
            percent = 1;
        if (percent === 0)
            percent = 0.001;
        phase = phase - 1;

        var xspace = nbPhases ? (width - 2 * margins) / nbPhases : 0;
        ctx.beginPath();

        ctx.moveTo(margins + xspace * phase, height - margins - _points[phase]);
        ctx.lineTo(margins + xspace * phase + xspace * percent, height - margins - _points[phase] - ((_points[phase + 1] - _points[phase]) * percent));
    }

    function updatecolor(idx, status) {
        var c = neutralColor;
        if (status === GndBondProcessPhaseReport.FAIL){
            c = config.resultFailColor;}
        else if (status === GndBondProcessPhaseReport.ERROR){
            c = config.resultErrorColor;}
        else if (status === GndBondProcessPhaseReport.PASS){
            c = config.resultPassColor;}
        if (stepColor)
            stepColor[idx] = c;
}

    onWidthChanged: updateTimer.start()
    onHeightChanged: { recalcPoints(); updateTimer.start(); }
    onNbPhasesChanged: { recalcPoints(); updateTimer.start(); }
    onCurrentPhaseChanged: updateTimer.start()
    onPhasePercentChanged: updateTimer.start()
    onValuePhase1Changed: { recalcPoints(); updateTimer.start(); }
    onValuePhase2Changed: { recalcPoints(); updateTimer.start(); }
    onValuePhase3Changed: { recalcPoints(); updateTimer.start(); }
    onStepStatus1Changed: { updatecolor(0, stepStatus1); updateTimer.start(); }
    onStepStatus2Changed: { updatecolor(1, stepStatus2); updateTimer.start();}
    onStepStatus3Changed: { updatecolor(2, stepStatus3); updateTimer.start(); }

    onPaint: {
        var ctx = idCanvas.getContext('2d');
        ctx.reset();

        // Display background
        ctx.save();
        ctx.lineWidth = lineWidth/2;
        ctx.lineCap = "round";
        ctx.strokeStyle = fadedColor;
        for (var i = 1; i <= nbPhases; ++i) {
            drawpath(ctx, i);
            ctx.stroke();
        }
        ctx.restore();

        // Display color
        ctx.save();
        ctx.lineWidth = lineWidth;
        ctx.lineCap = "round";
        ctx.strokeStyle = fadedColor;
        ctx.shadowOffsetX = 0;
        ctx.shadowOffsetY = 0;
        //Modif LN 12/02/2020 : l'utilisation d'un shadowBlur génère un temps de 50 à 150ms pour le traçage de la courbe
        //                      temps durant lequel les autres signaux de l'appli ne sont pas pris en compte
        //                      (Ex: signal buttonStopPressed n'est pris en compte qu'après traçage de la courbe et ne permet pas
        //                      une bonne prise en compte d'un arrêt d'urgence)
//        ctx.shadowBlur = 3;

        for (var i = 1; i <= currentPhase; ++i) {
            ctx.strokeStyle = stepColor[i-1];
            ctx.shadowColor = stepColor[i-1];
            drawpath(ctx, i, (i == currentPhase) ? phasePercent : 1);
            ctx.stroke();
        }

        ctx.restore();

    }

    Component.onCompleted: {
        updatecolor(0, stepStatus1);
        updatecolor(1, stepStatus2);
        updatecolor(2, stepStatus3);
        updateTimer.start();
        //DavidTest
//        recalcPoints();
    }

    Timer {
        id: updateTimer
        interval: 50
        onTriggered: {
            parent.requestPaint();
        }
    }
}
