import QtQuick 2.2
import Horus 1.0
import "../HorusComponents"

Image {
    property var gndbondProcess
    property bool isUnderVoltage
    property bool displayBg: true

    property int editPhase: 1
    property int displayedPhaseIndex: gndbondProcess ? (gndbondProcess.currentPhase || editPhase) - 1 : -1

    property var rzMsg: null

//    source: "bg_central.png"

    source: displayBg ? "bg_central.png" : ""

    Item {
        anchors {
            top: parent.top
            bottom: parent.bottom
            left: parent.left
        }
        width: 359

        /********************
        * Graph zone - auto *
        ********************/
        Item {
            id: graphzone_auto

            height: graph_auto.height + 60 + 30
            visible: gndbondProcess && gndbondProcess.parameters ? (gndbondProcess.parameters.mode.value === ParamGndBond.Auto) : false

            anchors {
                left: parent.left
                right: parent.right
                bottom: parent.bottom
            }

            Item {
                id: graph_auto

                anchors {
                    left: parent.left
                    right: parent.right
                    bottom: parent.bottom
                    margins: 14
                    bottomMargin: 60
                }

                height: 150

                Rectangle {
                    anchors.fill: parent
                    anchors.rightMargin: 2
                    radius: 14
                    color: "#2a2939"
                }

                Button {
                    anchors {
                        top: parent.bottom
                        topMargin: 4
                        right: parent.right
                    }
                    srcImage: "next.png"
                    rectVisible: false
                    width: 32
                    opacity: (!isUnderVoltage && editPhase < 3 ? 1 : 0)
                    onClicked: editPhase = Math.min(editPhase + 1, 3)
                    Behavior on opacity { NumberAnimation { duration: 100 } }
                }

                Button {
                    anchors {
                        top: parent.bottom
                        topMargin: 4
                        left: parent.left
                    }
                    srcImage: "prev.png"
                    rectVisible: false
                    width: 32
                    opacity: (!isUnderVoltage && editPhase > 1 ? 1 : 0)
                    onClicked: editPhase = Math.max(editPhase - 1, 1)
                    Behavior on opacity { NumberAnimation { duration: 100 } }
                }

                Rectangle {
                    color: "#323140"
                    radius: 14
                    property real w: (parent.width - 20) / /*(gndbondProcess && gndbondProcess.parameters ? 3 : 3)*/3
                    x: displayedPhaseIndex * w
                    width: w + 20
                    height: parent.height

                    Behavior on x {
                        enabled: displayedPhaseIndex >= 0
                        NumberAnimation {
                            duration: 800
                            easing.type: Easing.OutExpo
                        }
                    }

                    Button { // Duration
                        id : duration_btn
                        property variant param: gndbondProcess && gndbondProcess.parameters && displayedPhaseIndex >= 0 && displayedPhaseIndex < 3? gndbondProcess.parameters.phases[displayedPhaseIndex].time : {value: 0}

                        anchors {
                            top: parent.bottom
                            topMargin: 14
                            horizontalCenter: parent.horizontalCenter
                        }

                        //DavidTest
                        width: 70 /*105*/
                        height: 30
                        text: /*"Press Stop"*/{
                            var nb = param.value * (1 - (gndbondProcess && gndbondProcess.parameters ? gndbondProcess.stepPercent : 0));
                            if (!isUnderVoltage) nb = param.value;
                            return config.autoTr + qsTr("%1 s").arg(Number(nb).toFixed(1));
                        }
                        textColor: enabled ? (pressed ? UiConfig.colors.fg_pressed : UiConfig.colors.fg_active) : "#fff"
                        font.pixelSize: 16
                        enabled: !isUnderVoltage && canChangeParameters && !remoteaccess.interfaceIsConnected

                        helpText: config.autoTr + qsTr("To be defined.")

                        onClicked: {rzMsg = popup().editParam(param); disableButtons();}

                        visible: true

                        Connections {
                            target: gndbondProcess.parameters.phases[1].time
                            onValueChanged: {
                                // Si la phase est une phase de maintien et qu'on la paramète à 0s alors une message d'erreur est affiché
                                if (gndbondProcess.parameters.phases[1].time.value === 0) {
                                    rzMsg = popup().msg(qsTr("Value error"), qsTr("Holding phase can't last 0s"), [qsTr("Ok")]);
                                    disableButtons();
                                    gndbondProcess.parameters.phases[1].time.value = 0.1;
                                }
                            }
                        }
                    }

                    Button { // Finished
                        id :end_btn
                        anchors {
                            top: parent.bottom
                            topMargin: 14
                            horizontalCenter: parent.horizontalCenter
                        }
                        width: 105
                        height: 30
                        text: ""
                        textColor: "#fff"
                        enabled: false

                        visible: false

                        SequentialAnimation {
                            id: anim
                            running: end_btn.visible
                            loops: Animation.Infinite
                            PropertyAnimation { target: end_btn; property: "text"; to: "Press Stop"; duration: 500 }
                            PropertyAnimation { target: end_btn; property: "text"; to: ""; duration: 500 }
                        }
                    }
                }

                Repeater {
                    model: gndbondProcess && gndbondProcess.parameters ? 3 : 0
                    delegate: MouseArea {
                        property real w: (graph_auto.width - 20) / (gndbondProcess && gndbondProcess.parameters ? 3 : 3)
                        anchors.bottom: graph_auto.bottom
                        x: index * w + 11
                        width: w
                        height: graph_auto.height + 35
                        onClicked: editPhase = index + 1

                        Text {
                            anchors {
                                top: parent.bottom
                                topMargin: -30
                                left: parent.left
                                right: parent.right
                            }
                            text: index + 1
                            color: index == displayedPhaseIndex ? "#e8e8f0" : "#807c90"
                            horizontalAlignment: Text.AlignHCenter
                            Behavior on color { ColorAnimation {} }
                        }

                        Image {
                            anchors {
                                bottom: parent.bottom
                                bottomMargin: 2
                                right: parent.right
                            }
                            source: "separator.png"
                            visible: index != (gndbondProcess ? 3 : 3) - 1
                        }
                    }
                }

                GndBondGraph {
                    anchors.fill: parent

                    mode: gndbondProcess.parameters.mode.value

                    nbPhases: 3
                    valuePhase1: gndbondProcess && gndbondProcess.parameters.current ? gndbondProcess.parameters.current.value : 0
                    valuePhase2: gndbondProcess && gndbondProcess.parameters.current ? gndbondProcess.parameters.current.value : 0
                    valuePhase3:  0

                    //DavidTest
                    stepStatus1: gndbondProcess ? gndbondProcess.phases[0].status : GndBondProcess.OFF
                    stepStatus2: gndbondProcess ? gndbondProcess.phases[1].status : GndBondProcess.OFF
                    stepStatus3: gndbondProcess ? gndbondProcess.phases[2].status : GndBondProcess.OFF
//                    stepStatus1:  GndBondProcess.PASS
//                    stepStatus2:  GndBondProcess.PASS
//                    stepStatus3:  GndBondProcess.PASS

                    phasePercent: gndbondProcess ? gndbondProcess.stepPercent : 0 /*1*/
                    currentPhase: gndbondProcess ? gndbondProcess.currentPhase : -1 /*3*/
                }
            }
        }

        /*****************
        * Result message *
        *****************/
        TestStatus {
            id: testStatus
            anchors {
                top: parent.top
                left: parent.left
                right: parent.right
            }
            height: 70
            //DavidTest
            state: gndbondProcess ? gndbondProcess.status : "" /*GndBondProcess.PASS*/
            errorText: gndbondProcess ? gndbondProcess.errorText : ""
        }
    }

    /*******************
    * Live report zone *
    *******************/
    MeasureCarousselGndBond {
        id: livereport_internal

        anchors {
            top: parent.top
            bottom: parent.bottom
            left: parent.left
            leftMargin: 359
            right: parent.right
        }

        //DavidTest
        u: gndbondProcess ? (gndbondProcess.voltageText ? gndbondProcess.voltageText : "") : ""
        r: gndbondProcess ? (gndbondProcess.resistanceText ? gndbondProcess.resistanceText : "") : ""
        i: gndbondProcess ? (gndbondProcess.currentText ? gndbondProcess.currentText : "") : ""

        uunit: gndbondProcess ? (gndbondProcess.voltageUnit ? gndbondProcess.voltageUnit : "") : ""
        runit: gndbondProcess ? (gndbondProcess.resistanceUnit ? gndbondProcess.resistanceUnit : "") : ""
        iunit: gndbondProcess ? (gndbondProcess.currentUnit ? gndbondProcess.currentUnit : "") : ""

//        u: "3,19"
//        r: "99,8"
//        i: "0,0"

//        uunit: "V"
//        runit: "mΩ"
//        iunit: "A"

//        ulast: gndbondProcess ? (gndbondProcess.voltageMaxText ? gndbondProcess.voltageMaxText : "") : ""
//        rlast: gndbondProcess ? (gndbondProcess.resistanceMaxText ? gndbondProcess.resistanceMaxText : "") : ""
//        ilast: gndbondProcess ? (gndbondProcess.currentMaxText ? gndbondProcess.currentMaxText : "") : ""

        ulast: ""
        rlast: gndbondProcess ? gndbondProcess.errorText : ""
        ilast: gndbondProcess ? gndbondProcess.errorText : ""

        ulength: gndbondProcess ? (gndbondProcess.voltageTextLength ? gndbondProcess.voltageTextLength :3) :3
        rlength: gndbondProcess ? (gndbondProcess.resistanceTextLength ? gndbondProcess.resistanceTextLength :3) :3
        ilength: gndbondProcess ? (gndbondProcess.currentTextLength ? gndbondProcess.currentTextLength :3) :3
    }

    Connections {
        target: gndbondProcess
        onStatusChanged : {
            if (end_btn.visible || !duration_btn.visible) {
                end_btn.visible = false;
                duration_btn.visible = true;
            }
        }
        onFinished : {
            if(gndbondProcess.status !== GndBondProcess.OFF) {
                duration_btn.visible = false;
                end_btn.visible = true;
            }
        }
    }

    function disableButtons(){
        hal.setStartLight(false);
        hal.setStopLight(false);
    }
}
