import QtQuick 2.2
import Horus 1.0
import "../HorusComponents"

Item {
    property bool canChangeParameters: config.acl.value <= ParamGlobal.ADMINISTRATOR
    property bool canChangeProgram: config.acl.value <= ParamGlobal.TECHNICIAN

    ReportZone {
        id: reportZone
        anchors {
            top: parent.top
            left: parent.left
            leftMargin: 5
        }
        gndbondProcess: process
        isUnderVoltage: page.isUnderVoltage
    }

    /*********************************
    * Right bar (params, list, help) *
    *********************************/
    RightBar {
        id: rightbar
        anchors {
            top: parent.top
            right: parent.right
            rightMargin: -10
        }
        //HelpDisable
        enabled_help: /*!isUnderVoltage && !remoteaccess.interfaceIsConnected*/false
        enabled_list: !isUnderVoltage && canChangeProgram && !remoteaccess.interfaceIsConnected
        enabled_settings: !isUnderVoltage && canChangeParameters && !remoteaccess.interfaceIsConnected
        stopMessage_visible: isUnderVoltage && process.finished

        startStopRelated: true
    }

    /*****************
    * Parameters row *
    *****************/
    Row {
        id: bottomrow

        anchors {
            horizontalCenter: parent.horizontalCenter
            bottom: parent.bottom
            bottomMargin: -10
        }

        spacing: 14

        ErrorButton { // Time
            property variant param: gndbond.mode

            textTitle: config.autoTr + qsTr("Time")
            //DavidTest
            text: /*"0.0s"*/ {
                if (param.value === ParamGndBond.Permanent) {
                    return param.text;
                }
                else {
                    var i, remaining = 0;
                    if (process.currentPhase > 0)
                        remaining = gndbond ? (gndbond.phases[process.currentPhase-1].time.value * (1 - process.stepPercent)) : 0;
                    for (i = process.currentPhase || 1; i < 3; ++i)
                        remaining += gndbond.phases[i].time.value
                    return config.autoTr + qsTr("%1 s").arg(Number(remaining).toFixed(1));
                }
            }

            startRelated: true

            color: param.value === ParamGndBond.Permanent ? UiConfig.colors.fg_inactive : "#fff"
            enabled: false
            visible: isUnderVoltage
        }

        ErrorButton { // Time
            property variant param: gndbond.mode

            //DavidTest
            textTitle: config.autoTr + qsTr("Time")
            text: param.text /*"5.0 s"*/
            enabled: canChangeParameters && param.modifiable && !remoteaccess.interfaceIsConnected
            visible: !isUnderVoltage
            helpText:qsTr("This button opens a list of the modes available for the ground bond function")

            onClicked: {msg = popup().editParam(param);disableButtons();}
        }

        ErrorButton { // Current
            id: param_current
            property variant param: gndbond.current

            textTitle: gndbond.currentType.text
            text: param.text

            enabled: !isUnderVoltage && canChangeParameters && param.modifiable && !remoteaccess.interfaceIsConnected

            helpText:qsTr("This button opens a keypad to edit the current value of your ground bond test")

            onClicked: {msg = popup().editParam(param); disableButtons();}
        }

        ErrorButton { // Low Limit
            id: param_lowlimit

            property variant param: gndbond.lowLimit

            textTitle: config.autoTr + qsTr("Low Limit")
            text: param.text
            enabled: !isUnderVoltage && canChangeParameters && param.modifiable && !remoteaccess.interfaceIsConnected

            helpText:qsTr("This button opens a keypad to edit the low limit value and unit of your ground bond test")

            startRelated: true

            onClicked: {msg = popup().editParam(param); disableButtons();}

//            Connections {
//                target: gndbond.highLimit
//                onUnitChanged: {
//                    if (gndbond.lowLimit.unit !== gndbond.highLimit.unit) {
//                        msg = popup().editParam(gndbond.lowLimit);
//                        msg = popup().msg(qsTr("Unit error"), qsTr("High limit unit and low limit units must be the same"), [qsTr("Ok")]);
//                        disableButtons();
//                    }
//                }
//            }

            state: {
                var st = "";
                for (var i = 0; i < 3; ++i) {
                    if (process.phases[i].lowLimitStatus === GndBondProcessPhaseReport.ERROR) st = "error";
                    else if (process.phases[i].lowLimitStatus === GndBondProcessPhaseReport.FAIL) st = "fail";
                }
                return st;
            }
        }

        ErrorButton { // High Limit
            id: param_highlimit
            property variant param: gndbond.highLimit


            textTitle: config.autoTr + qsTr("High Limit")
            text: param.text
            enabled: !isUnderVoltage && canChangeParameters && param.modifiable && !remoteaccess.interfaceIsConnected

            helpText:qsTr("This button opens a keypad to edit the high limit value and unit of your ground bond test")

            startRelated: true

            onClicked: {msg = popup().editParam(param); disableButtons();}
//            Connections {
//                target: gndbond.lowLimit
//                onUnitChanged: {
//                    console.log("lowlimit onUnitChanged");
//                    if (gndbond.lowLimit.unit !== gndbond.highLimit.unit) {
//                        msg = popup().editParam(gndbond.highLimit);
//                        msg = popup().msg(qsTr("Unit error"), qsTr("High limit unit and low limit units must be the same"), [qsTr("Ok")]);
//                    }
//                }
//            }

            state: {
                //DavidTest
                var st = "";
                for (var i = 0; i < 3; ++i) {
                    if (process.phases[i].highLimitStatus === GndBondProcessPhaseReport.ERROR) st = "error";
                    else if (process.phases[i].highLimitStatus === GndBondProcessPhaseReport.FAIL) st = "fail";
                }
                return st;
//                return "";
            }
        }

        ErrorButton { // Zero
            id: param_zero
            property variant param: gndbond.zero

            textTitle: config.autoTr + qsTr("Zero")
            text: param.text

//            coloriage: param.value === 1 ? UiConfig.colors.bg_pressed : UiConfig.colors.bg_active

            // Contrairement aux autres paramètres, le tarage est lui réalisable pendant une mesure
            enabled: canChangeParameters && param.modifiable

            helpText:qsTr("This button indicate wheter the wires are tared or not")

            rectColor: (param.value === 1 ? "#fff" /*UiConfig.colors.bg_pressed*/ : UiConfig.colors.bg_active)
            rectBorder.color: (param.value === 1 ? UiConfig.colors.border : "transparent")
            rectBorder.width: (param.value === 1 ? 1 : 3)
            rectShown: (param.value === 1 ? true:false)
            titleColor: (param.value === 1 ? "#272737" : "#fff")
            blackFlag: (param.value === 1 ? true : false)

            onClicked: param.value === 1 ? param.setValue(0) : param.setValue(1);


            Behavior on rectColor { ColorAnimation {} }

            Component.onDestruction: {
                param.setValue(0);
            }
        }
    }

    Connections {
        target: msg
        onClose: {
            //Dans le cas d'une double popup la condition popup.isOpened pose problème, on la contourne ici sachant qu'elle n'est qu'une sécurité
            hal.setStartLight(!remoteaccess.interfaceIsConnected && hal.safetyLoop /*&& !popup().isOpened()*/);
            hal.setStopLight(false);
        }
    }

    Connections {
        //Permet de ne pas rallumer le bouton start lors de l'ouverture de la pop up d'erreur lié au temps de maintien grace au booleen visible de cette page
        target: reportZone.rzMsg
        onClose: {
            //Dans le cas d'une double popup la condition popup.isOpened pose problème, on la contourne ici sachant qu'elle n'est qu'une sécurité
            hal.setStartLight(!remoteaccess.interfaceIsConnected && hal.safetyLoop && visible);
            hal.setStopLight(false);
        }
    }

    function disableButtons(){
        hal.setStartLight(false);
        hal.setStopLight(false);
    }
}
