import QtQuick 2.0
import Horus 1.0
import "../HorusComponents"

Page {
    id: page
    property bool isUnderVoltage: process.running

    title: config.autoTr + qsTr("GndBond")
    navigationBtnEnable: !isUnderVoltage
    headerButton {
        text: gndbondLoader.filename
        enabled: !isUnderVoltage && (config.acl.value <= ParamGlobal.ADMINISTRATOR) && !remoteaccess.interfaceIsConnected
        startRelated: true
        onClicked: {
            msg = popup().editText(
                        qsTr("Filename"),
                        gndbondLoader.filename,
                        function (name) {
                            if (name !== undefined) {
                                if (gndbondLoader.exists(name)) {
                                    msg = popup().msg(qsTr("Warning"), qsTr("There is already a configuration named \"%1\". Do you want to overwrite it ?").arg(gndbondLoader.data.sanitizeName(name)), [qsTr("Overwrite"), qsTr("Cancel")], function(nr) {
                                        if (nr === 0) {
                                            gndbondLoader.data.copyToStorage(name);
                                            config.gndbondConfig = name;
                                            return true;
                                        } else if (nr === 1) {
                                            return true;
                                        }
                                        return false;
                                    }, /* replace: */ true);
                                    return false;
                                }
                                else {
                                    msg = popup().msg(qsTr("Rename"), qsTr("Do you want to rename \"%1\" or do you want to duplicate \"%1\" and rename it ?").arg(config.gndbondConfig), [qsTr("Rename"), qsTr("Duplicate & Rename")], function(nr) {
                                        if (nr === 1) {
                                            gndbondLoader.data.copyToStorage(name);
                                            config.gndbondConfig = name;
                                            return true;
                                        } else if (nr === 0) {
                                            gndbondLoader.data.copyToStorage(name);
                                            gndbondLoader.remove(config.gndbondConfig);
                                            config.gndbondConfig = name;
                                            return true;
                                        }
                                        return false;
                                    }, /* replace: */ true)
                                }
                            }
                            return (true);
                        }, false, "^[a-zA-Z0-9_-]{1,100}$");
            disableButtons();
        }
    }

    Connections {
        target: remoteaccess
        onModeGndBondChanged: {
            if (!remoteaccess.modeGndBond && page.visible)
                back_page();
        }
        onFunctionsDeactivated: {
            if (!remoteaccess.modeGndBond && page.visible)
                back_page();
        }
    }

    property var process: remoteaccess.modeGndBond ? remoteaccess.gndbondProcess : processQml
    GndBondProcess{
        id: processQml
        parameters: gndbondLoader.data
        canbusGndBond: canbus.gndbond
        halObj: hal
        configObj: config
        inhibit: !page.visible || popup().isOpened() || remoteaccess.modeGndBond
        property bool startEnable: false

        onCommunicationError: {
            if(!process.finished) {
                page.msg = popup().msg(qsTr("Communication Failed"), qsTr("GndBond function stopped responding. Please restart the machine for safety.\nContact our service if it happens again."), [qsTr("Ok")], function(nr) {
                    if (nr === 0) {
                        return true;
                    }
                });
            }
            else {
                page.msg = popup().msg(qsTr("Start Failed"), qsTr("The test failed to start. Try again to launch the test."), [qsTr("Ok")], function(nr) {
                    if (nr === 0) {
                        return true;
                    }
                });
            }

            disableButtons();
        }

        onInterrupted: {
            measure_stop();
            page.msg = popup().msg(qsTr("Test aborted"), qsTr("The test has been aborted"), [qsTr("Ok")], function(nr) {
                if (nr === 0) return true;
                else return false;
            });

        }

        Connections {
            target: hal
            onStartButtonPressed: {
                if (!remoteaccess.interfaceIsConnected && !process.inhibit) {
                    if (!hal.safetyLoop) {
                        securityLoopWatcher.open();
                    }
                    else if (!process.readyToStart() && page.msg == null && process.invalidParameters() !== "") {
                        page.msg = popup().msg(qsTr("Test invalid"), qsTr("Some parameters are invalid:\n%1").arg(process.invalidParameters()), [qsTr("Ok")], function(nr) {
                            if (nr === 0) {
                                return true;
                            }
                        });
                        disableButtons();
                    }
                    else {
                        timer.running = true;
                    }


                    if (config.acl.value === ParamGlobal.SERVICE) {
                        process.close_HoldingLoop();
                    }
                }
            }
            onStopButtonPressed: {
                console.log("page_gnd_live: process.running = ", process.running, " !process.finished = ",!process.finished);
                if (process.running && !process.finished) {
                    process.cmd_Discharge();
//                    page.msg = popup().msg(qsTr("Test aborted"), qsTr("The test has been aborted"), [qsTr("Ok")], function(nr) {
//                        if (nr === 0) return true;
//                        else return false;
//                    });
                }
                else {
                    process.measure_stop();
                    if(page.msg) {
                        page.msg.close();
                    }
                }
                hal.setStartLight(!process.inhibit && !remoteaccess.interfaceIsConnected && hal.safetyLoop);
                hal.setStopLight(false);
            }
            onStartButtonReleased: {
                timer.running = false;
                if(process.startEnable || !hal.safetyLoop){
                    process.startEnable = false;
                }
                else if (!process.running && page.msg == null && !remoteaccess.interfaceIsConnected && config.acl.value !== ParamGlobal.SERVICE && !process.inhibit) {
                    page.msg = popup().tempo(qsTr("Launch a test"), qsTr("Press start for 1s"), 2000);
                    disableButtons();
                }
            }
        }

        Timer {
            id:timer
            interval: 1000
            running: false
            repeat: false
            onTriggered: {
                process.startEnable = true;
                process.close_HoldingLoop();
            }
        }
    }

    SecurityLoopWatcher {
        id: securityLoopWatcher
        process: remoteaccess.modeMegohmmeter ? remoteaccess.megohmmeterProcess : processQml
    }

    Loader {
        property variant gndbond : gndbondLoader.data
        anchors.fill: parent

        focus: true

        source: "auto.qml"

        ParamGndBondLoader {
            id: gndbondLoader
            filename: config.gndbondConfig
        }
    }

    Component.onCompleted: {
        paramupdater.gndbond.enable = true;
        hal.setStartLight(!remoteaccess.interfaceIsConnected && hal.safetyLoop && !process.inhibit);
        hal.setStopLight(false);
    }
    Component.onDestruction:{
        paramupdater.gndbond.enable = false;
        hal.setStartLight(false);
        hal.setStopLight(false);
    }

    onVisibleChanged: {
        hal.setStartLight(visible && !remoteaccess.interfaceIsConnected && hal.safetyLoop);
        hal.setStopLight(isUnderVoltage);
    }

    onIsUnderVoltageChanged: {
        if(isUnderVoltage) remoteaccess.disableRemoteAccess();
        else remoteaccess.enableRemoteAccess();
    }

    function disableButtons(){
        hal.setStartLight(false);
        hal.setStopLight(false);
    }
}
