import QtQuick 2.5
import Horus 1.0
import "../HorusComponents"

Item {
    property alias pdf: pdfdec
    property int page: 1 // Currently displayed page
    property bool showNavig: true // Display embedded navigation buttons
    signal loadError() // Signal loading errors

    id: pdfZone
    clip: true
    PdfDecoder {
        id: pdfdec
        onLoadedChanged: if (!loaded) loadError()
    }
    Item {
        id: photoFrame
        anchors.horizontalCenter: scale * width <= pdfZone.width ? parent.horizontalCenter : undefined
        anchors.verticalCenter: scale * height <= pdfZone.height ? parent.verticalCenter : undefined
        x: dragArea.drag.maximumX
        y: dragArea.drag.maximumY
        width: image.width
        height: image.height
        scale: pdfZone.width / (image.sourceSize.width + 200) //Le "+200" permet d'afficher l'image avec un zoom moins grand au début pour vir l'ensemble de la photo mais laisser à l'utilisateur la possibilité de zoomer plus (ajouter lors du dev de la séquence)
        Image {
            id: image
            anchors.centerIn: parent
            source: "image://PdfDecoder/" + pdfdec.referenceName + "/" + page
            antialiasing: true
            asynchronous: true
        }
        PinchArea {
            id: pinchArea
            anchors.fill: parent
            pinch.target: photoFrame
            pinch.minimumRotation: 0
            pinch.maximumRotation: 0
            pinch.minimumScale: 0.1
            pinch.maximumScale: 10
            pinch.dragAxis: Pinch.XAndYAxis
            pinch.minimumX: (photoFrame.scale - 1) * photoFrame.width / 2 - photoFrame.scale * photoFrame.width + pdfZone.width
            pinch.maximumX: (photoFrame.scale - 1) * photoFrame.width / 2
            pinch.minimumY: (photoFrame.scale - 1) * photoFrame.height / 2 - photoFrame.scale * photoFrame.height + pdfZone.height
            pinch.maximumY: (photoFrame.scale - 1) * photoFrame.height / 2

            MouseArea {
                id: dragArea
                anchors.fill: parent
                drag.target: photoFrame
                drag.minimumX: parent.pinch.minimumX
                drag.maximumX: parent.pinch.maximumX
                drag.minimumY: parent.pinch.minimumY
                drag.maximumY: parent.pinch.maximumY
//                scrollGestureEnabled: false

                onDoubleClicked: {
                    photoFrame.scale = pdfZone.width / image.sourceSize.width
                    photoFrame.x = drag.maximumX
                    photoFrame.y = drag.maximumY
                }
            }
        }
    }

    /*********
    * Waiter *
    *********/
    Image {
        id: waiter
        anchors.centerIn: pdfZone
        source: "wait.png"
        visible: image.status == Image.Loading

        RotationAnimator {
            target: waiter
            from: 0
            to: -360/13
            duration: 1000
            running: waiter.visible
            loops: Animation.Infinite
        }
    }

    /*************
    * Navigation *
    *************/
    Row {
        id: navig
        x: 10
        y: 10
        spacing: 10
        visible: showNavig && opacity > 0
        state: (image.status == Image.Loading || dragArea.drag.active || pinchArea.pinch.active) ? "open" : ""

        Button {
            enabled: (page > 1)
            srcImage: "../HorusComponents/ButtonPrev_prev.png"
            onClicked: page -= 1
        }

        Button {
            anchors.verticalCenter: parent.verticalCenter
            enabled: pdfdec.nbPages
            width: pagebtn.width + 20

            onClicked: popup().editNumber(qsTr("Change page"), page, 1, pdfdec.nbPages, "", 0, function(nr) {
                if (nr !== undefined)
                    page = nr;
                return true;
            });

            Text {
                id: pagebtn
                anchors.centerIn: parent
                text: pdfdec.nbPages ? page + "/" + pdfdec.nbPages : "Error"
                color: "#ffffff"
                font.pixelSize: 18
            }
        }

        Button {
            enabled: (page < pdfdec.nbPages)
            srcImage: "../HorusComponents/ButtonNext_next.png"
            onClicked: page += 1
        }

        transitions: [
            Transition {
                from: "open"
                to: ""
                SequentialAnimation {
                    PropertyAction {
                        target: navig
                        property: "opacity"
                        value: 1
                    }
                    PauseAnimation {
                        duration: 2000
                    }
                    NumberAnimation {
                        target: navig
                        property: "opacity"
                        duration: 200
                        easing.type: Easing.InOutQuad
                        to: 0
                    }
                }
            },
            Transition {
                from: ""
                to: "open"
                NumberAnimation {
                    target: navig
                    property: "opacity"
                    duration: 200
                    alwaysRunToEnd: true
                    easing.type: Easing.InOutQuad
                    to: 1
                }
            }
        ]
    }
}
