import QtQuick 2.2
import Horus 1.0
import "../HorusComponents"

Image {
    property var hipotProcess
    property bool isUnderVoltage
    property bool displayBg: true

    property int editPhase: 1
    property int displayedPhaseIndex: hipotProcess ? (hipotProcess.currentPhase || Math.min(editPhase, hipotProcess.parameters.nbPhases)) - 1 : -1

    property var rzMsg: null

    source: displayBg ? "bg_central.png" : ""
//    width: 676
//    height: 323

    Item {
        anchors {
            top: parent.top
            bottom: parent.bottom
            left: parent.left
        }
        width: 359

        /********************
        * Graph zone - auto *
        ********************/
        Item {
            id: graphzone_auto

            height: graph_auto.height + 60 + 30
            visible: hipotProcess && hipotProcess.parameters ? (hipotProcess.parameters.mode.value === ParamHipot.Auto) : false

            anchors {
                left: parent.left
                right: parent.right
                bottom: parent.bottom
            }

            Item {
                id: graph_auto

                anchors {
                    left: parent.left
                    right: parent.right
                    bottom: parent.bottom
                    margins: 14
                    bottomMargin: 60
                }

                height: 150

                Rectangle {
                    anchors.fill: parent
                    anchors.rightMargin: 2
                    radius: 14
                    color: "#2a2939"
                }

                Button {
                    anchors {
                        top: parent.bottom
                        topMargin: 4
                        right: parent.right
                    }
                    srcImage: "next.png"
                    rectVisible: false
                    width: 32
                    opacity: (!isUnderVoltage && editPhase < hipotProcess.parameters.nbPhases ? 1 : 0)
                    onClicked: editPhase = Math.min(editPhase + 1, hipotProcess.parameters.nbPhases)
                    Behavior on opacity { NumberAnimation { duration: 100 } }
                }

                Button {
                    anchors {
                        top: parent.bottom
                        topMargin: 4
                        left: parent.left
                    }
                    srcImage: "prev.png"
                    rectVisible: false
                    width: 32
                    opacity: (!isUnderVoltage && editPhase > 1 ? 1 : 0)
                    onClicked: editPhase = Math.max(editPhase - 1, 1)
                    Behavior on opacity { NumberAnimation { duration: 100 } }
                }

                Rectangle {
                    color: "#323140"
                    radius: 14
                    property real w: (parent.width - 20) / (hipotProcess && hipotProcess.parameters ? hipotProcess.parameters.nbPhases : 3)
                    x: displayedPhaseIndex * w
                    width: w + 20
                    height: parent.height

                    Behavior on x {
                        enabled: displayedPhaseIndex >= 0
                        NumberAnimation {
                            duration: 800
                            easing.type: Easing.OutExpo
                        }
                    }

                    Button { // Duration
                        property variant param: hipotProcess && hipotProcess.parameters && displayedPhaseIndex >= 0 ? hipotProcess.parameters.phases[displayedPhaseIndex].time : {value: 0}

                        anchors {
                            top: parent.bottom
                            topMargin: 14
                            horizontalCenter: parent.horizontalCenter
                        }

                        //DavidTest
                        width: 70 /*105*/
                        height: 30                        
                        text: /*"Press Stop"*/ {
                            var nb = param.value * (1 - (hipotProcess && hipotProcess.parameters ? hipotProcess.stepPercent : 0));
                            if (!isUnderVoltage) nb = param.value;
                            return config.autoTr + qsTr("%1 s").arg(Number(nb).toFixed(1));
                        }
                        textColor: enabled ? (pressed ? UiConfig.colors.fg_pressed : UiConfig.colors.fg_active) : "#fff"
                        font.pixelSize: 16
                        enabled: !isUnderVoltage && canChangeParameters && !remoteaccess.interfaceIsConnected

                        helpText: config.autoTr + qsTr("To be defined.")

                        onClicked: {rzMsg = popup().editParam(param); disableButtons();}

                        Connections {
                            target: hipotProcess.parameters.phases[displayedPhaseIndex].time
                            onValueChanged: {
                                // Si la phase est une phase de maintien et qu'on la paramète à 0s alors une message d'erreur est affiché
                                if (displayedPhaseIndex !== 0 && (hipotProcess.parameters.phases[displayedPhaseIndex].voltage.value - hipotProcess.parameters.phases[displayedPhaseIndex-1].voltage.value) === 0 && hipotProcess.parameters.phases[displayedPhaseIndex].time.value === 0) {
                                    rzMsg = popup().msg(qsTr("Value error"), qsTr("Holding phase can't last 0s"), [qsTr("Ok")]);
                                    disableButtons();
                                    hipotProcess.parameters.phases[displayedPhaseIndex].time.value = 0.1;
                                }
                            }
                        }

//                        visible: hipotProcess ? (hipotProcess.finished ? false: true) : true
                    }
                    Button { // Finished
                        id :end_btn
                        anchors {
                            top: parent.bottom
                            topMargin: 14
                            horizontalCenter: parent.horizontalCenter
                        }
                        width: 105
                        height: 30
                        text: ""
                        textColor: "#fff"
                        enabled: false

                        visible: false

                        SequentialAnimation {
                            id: anim
                            running: end_btn.visible
                            loops: Animation.Infinite
                            PropertyAnimation { target: end_btn; property: "text"; to: "Press Stop"; duration: 500 }
                            PropertyAnimation { target: end_btn; property: "text"; to: ""; duration: 500 }
                        }
                    }
                }

                Repeater {
                    model: hipotProcess && hipotProcess.parameters ? hipotProcess.parameters.nbPhases : 0
                    delegate: MouseArea {
                        property real w: (graph_auto.width - 20) / (hipotProcess && hipotProcess.parameters ? hipotProcess.parameters.nbPhases : 3)
                        anchors.bottom: graph_auto.bottom
                        x: index * w + 11
                        width: w
                        height: graph_auto.height + 35
                        onClicked: editPhase = index + 1

                        Text {
                            anchors {
                                top: parent.bottom
                                topMargin: -30
                                left: parent.left
                                right: parent.right
                            }
                            text: index + 1
                            color: index == displayedPhaseIndex ? "#e8e8f0" : "#807c90"
                            horizontalAlignment: Text.AlignHCenter
                            Behavior on color { ColorAnimation {} }
                        }

                        Image {
                            anchors {
                                bottom: parent.bottom
                                bottomMargin: 2
                                right: parent.right
                            }
                            source: "separator.png"
                            visible: index != (hipotProcess ? hipotProcess.parameters.nbPhases : 3) - 1
                        }
                    }
                }

                HipotGraph {
                    id:autoGraph
                    anchors.fill: parent

                    mode: hipotProcess.parameters.mode.value
                    nbPhases: hipotProcess && hipotProcess.parameters ? hipotProcess.parameters.nbPhases : 3
                    valuePhase1: hipotProcess && hipotProcess.parameters ? hipotProcess.parameters.phases[0].voltage.value : 0
                    valuePhase2: hipotProcess && hipotProcess.parameters ? hipotProcess.parameters.phases[1].voltage.value : 0
                    valuePhase3: hipotProcess && hipotProcess.parameters ? hipotProcess.parameters.phases[2].voltage.value : 0
                    valuePhase4: hipotProcess && hipotProcess.parameters ? hipotProcess.parameters.phases[3].voltage.value : 0
                    valuePhase5: hipotProcess && hipotProcess.parameters ? hipotProcess.parameters.phases[4].voltage.value : 0
                    valuePhase6: hipotProcess && hipotProcess.parameters ? hipotProcess.parameters.phases[5].voltage.value : 0
                    valuePhase7: hipotProcess && hipotProcess.parameters ? hipotProcess.parameters.phases[6].voltage.value : 0

                    //DavidTest
                    stepStatus1: graphzone_auto.visible ? (hipotProcess ? hipotProcess.phases[0].status : HipotProcess.OFF) : HipotProcess.OFF
                    stepStatus2: graphzone_auto.visible ? (hipotProcess ? hipotProcess.phases[1].status : HipotProcess.OFF) : HipotProcess.OFF
                    stepStatus3: graphzone_auto.visible ? (hipotProcess ? hipotProcess.phases[2].status : HipotProcess.OFF) : HipotProcess.OFF
                    stepStatus4: graphzone_auto.visible ? (hipotProcess ? hipotProcess.phases[3].status : HipotProcess.OFF) : HipotProcess.OFF
                    stepStatus5: graphzone_auto.visible ? (hipotProcess ? hipotProcess.phases[4].status : HipotProcess.OFF) : HipotProcess.OFF
                    stepStatus6: graphzone_auto.visible ? (hipotProcess ? hipotProcess.phases[5].status : HipotProcess.OFF) : HipotProcess.OFF
                    stepStatus7: graphzone_auto.visible ? (hipotProcess ? hipotProcess.phases[6].status : HipotProcess.OFF) : HipotProcess.OFF
//                    stepStatus1: HipotProcess.FAIL
//                    stepStatus2: HipotProcess.FAIL
//                    stepStatus3: HipotProcess.FAIL
//                    stepStatus4: HipotProcess.FAIL
//                    stepStatus5: HipotProcess.FAIL
//                    stepStatus6: HipotProcess.FAIL
//                    stepStatus7: HipotProcess.FAIL

                    phasePercent: graphzone_auto.visible ? (hipotProcess ? hipotProcess.stepPercent : 0) : 0
                    currentPhase: graphzone_auto.visible ? (hipotProcess ? hipotProcess.currentPhase : -1) : -1

//                    phasePercent: 0.8
//                    currentPhase: 2
                }
            }
        }

        //////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////



        /*************************
        * Graph zone - permanent *
        **************************/
        Item {
            id: graphzone_permanent

            height: graph_permanent.height + 60 + 30
            visible: hipotProcess && hipotProcess.parameters ? (hipotProcess.parameters.mode.value === ParamHipot.Permanent) : false

            anchors {
                left: parent.left
                right: parent.right
                bottom: parent.bottom
            }

            Item {
                id: graph_permanent

                anchors {
                    left: parent.left
                    right: parent.right
                    bottom: parent.bottom
                    margins: 14
                    bottomMargin: 60
                }

                height: 150

                Rectangle {
                    anchors.fill: parent
                    anchors.rightMargin: 2
                    radius: 14
                    color: "#2a2939"
                }

                Button {
                    anchors {
                        top: parent.bottom
                        topMargin: 4
                        right: parent.right
                    }
                    srcImage: "next.png"
                    rectVisible: false
                    width: 32
                    opacity: (!isUnderVoltage && editPhase < 2 ? 1 : 0)
                    onClicked: editPhase = Math.min(editPhase + 1, 3)
                    Behavior on opacity { NumberAnimation { duration: 100 } }
                }

                Button {
                    anchors {
                        top: parent.bottom
                        topMargin: 4
                        left: parent.left
                    }
                    srcImage: "prev.png"
                    rectVisible: false
                    width: 32
                    opacity: (!isUnderVoltage && editPhase > 1 ? 1 : 0)
                    onClicked: editPhase = Math.max(editPhase - 1, 1)
                    Behavior on opacity { NumberAnimation { duration: 100 } }
                }

                Rectangle {
                    id: rect_surbrillant
                    color: "#323140"
                    radius: 14
                    property real w: (parent.width - 20) / 3
                    x: displayedPhaseIndex < 2 ? displayedPhaseIndex * w : (displayedPhaseIndex-1) * w
                    width: w  * (displayedPhaseIndex === 0 ? 1 : 2) + 20
                    height: parent.height

                    Behavior on x {
                        enabled: displayedPhaseIndex >= 0
                        NumberAnimation {
                            duration: 800
                            easing.type: Easing.OutExpo
                        }
                    }

                    Button { // Duration
                        id : duration_btn
                        property variant param: hipotProcess && hipotProcess.parameters && displayedPhaseIndex === 0 ? hipotProcess.parameters.phases[0].time : {value: 0}

                        anchors {
                            top: parent.bottom
                            topMargin: 14
                            horizontalCenter: parent.horizontalCenter
                        }

                        width: 95
                        height: 30
                        //DAvidTest Permanent
                        text: /*"9.2"*/ {
                            var dur = "";
                            if (!isUnderVoltage) {
                                dur = Number(param.value).toFixed(1);
                            }
                            else dur = hipotProcess && hipotProcess.parameters ? hipotProcess.durationText : "";
                            return config.autoTr + dur;
                        }
                        textColor: enabled ? (pressed ? UiConfig.colors.fg_pressed : UiConfig.colors.fg_active) : "#fff"
                        font.pixelSize: 16
                        enabled: !isUnderVoltage && canChangeParameters && !remoteaccess.interfaceIsConnected

                        helpText: config.autoTr + qsTr("Open the edition of rise time.")

                        onClicked: {rzMsg = popup().editParam(param); disableButtons();}

                        visible: !isUnderVoltage ? (displayedPhaseIndex === 0) : true
                    }
                }

                Repeater {
                    model: hipotProcess && hipotProcess.parameters ? 2 : 0
                    delegate: MouseArea {
                        property real w: (graph_permanent.width - 20) / 3
                        anchors.bottom: graph_permanent.bottom
                        x: index * w + 11
                        width: (index+1) * w
                        height: graph_permanent.height + 35
                        onClicked: editPhase = index + 1

                        Text {
                            anchors {
                                top: parent.bottom
                                topMargin: -30
                                left: parent.left
                                leftMargin: index === 1 ? w : w/2
                                right: parent.right
                            }
                            text: index + 1
                            color: index == displayedPhaseIndex ? "#e8e8f0" : "#807c90"
                            Behavior on color { ColorAnimation {} }
                        }

                        Image {
                            anchors {
                                bottom: parent.bottom
                                bottomMargin: 2
                                right: parent.right
                            }
                            source: "separator.png"
                            visible: index != 1
                        }
                    }
                }

                HipotGraph {
                    id: graph
                    anchors.fill: parent

                    mode: hipotProcess.parameters.mode.value
                    nbPhases: 3
                    valuePhase1: hipotProcess && hipotProcess.parameters ? hipotProcess.parameters.phases[0].voltage.value : 0
                    valuePhase2: hipotProcess && hipotProcess.parameters ? hipotProcess.parameters.phases[1].voltage.value : 0
                    valuePhase3: 0

                    stepStatus1: graphzone_permanent.visible ? (hipotProcess ? hipotProcess.phases[0].status : HipotProcess.OFF) : HipotProcess.OFF
                    stepStatus2: graphzone_permanent.visible ? (hipotProcess ? hipotProcess.phases[1].status : HipotProcess.OFF) : HipotProcess.OFF
                    stepStatus3: graphzone_permanent.visible ? (hipotProcess ? hipotProcess.phases[1].status : HipotProcess.OFF) : HipotProcess.OFF

                    //DavidTest Permanent
                    phasePercent: graphzone_permanent.visible ? (hipotProcess ? hipotProcess.stepPercent : 0) : 0
                    currentPhase: graphzone_permanent.visible ? (hipotProcess ? hipotProcess.graphiqPhase : -1) : 0

//                    phasePercent: 0.9
//                    currentPhase: 3

                    // Animation permettant d'animer la phase 3 du test permanent (3 points successifs)
//                    SequentialAnimation {
//                        id: permAnim
//                        running: hipotProcess.graphiqPhase === 3 && hipotProcess.phases[1].status === HipotProcess.NORMAL
//                        NumberAnimation { target: graph; property: "phasePercent"; from: 0; to: 1; duration: 2000; loops: Animation.Infinite}
//                    }
                }
            }
        }

        ////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////



        /**********************
        * Graph zone - manual *
        **********************/
        Item {
            id: graphzone_manual

            height: graph_manual.height +  anchors.bottomMargin
            visible: hipotProcess && hipotProcess.parameters ? (hipotProcess.parameters.mode.value === ParamHipot.Manual) : false

            anchors {
                horizontalCenter: parent.horizontalCenter
                horizontalCenterOffset: -40
                bottom: parent.bottom
                bottomMargin: 7
            }

            Item {
                id: graph_manual
                anchors {
                    bottom: graphzone_manual.bottom
                    bottomMargin: 10
                    horizontalCenter: parent.horizontalCenter
                }

                width: arrow.width
                height: arrow.height

                ArrowUp {
                    id: arrow

                    stepPerCent: hipotProcess && hipotProcess.parameters && isUnderVoltage ? 100 * (hipotProcess.manualVoltage / hipotProcess.parameters.phases[0].voltage.value) : 0;
                    stepColor: {
                        var c = "#ffd827";
                        if (!hipotProcess) return c;
                        if (hipotProcess.status === HipotProcessPhaseReport.ERROR) c = config.resultErrorColor;
                        else if (hipotProcess.status === HipotProcessPhaseReport.FAIL) c = config.resultFailColor;
                        return c;
                    }
                }

                Column{
                    id: manual_step_buttons
                    anchors {
                        left: arrow.right
                        bottom: arrow.bottom
                        leftMargin: 50
                    }

                    spacing: 10
                    ButtonTimed {
                        id: stepUp
                        enabled: isUnderVoltage
                        srcImage: enabled ? "arrowup.png" : "arrowup_off.png"
                        rectVisible: false
                        helpText: ""

                        onAutoClicked: {
                            var voltageParam = hipotProcess.manualVoltage + hipotProcess.parameters.step.value
                            if(voltageParam > hipotProcess.parameters.phases[0].voltage.value){
                                voltageParam = hipotProcess.parameters.phases[0].voltage.value;
                            }
                            hipotProcess.manualVoltage = voltageParam;
                            canbus.hipot.send_cmd_manualControl(hipotProcess.manualVoltage)
                        }
                    }

                    ButtonTimed {
                        id: stepDown

                        enabled: isUnderVoltage
                        srcImage: enabled ? "arrowdown.png" : "arrowdown_off.png"
                        rectVisible: false
                        helpText: ""

                        onAutoClicked: {
                            var voltageParam =  hipotProcess.manualVoltage - hipotProcess.parameters.step.value
                            if(voltageParam<0){
                                voltageParam = 0;
                            }
                            hipotProcess.manualVoltage = voltageParam;
                            canbus.hipot.send_cmd_manualControl(hipotProcess.manualVoltage)
                        }
                    }
                }

            }
        }

        /*****************
        * Result message *
        *****************/
        TestStatus {
            anchors {
                top: parent.top
                left: parent.left
                right: parent.right
            }
            height: 70
            //DavidTest
            state: hipotProcess ? hipotProcess.status : ""
//            state: HipotProcess.FAIL
            errorText: hipotProcess ? hipotProcess.errorText : ""
        }
    }

    /*******************
    * Live report zone *
    *******************/
    MeasureCaroussel {
        id: livereport_internal

        anchors {
            top: parent.top
            bottom: parent.bottom
            left: parent.left
            leftMargin: 359
            right: parent.right
        }
        //DavidTest
        u: hipotProcess ? (hipotProcess.voltageText ? hipotProcess.voltageText : "") : ""
        it: hipotProcess ? (hipotProcess.currentTotalText ? hipotProcess.currentTotalText: "") :""
        ir: hipotProcess ? (hipotProcess.currentRealText ?  hipotProcess.currentRealText : "" ) : ""

        uunit: hipotProcess ? (hipotProcess.voltageUnit ? hipotProcess.voltageUnit : "") : ""
        itunit: hipotProcess ? (hipotProcess.currentTotalUnit ? hipotProcess.currentTotalUnit : "") : ""
        irunit: hipotProcess ? (hipotProcess.currentRealUnit ? hipotProcess.currentRealUnit : "") : ""

        // On décide de n'afficher le max que quand le test est bon
        umax: hipotProcess ? (hipotProcess.status === HipotProcess.PASS ? hipotProcess.voltageMaxText : "") : ""
        itmax: hipotProcess ? (hipotProcess.status === HipotProcess.PASS ? hipotProcess.currentTotalMaxText : "") : ""
        irmax: hipotProcess ? (hipotProcess.status === HipotProcess.PASS ? hipotProcess.currentRealMaxText : "") : ""

        errorText: hipotProcess ? (hipotProcess.errorText ? hipotProcess.errorText : "") : ""
        chargeText: hipotProcess ? (hipotProcess.chargeText ? hipotProcess.chargeText : "") : ""

//        disabledLabel: hipotProcess.parameters.voltageType.value === ParamHipot.DC ? qsTr("I real") : ""

        uenabled: true
        itenabled: true
        irenabled: hipotProcess.parameters.voltageType.value === ParamHipot.DC ? false : true

        udisj: hipotProcess ? (hipotProcess.voltageDisjText ? hipotProcess.voltageDisjText : ""):""
        itdisj: hipotProcess ? (hipotProcess.currentTotalDisjText ? hipotProcess.currentTotalDisjText : ""):""
        irdisj: hipotProcess ? (hipotProcess.currentRealDisjText ? hipotProcess.currentRealDisjText : ""):""

        ulength: hipotProcess ? (hipotProcess.voltageTextLength ? hipotProcess.voltageTextLength :3) :3
        itlength: hipotProcess ? (hipotProcess.currentTotalTextLength ? hipotProcess.currentTotalTextLength :3) :3
        irlength: hipotProcess ? (hipotProcess.currentRealTextLength ? hipotProcess.currentRealTextLength :3) :3

        filter: hipotProcess ? ((hipotProcess.parameters.filter.value === ParamHipot.CAPA && hipotProcess.parameters.filter.modifiable) ? "Capa.png" : "") : ""

        currentLimitation: hipotProcess.parameters.limitation3mAAC()

//        Component.onCompleted: {
//            console.log("ReportZone limitation3mA ? ",hipotProcess.parameters.limitation3mAAC());
//        }

        //        u: "2,500"
        //        it:  "2,113"
        //        ir: "2,113"

        //        uunit: "kV"
        //        itunit: "mA"
        //        irunit: "mA"

        //        umax:  "2,50kV"
        //        itmax:  "2,113mA"
        //        irmax:  "2,113mA"

    }

    Connections {
        target: hipotProcess
        onStatusChanged : {
            if (end_btn.visible || !duration_btn.visible) {
                end_btn.visible = false;
                duration_btn.visible = true;
            }
            //Notamment en début de test on veut envoyer la commande en tension
            if (hipotProcess.parameters.mode.value === ParamHipot.Manual) {
//                console.log("onStatusChanged et manual Voltage = ", hipotProcess.manualVoltage);
                canbus.hipot.send_cmd_manualControl(hipotProcess.manualVoltage);
            }
        }
        onFinished : {
            //Si le status est à OFF quand on reçoit le signal Fin de Test c'est que l'utilisateur à appuyer sur STOP
            //Pas besoin du message "Press Stop" dans ce cas
            if(hipotProcess.status !== HipotProcess.OFF) {
                duration_btn.visible = false;
                end_btn.visible = true;
            }
        }
    }
    Connections {
        target: hipotProcess.parameters.mode
        onValueChanged: editPhase = 1;
    }

//    Connections {
//        target: hipotProcess.parameters.phases[1].voltage
//        onValueChanged: {
//            autoGraph.requestPaint();
//        }
//    }

    function disableButtons(){
        hal.setStartLight(false);
        hal.setStopLight(false);
    }
}
