import QtQuick 2.2
import Horus 1.0
import "../HorusComponents"

Item {
    property bool canChangeParameters: config.acl.value <= ParamGlobal.ADMINISTRATOR
    property bool canChangeProgram: config.acl.value <= ParamGlobal.TECHNICIAN
    property var msg: null

    ReportZone {
        id: reportZone
        anchors {
            top: parent.top
            left: parent.left
            leftMargin: 5
        }
        hipotProcess: process
        isUnderVoltage: page.isUnderVoltage
    }

    /*********************************
    * Right bar (params, list, help) *
    *********************************/
    RightBar {
        id: rightbar
        anchors {
            top: parent.top
            right: parent.right
            rightMargin: -10
        }
        enabled_help: !isUnderVoltage && !remoteaccess.interfaceIsConnected
        enabled_list: !isUnderVoltage && canChangeProgram && !remoteaccess.interfaceIsConnected
        enabled_settings: !isUnderVoltage && canChangeParameters && !remoteaccess.interfaceIsConnected
        stopMessage_visible: isUnderVoltage && process.finished

        startStopRelated: true
    }

    /*****************
    * Parameters row *
    *****************/
    Row {
        id: bottomrow

        anchors {
            horizontalCenter: parent.horizontalCenter
            bottom: parent.bottom
            bottomMargin: -10
        }

        spacing: 14

        ErrorButton { // Time
            property variant param: hipot.mode

            textTitle: config.autoTr + qsTr("Time")

            //DavidTest
            text: /* "3.4s"*/
            {
                if(param.value === ParamHipot.Permanent) {
                    return param.text;
                }
                else {
                    var i, remaining = 0;
                    if (process.currentPhase > 0)
                        remaining = hipot ? (hipot.phases[process.currentPhase-1].time.value * (1 - process.stepPercent)) : 0;
                    for (i = process.currentPhase || 1; i < hipot.nbPhases; ++i)
                        remaining += hipot.phases[i].time.value

                        return config.autoTr + qsTr("%1 s").arg(Number(remaining).toFixed(1));
                }
            }


            startRelated: true

            color: param.value === ParamHipot.Permanent ? UiConfig.colors.fg_inactive : "#fff"
            enabled: false
            visible: isUnderVoltage

        }

        ErrorButton { // Time
            id: timeBtn
            property variant param: hipot.mode

            textTitle: config.autoTr + qsTr("Time")
            text: param.text
            enabled: canChangeParameters && param.modifiable && !remoteaccess.interfaceIsConnected
            helpText:qsTr("This button opens a list of the modes available for the hipot function")
            visible: !isUnderVoltage

            startRelated: true

            onClicked: {
                msg = popup().editParam(param);
                disableButtons();
            }
        }

        ErrorButton { // Voltage
            id: param_voltage
            property var ind : (!hipot.multiFlag && (reportZone.displayedPhaseIndex === hipot.nbPhases - 1)) ? reportZone.displayedPhaseIndex -1 : reportZone.displayedPhaseIndex;
            property variant param: hipot.phases[ind].voltage

            textTitle: hipot.voltageType.text
            text: param.text

            enabled: !isUnderVoltage && canChangeParameters && param.modifiable && !remoteaccess.interfaceIsConnected

            helpText:qsTr("This button opens a keypad to edit the voltage value of your hipot test")

            startRelated: true

            onClicked: {
                msg = popup().editParam(param);
                 disableButtons();
            }
        }

        ErrorButton { // Imin
            id: param_imin

            property variant param: hipot.phases[reportZone.displayedPhaseIndex].imin

            textTitle: config.autoTr + qsTr("I min")
            text: param.text
            enabled: !isUnderVoltage && canChangeParameters && param.modifiable && !remoteaccess.interfaceIsConnected

            helpText:qsTr("This button opens a keypad to edit the low current limit value of your hipot test")

            startRelated: true

            onClicked: {
                msg = popup().editParam(param);
                disableButtons();
            }

            state: {
                var st = "";
                for (var i = 0; i < hipot.nbPhases; ++i) {
                    if (process.phases[i].iMinStatus === HipotProcessPhaseReport.ERROR) st = "error";
                    else if (process.phases[i].iMinStatus === HipotProcessPhaseReport.FAIL) st = "fail";
                }
                return st;
            }
        }

        ErrorButton { // Imax
            property variant param: hipot.phases[reportZone.displayedPhaseIndex].imax


            textTitle: config.autoTr + qsTr("I max")
            text: /*"2mA"*/(hipot.phases[reportZone.displayedPhaseIndex].breakdown.value === ParamHipotPhase.DeltaI_Imax || hipot.phases[reportZone.displayedPhaseIndex].breakdown.value === ParamHipotPhase.Imax) ? param.text : "OFF"
            enabled: !isUnderVoltage && canChangeParameters && param.modifiable && !remoteaccess.interfaceIsConnected

            helpText:qsTr("This button opens a keypad to edit the high current limit value of your hipot test")

            startRelated: true

            onClicked: {
                msg = popup().editParam(param);
                disableButtons();
            }

            //DavidTest
            state: {
                var st = "";
                for (var i = 0; i < hipot.nbPhases; ++i) {
                    if (process.phases[i].iMaxStatus === HipotProcessPhaseReport.ERROR) st = "error";
                    else if (process.phases[i].iMaxStatus === HipotProcessPhaseReport.FAIL) st = "fail";
                }
                return st;
//                return "fail";
            }
        }

        ErrorButton { // Delta I
            property variant param: hipot.phases[reportZone.displayedPhaseIndex].deltaICurrent

            textTitle: config.autoTr + qsTr("Delta I")
            text: (hipot.phases[reportZone.displayedPhaseIndex].breakdown.value === ParamHipotPhase.DeltaI_Imax || hipot.phases[reportZone.displayedPhaseIndex].breakdown.value === ParamHipotPhase.DeltaI) ? param.text : "OFF";
            enabled: !isUnderVoltage && canChangeParameters && param.modifiable && !remoteaccess.interfaceIsConnected

            helpText:qsTr("This button opens a keypad to edit the differential current limit value of your hipot test")

            startRelated: true

            onClicked: {
//                console.log("auto.qml: DeltaI: compValue = ", param.compValue);
                msg = popup().editParam(param);
                disableButtons();
            }

            state: {
                var st = "";
                for (var i = 0; i < hipot.nbPhases; ++i) {
                    if (process.phases[i].deltaIStatus === HipotProcessPhaseReport.ERROR) st = "error";
                    else if (process.phases[i].deltaIStatus === HipotProcessPhaseReport.FAIL) st = "fail";
                }
                return st;
//                return "fail";
            }
        }

    }

    Connections {
        target: msg
        onClose: {
            //Dans le cas d'une double popup la condition popup.isOpened pose problème, on la contourne ici sachant qu'elle n'est qu'une sécurité
            hal.setStartLight(!remoteaccess.interfaceIsConnected && hal.safetyLoop /*&& !popup().isOpened()*/);
            hal.setStopLight(false);
        }
    }

    Connections {
        //Permet de ne pas rallumer le bouton start lors de l'ouverture de la pop up d'erreur lié au temps de maintien grace au booleen visible de cette page
        target: reportZone.rzMsg
        onClose: {
            //Dans le cas d'une double popup la condition popup.isOpened pose problème, on la contourne ici sachant qu'elle n'est qu'une sécurité
            hal.setStartLight(!remoteaccess.interfaceIsConnected && hal.safetyLoop && visible);
            hal.setStopLight(false);
        }
    }

    function disableButtons(){
        hal.setStartLight(false);
        hal.setStopLight(false);
    }
}
