import QtQuick 2.2
import QtMultimedia 5.0
import Horus 1.0
import "../HorusComponents"

Item {
    property bool canChangeParameters: config.acl.value <= ParamGlobal.ADMINISTRATOR
    property bool canChangeProgram: config.acl.value <= ParamGlobal.TECHNICIAN

    ReportZone {
        id: reportZone
        anchors {
            top: parent.top
            left: parent.left
            leftMargin: 5
        }
        hipotProcess: process
        isUnderVoltage: page.isUnderVoltage
    }

    /*********************************
    * Right bar (params, list, help) *
    *********************************/
    RightBar {
        id: rightbar
        anchors {
            top: parent.top
            right: parent.right
            rightMargin: -10
        }
        enabled_help: !isUnderVoltage && !remoteaccess.interfaceIsConnected
        enabled_list: !isUnderVoltage && canChangeProgram && !remoteaccess.interfaceIsConnected
        enabled_settings: !isUnderVoltage && canChangeParameters && !remoteaccess.interfaceIsConnected
    }

    /*****************
    * Parameters row *
    *****************/
    Row {
        id: bottomrow

        anchors {
            horizontalCenter: parent.horizontalCenter
            bottom: parent.bottom
            bottomMargin: -10
        }

        spacing: 14

        ErrorButton { // Time
            property variant param: hipot.mode

            textTitle: config.autoTr + qsTr("Time")
            text: param.text
            enabled: !isUnderVoltage && canChangeParameters && param.modifiable && !remoteaccess.interfaceIsConnected

            onClicked: popup().editParam(param)
        }

        ErrorButton { // Tension
            id: param_voltage

            property variant param: hipot.phases[0].voltage

            textTitle: hipot.voltageType.text
            text: param.text
            enabled: !isUnderVoltage && canChangeParameters && param.modifiable && !remoteaccess.interfaceIsConnected

            onClicked: popup().editParam(param)
        }

        ErrorButton { // Step
            id: param_step

            property variant param: hipot.step

            textTitle: config.autoTr + qsTr("Step")
            text: param.text
            enabled: !remoteaccess.interfaceIsConnected || isUnderVoltage

            onClicked: popup().editParam(param)
        }

        ErrorButton { // Imax
            property variant param: hipot.phases[0].imax

            textTitle: config.autoTr + qsTr("I max")
            text: (hipot.phases[reportZone.displayedPhaseIndex].breakdown.value === ParamHipotPhase.DeltaI_Imax || hipot.phases[reportZone.displayedPhaseIndex].breakdown.value === ParamHipotPhase.Imax) ? param.text : "OFF"
            enabled: !isUnderVoltage && canChangeParameters && param.modifiable && !remoteaccess.interfaceIsConnected

            helpText:qsTr("This button opens a keypad to edit the high current limit value of your hipot test")

            startRelated: true

            onClicked: {
                msg = popup().editParam(param);
                disableButtons();
            }

            state: {
                var st = "";
                for (var i = 0; i < 3; ++i) {
                    if (process.phases[i].iMaxStatus == HipotProcessPhaseReport.ERROR) st = "error";
                    else if (process.phases[i].iMaxStatus == HipotProcessPhaseReport.FAIL) st = "fail";
                }
                return st;
            }
        }

        ErrorButton { // Delta I
            property variant param: hipot.phases[0].deltaICurrent

            textTitle: config.autoTr + qsTr("Delta I")
            text: (hipot.phases[reportZone.displayedPhaseIndex].breakdown.value === ParamHipotPhase.DeltaI_Imax || hipot.phases[reportZone.displayedPhaseIndex].breakdown.value === ParamHipotPhase.DeltaI) ? param.text : "OFF";
            enabled: !isUnderVoltage && canChangeParameters && param.modifiable && !remoteaccess.interfaceIsConnected

            onClicked: popup().editParam(param)

            state: {
                var st = "";
                for (var i = 0; i < 3; ++i) {
                    if (process.phases[i].deltaIStatus == HipotProcessPhaseReport.ERROR) st = "error";
                    else if (process.phases[i].deltaIStatus == HipotProcessPhaseReport.FAIL) st = "fail";
                }
                return st;
            }
        }
    }
}
