import QtQuick 2.0
import Horus 1.0
import "../HorusComponents"

Page {
    id: page
    property bool isUnderVoltage: process.running

    property bool multi: extra? extra.multi : false

    title: config.autoTr + (multi ? qsTr("MultiHipot") : qsTr("Hipot"))
    navigationBtnEnable: !isUnderVoltage
    headerButton {
        text: hipotLoader.filename
        enabled: !isUnderVoltage && (config.acl.value <= ParamGlobal.ADMINISTRATOR) && !remoteaccess.interfaceIsConnected
        startRelated: true
        onClicked: {
            function configHip() {
                return (multi ? config.multiHipotConfig : config.hipotConfig);
            }
            msg = popup().editText(
                        qsTr("Filename"),
                        hipotLoader.filename,
                        function (name) {
                            if (name !== undefined) {
                                if (hipotLoader.exists(name)) {
                                    msg = popup().msg(qsTr("Warning"), qsTr("There is already a configuration named \"%1\". Do you want to overwrite it ?").arg(hipotLoader.data.sanitizeName(name)), [qsTr("Overwrite"), qsTr("Cancel")], function(nr) {
                                        if (nr === 0) {
                                            hipotLoader.data.copyToStorage(name);
                                            if (multi) config.multiHipotConfig  = name;
                                            else config.hipotConfig = name;
                                            return true;
                                        } else if (nr === 1) {
                                            return true;
                                        }
                                        return false;
                                    }, /* replace: */ true);
                                    return false;
                                }
                                else {
                                    msg = popup().msg(qsTr("Rename"), qsTr("Do you want to rename \"%1\" or do you want to duplicate \"%1\" and rename it ?").arg(configHip()), [qsTr("Rename"), qsTr("Duplicate & Rename")], function(nr) {
                                        if (nr === 1) {
                                            hipotLoader.data.copyToStorage(name);
                                            if (multi) config.multiHipotConfig  = name;
                                            else config.hipotConfig = name;
                                            return true;
                                        } else if (nr === 0) {
                                            hipotLoader.data.copyToStorage(name);
                                            hipotLoader.remove(configHip());
                                            if (multi) config.multiHipotConfig  = name;
                                            else config.hipotConfig = name;
                                            return true;
                                        }
                                        return false;
                                    }, /* replace: */ true)
                                }
                            }
                            return (true);
                        }, false, "^[a-zA-Z0-9_-]{1,100}$");
            disableButtons();
        }
    }

    Connections {
        target: remoteaccess
        onModeHipotChanged: {
            if (!remoteaccess.modeHipot && page.visible)
                back_page();
        }
        onFunctionsDeactivated: {
            if (!remoteaccess.modeHipot && page.visible)
                back_page();
        }
    }

    property var process: remoteaccess.modeHipot ? remoteaccess.hipotProcess : processQml
    HipotProcess {
        id: processQml

        parameters: hipotLoader.data
        canbusHipot: canbus.hipot
        halObj: hal
        configObj: config
        inhibit: !page.visible || popup().isOpened() || remoteaccess.modeHipot

        property bool startEnable: false

        onCommunicationError: {
            if(!process.finished) {
                page.msg = popup().msg(qsTr("Communication Failed"), qsTr("Hipot function stopped responding. Please restart the machine for safety.\nContact our service if it happens again."), [qsTr("Ok")], function(nr) {
                    if (nr === 0) {
                        return true;
                    }
                });
            }
            else {
                page.msg = popup().msg(qsTr("Start Failed"), qsTr("The test failed to start. Try again to launch the test."), [qsTr("Ok")], function(nr) {
                    if (nr === 0) {
                        return true;
                    }
                });
            }

            disableButtons();
        }

        onInterrupted: {
            measure_stop();
            page.msg = popup().msg(qsTr("Test aborted"), qsTr("The test has been aborted"), [qsTr("Ok")], function(nr) {
                if (nr === 0) return true;
                else return false;
            });

        }

        Connections {
            target: hal
//            onStartButtonPressed: {
//                var indexPh = "";
//                var txtErr = ";"
//                var tabErr1 = [];
//                var tabErr2 = [];
//                var tabPh = [];
////                if (hal.securityLoop) {
////                    securityLoopWatcher.open();
////                }
///*                else */if (!remoteaccess.interfaceIsConnected){
//                    // On créé un tableau réunissant les indices des phases où les limites ne sont pas bien paramétrées ou les phases de maintien paramétré à 0s
//                    for (var i=0; i < hipotLoader.data.nbPhases; i++) {
//                        if (hipotLoader.data.phases[i].imaxTotal.row_value() < hipotLoader.data.phases[i].iminTotal.row_value() || hipotLoader.data.phases[i].imaxReal.row_value() < hipotLoader.data.phases[i].iminReal.row_value()) {
//                            tabErr1.push(i+1);
//                        }
//                        if (i!==0 && hipotLoader.data.phases[i].time.value === 0 && (hipotLoader.data.phases[i-1].voltage.value - hipotLoader.data.phases[i].voltage.value) == 0) {
//                            tabErr2.push(i+1);
//                        }
//                    }
//                    if (tabErr1.length !== 0) {
//                        tabPh = tabErr1;
//                        indexPh = qsTr("Imax value must be superior to Imin value in phase ");
//                    }
//                    else if (tabErr2.length !== 0) {
//                        tabPh = tabErr2;
//                        indexPh = qsTr("Holding phase can't last 0s as in phase ");
//                    }
//                    // On créé un String à partir du tableau d'indices afon de fourir le message d'erreur
//                    for (var j = 0; j < tabPh.length; j++) {
//                        indexPh += tabPh[j].toString();
//                       if (tabPh.length != 1) {
//                           if (j == tabPh.length-2) indexPh += " & ";
//                           else if (j < tabPh.length-2 ) indexPh += ", ";
//                       }
//                    }
//                    if (indexPh !== "") {
//                        popup().msg(qsTr("Value error"), indexPh, [qsTr("Ok")], function(nr) {
//                            if (nr === 0) {
//                                return true;
//                            }
//                        });
//                    }
//                    else {
//                        timer.running = true;
//                    }

//                        /*
//                            Version modifiée par LN le 09/05/2017
//                            Modification : * Ajout des deux conditions ci-dessus permettant de faire une dernoère vérification des limites basses et hautes avant de lancer un test
//                        */

////                        else {
////                            process.measure_start();
////                        }
//                }
//            }
            onStartButtonPressed: {
                if (!remoteaccess.interfaceIsConnected && !process.inhibit) {
                    if (!hal.safetyLoop) {
                        securityLoopWatcher.open();
                    }
                    else if (!process.readyToStart() && page.msg == null && process.invalidParameters() !== "") {
                        page.msg = popup().msg(qsTr("Test invalid"), qsTr("Some parameters are invalid:\n%1").arg(process.invalidParameters()), [qsTr("Ok")], function(nr) {
                            if (nr === 0) {
                                return true;
                            }
                        });
                        disableButtons();
                    }
                    else {
                        timer.running = true;
                    }


                    if (config.acl.value === ParamGlobal.SERVICE) {
                        process.close_HoldingLoop();
                    }
                }
            }
            onStopButtonPressed: {
                if (process.running && !process.finished) {
                    //LCIETest
//                    process.measure_stop();
                    process.cmd_Discharge();
//                    page.msg = popup().msg(qsTr("Test aborted"), qsTr("The test has been aborted"), [qsTr("Ok")], function(nr) {
//                        if (nr === 0) return true;
//                        else return false;
//                    });
                }
                else {
                    process.measure_stop();
                    if(page.msg) {
                        page.msg.close();
                    }
                }
                hal.setStartLight(!process.inhibit && !remoteaccess.interfaceIsConnected && hal.safetyLoop && !(process.running && !process.finished));
                hal.setStopLight(process.running && !process.finished);
            }
            onStartButtonReleased: {
                timer.running = false;
                if(process.startEnable || !hal.safetyLoop){
                    process.startEnable = false;
                }
                else if (!process.running && page.msg == null && !remoteaccess.interfaceIsConnected && config.acl.value !== ParamGlobal.SERVICE && !process.inhibit) {
                    page.msg = popup().tempo(qsTr("Launch a test"), qsTr("Press start for 1s"), 2000);
                    disableButtons();
                }
            }
        }

        Timer {
            id:timer
            interval: 1000
            running: false
            repeat: false
            onTriggered: {
                process.startEnable = true;
                process.close_HoldingLoop();
             }
        }
    }

    SecurityLoopWatcher {
        id: securityLoopWatcher
        process: remoteaccess.modeHipot ? remoteaccess.hipotProcess : processQml
    }

//    SecurityLoopWatcher {
//        id: securityLoopWatcher
//        process: process
//    }

    Loader {
        property variant hipot : hipotLoader.data
        anchors.fill: parent

        focus: true

        source: (hipot.mode.value === ParamHipot.Auto || hipot.mode.value === ParamHipot.Permanent) ? "auto.qml" : "manual.qml"

        ParamHipotLoader {
            id: hipotLoader
            multiFlag: multi
            filename: multi ? config.multiHipotConfig : config.hipotConfig

            onFilenameChanged: {
                processQml.parameters = hipotLoader.data;
            }
        }
    }

    Component.onCompleted: {
//        console.log("page_hipot_live completed: loader = ", hipotLoader, " et loader.multi ? ", hipotLoader.multiFlag);

        //TODO: vérifier si cette ligne est encore nécessaire
        if(multi)hipotLoader.setFilename(config.multiHipotConfig);

//        console.log("page_hipot_live completed: multi = ", multi);

        //Modif LN du 12/02/2020:
        //On ajoute cette mise à jour des propriétés pour que même le fichier défaut
        //créé avant la réception des propriétés puisse prendre en compte celles-ci dès ouverture de la page
        hipotLoader.data.updateProperties();

        paramupdater.hipot.setMulti(hipotLoader.multiFlag);
        paramupdater.hipot.enable = true;
        hal.setStartLight(!remoteaccess.interfaceIsConnected && hal.safetyLoop && !process.inhibit);
        hal.setStopLight(false);
    }
    Component.onDestruction:{
        paramupdater.hipot.enable = false;
        hal.setStartLight(false);
        hal.setStopLight(false);
    }

    onVisibleChanged: {
        hal.setStartLight(visible && !remoteaccess.interfaceIsConnected && hal.safetyLoop);
        hal.setStopLight(false);
    }

    Connections {
        target: msg
        onClose: {
//            console.log("hipot_live: setstartlight(", !remoteaccess.interfaceIsConnected, ")");
            hal.setStartLight(visible && !remoteaccess.interfaceIsConnected && hal.safetyLoop && !process.inhibit && !process.running);
            hal.setStopLight(isUnderVoltage);
        }
    }

    onIsUnderVoltageChanged: {
        if(isUnderVoltage) remoteaccess.disableRemoteAccess();
        else remoteaccess.enableRemoteAccess();
    }

    function disableButtons(){
        hal.setStartLight(false);
        hal.setStopLight(false);
    }
}
