import QtQuick 2.2
import Horus 1.0
import "../HorusComponents"

Item {
    ListView {
        id: hlist
        anchors.fill: parent
        anchors.bottomMargin: 30
        model: hipot.nbPhases.value + 1
        orientation: ListView.Horizontal
        highlightFollowsCurrentItem: true
        highlightRangeMode: ListView.StrictlyEnforceRange
        snapMode: ListView.SnapOneItem
        currentIndex: 0
        clip: true

        delegate: Item {
            property int indexPhase: index - 1
            width: hlist.width <= 0 ? 800 : hlist.width /* Since hlist.width is
set after the computation of initial position, we set an initial large enough
size to get the first element correctly displayed */
            height: hlist.height

            ParametersList {
                id: vlist
                anchors.fill: parent
                model: indexPhase >= 0 ? hipot.expertPhases[indexPhase].parametersList : [hipot.voltageType, hipot.breakdown, hipot.nbPhases]
            }
        }
    }
    HScrollBar {
        id: hscroll
        anchors {
            bottom: parent.bottom
            bottomMargin: 20
            left: parent.left
            right: parent.right
        }
        scrollArea: hlist
    }
    Text {
        anchors {
            top: hscroll.bottom
            horizontalCenter: hscroll.left
            horizontalCenterOffset: hscroll.handleX + hscroll.handleWidth / 2
        }
        text: hlist.currentIndex == 0 ? qsTr("Global") : qsTr("Phase %1/%2").arg(hlist.currentIndex).arg(hipot.nbPhases.value)
        horizontalAlignment: Text.AlignHCenter
        font.pixelSize: 20
        color: UiConfig.colors.fg_root
    }
    MouseArea {
        anchors {
            top: hscroll.bottom
            left: parent.left
            right: parent.right
            bottom: parent.bottom
        }

        onClicked: hlist.positionViewAtIndex(mouse.x / width * hlist.count, ListView.SnapPosition);
    }
}
