import QtQuick 2.2
import Horus 1.0
import "../HorusComponents"

Page {
    id: hipotParameters

    property variant hipotLoader: extra.loader

    property variant hipot: extra.loader.data

    property bool multi: extra.loader.data.multiFlag

    title: config.autoTr + (multi ? qsTr("MultiHipot") : qsTr("Hipot"))
    headerButton {
        text: hipotLoader.filename
        onClicked: {
            popup().editText(
                qsTr("Filename"),
                hipotLoader.filename,
                function (name) {
                    if (name !== undefined) {
                        if ((!multi && hipotLoader.exists(name)) || (multi && hipotLoader.multiExists(name) )) {
                            popup().msg(qsTr("Warning"), qsTr("There is already a configuration named \"%1\". Do you want to overwrite it ?").arg(hipotLoader.data.sanitizeName(name)), [qsTr("Overwrite"), qsTr("Cancel")], function(nr) {
                                if (nr === 0) {
                                    hipotLoader.data.copyToStorage(name);
                                    config.hipotConfig = name;
                                    return true;
                                } else if (nr === 1) {
                                    return true;
                                }
                                return false;
                            }, /* replace: */ true);
                            return false;
                        }
                        else {
                            popup().msg(qsTr("Rename"), qsTr("Do you want to rename \"%1\" or do you want to duplicate \"%1\" and rename it ?").arg(config.hipotConfig), [qsTr("Rename"), qsTr("Duplicate & Rename")], function(nr) {
                                if (nr === 1) {
                                    hipotLoader.data.copyToStorage(name);
                                    config.hipotConfig = name;
                                    return true;
                                } else if (nr === 0) {
                                    hipotLoader.data.copyToStorage(name);
                                    hipotLoader.remove(config.hipotConfig);
                                    config.hipotConfig = name;
                                    return true;
                                }
                                return false;
                            }, /* replace: */ true)
                        }
                    }
                    return (true);
                }, false, "^[a-zA-Z0-9_-]{1,100}$");
        }
    }

//    ParamHipotLoader {
//        id: hipotLoader
//        multiFlag: multi
//        filename: multi ? config.multiHipotConfig : config.hipotConfig
//    }

    Loader {
        id: innerpage
        anchors {
            top: parent.top
            bottom: parent.bottom
            left: parent.left
            right: rightColumn.left
            rightMargin: 10
        }
        source: {
            if(hipot.mode.value === ParamHipot.Manual || !multi) return "manual.qml";
            else if (hipot.mode.value === ParamHipot.Auto) return "auto.qml";
            else if (hipot.mode.value === ParamHipot.Permanent) return "permanent.qml";
        }
    }

    Column {
        id: rightColumn

        anchors {
            top: parent.top
            right: parent.right
            rightMargin: -10
        }

        spacing: 10

        ButtonList {
            helpText: config.autoTr + qsTr("This button opens file list parameters.")

            onClicked: {
                function configHip(){
                    return (hipotLoader.multiFlag ? config.multiHipotConfig : config.hipotConfig);
                }

                var nb = 0;
                for (nb in hipotLoader.filesList) {
                    if (hipotLoader.filesList[nb] === configHip())
                        break;
                    nb++;
                }
                msg = popup().manageFiles(qsTr("Change settings"), hipotLoader.filesList, nb, hipotLoader,
                      function(nl) {
                          if (nl !== undefined) {
                              if (hipotLoader.multiFlag) config.multiHipotConfig = nl;
                              else config.hipotConfig = nl;
                          }
                      },
                    function(nr) {
                        return true;
                });
                disableButtons();
            }
        }

        ButtonAddPhase {
            enabled: hipot.nbPhases < 7
            visible: (hipot.mode.value === ParamHipot.Auto && multi)
            onClicked: hipot.addPhase(innerpage.item.currentIndex)
        }

        ButtonRmPhase {
            enabled: innerpage.item.currentIndex !== 0 && hipot.nbPhases > 3
            visible: (hipot.mode.value === ParamHipot.Auto && multi)
            onClicked: hipot.rmPhase(innerpage.item.currentIndex)
        }

        ButtonHelp {
            helpText: config.autoTr + qsTr("This button opens help.")
        }

        ButtonPlay {
            helpText: config.autoTr + qsTr("This button opens live report back")
            onClicked: back_page()
        }
    }

    Component.onCompleted:  {
//        console.log("page_hipot_live onCompleted : hipotLoader.multi = ", multi);
    }
}
