import QtQuick 2.2
import Horus 1.0
import "../HorusComponents"

Item {
    property alias currentIndex: hlist.currentIndex
    ListView {
        id: hlist
        anchors.fill: parent
        anchors.bottomMargin: 30
        model: 3
        orientation: ListView.Horizontal
        highlightFollowsCurrentItem: true
        highlightRangeMode: ListView.StrictlyEnforceRange
        snapMode: ListView.SnapOneItem
        currentIndex: 0
        clip: true

        delegate: Loader {
            property int indexPhase: index - 1
            width: hlist.width <= 0 ? 800 : hlist.width /* Since hlist.width is
set after the computation of initial position, we set an initial large enough
size to get the first element correctly displayed */
            height: hlist.height
            sourceComponent: indexPhase >= 0 ? phaseListComponent : globalComponent
        }

        Component {
            id: globalComponent
            Item {
                VScrollBar {
                    anchors {
                        top: parent.top
                        bottom: parent.bottom
                        left: parent.left
                    }
                    scrollArea: flickable
                }

                Flickable {
                    id: flickable

                    anchors.fill: parent
                    anchors.leftMargin: 10

                    contentWidth: flickable_inner.width
                    contentHeight: flickable_inner.height
                    flickableDirection: Flickable.VerticalFlick
                    interactive: visibleArea.heightRatio < 1
                    clip: true

                    Column {
                        id: flickable_inner
                        spacing: 10

                        AutoGlobalEntry {
                            title: hipot.mode.name
                            text: hipot.mode.text
                            onClicked: popup().editParam(hipot.mode)
                            enabled: hipot.mode.modifiable
                        }
                        AutoGlobalEntry {
                            title: hipot.voltageType.name
                            text: hipot.voltageType.text
                            onClicked: popup().editParam(hipot.voltageType)
                            enabled: hipot.voltageType.modifiable
                        }
                        AutoGlobalEntry { autoChangeAll: 'voltage' }
                        AutoGlobalEntry { autoChangeAll: 'time' }
                        AutoGlobalEntry { autoChangeAll: 'deltaICurrent' }
//                        AutoGlobalEntry { autoChangeAll: 'deltaIWidth' }
                        AutoGlobalEntry { autoChangeAll: 'breakdown' }
                        AutoGlobalEntry { autoChangeAll: 'iminTotal' }
                        AutoGlobalEntry { autoChangeAll: 'imaxTotal' }
                        AutoGlobalEntry { autoChangeAll: 'iminReal' }
                        AutoGlobalEntry { autoChangeAll: 'imaxReal' }
                    }
                }
            }
        }

        Component {
            id: phaseListComponent
            ParametersList {
                model: hipot.phases[indexPhase].parametersList(indexPhase === 1)
            }
        }
    }
    HScrollBar {
        id: hscroll
        anchors {
            bottom: parent.bottom
            left: parent.left
            right: parent.right
        }
        scrollArea: hlist
        clickable: false
    }
    MouseArea {
        anchors {
            bottom: hscroll.top
            left: parent.left
            right: parent.right
        }

        height: 25
        onClicked: hlist.positionViewAtIndex(mouse.x / width * hlist.count, ListView.SnapPosition);

        Repeater {
            model: 3
            delegate: Text {
                x: index * width
                width: parent.width / 3
                text: index == 0 ? config.autoTr + qsTr("Global") : "<font color=\"#d3d2d9\">%1</font>/%2".arg(index).arg(2)
                horizontalAlignment: Text.AlignHCenter
                font.pixelSize: 20
                color: index == 0 ? "#d3d2d9" : "#707173"
            }
        }
    }
}
