import QtQuick 2.2
import Horus 1.0
import "../HorusComponents"

Image {
    property var insulationProcess
    property bool isUnderVoltage

    property int editPhase: 1
    property int displayedPhaseIndex: insulationProcess ? (insulationProcess.currentPhase || editPhase) - 1 : -1

    property var rzMsg: null

    source: "bg_central.png"

    Item {
        anchors {
            top: parent.top
            bottom: parent.bottom
            left: parent.left
        }
        width: 359

        /********************
        * Graph zone - auto *
        ********************/
        Item {
            id: graphzone_auto
            height: graph_auto.height + 60 + 30
            visible: insulationProcess && insulationProcess.parameters ? (insulationProcess.parameters.mode.value === ParamInsulation.Auto) : false

            anchors {
                left: parent.left
                right: parent.right
                bottom: parent.bottom
            }

            Item {
                id: graph_auto

                anchors {
                    left: parent.left
                    right: parent.right
                    bottom: parent.bottom
                    margins: 14
                    bottomMargin: 60
                }

                height: 150

                Rectangle {
                    anchors.fill: parent
                    anchors.rightMargin: 2
                    radius: 14
                    color: "#2a2939"
                }

                Button {
                    anchors {
                        top: parent.bottom
                        topMargin: 4
                        right: parent.right
                    }
                    srcImage: "next.png"
                    rectVisible: false
                    width: 32
                    opacity: (!isUnderVoltage && editPhase < 3 ? 1 : 0)
                    onClicked: editPhase = Math.min(editPhase + 1, 3)
                    Behavior on opacity { NumberAnimation { duration: 100 } }
                }

                Button {
                    anchors {
                        top: parent.bottom
                        topMargin: 4
                        left: parent.left
                    }
                    srcImage: "prev.png"
                    rectVisible: false
                    width: 32
                    opacity: (!isUnderVoltage && editPhase > 1 ? 1 : 0)
                    onClicked: editPhase = Math.max(editPhase - 1, 1)
                    Behavior on opacity { NumberAnimation { duration: 100 } }
                }

                Rectangle {
                    color: "#323140"
                    radius: 14
                    property real w: (parent.width - 20) / 3
                    x: displayedPhaseIndex * w
                    width: w + 20
                    height: parent.height

                    Behavior on x {
                        enabled: displayedPhaseIndex >= 0
                        NumberAnimation {
                            duration: 800
                            easing.type: Easing.OutExpo
                        }
                    }

                    Button { // Duration
                        id : duration_btn
                        property variant param: insulationProcess && insulationProcess.parameters && displayedPhaseIndex >= 0 &&  displayedPhaseIndex < 3? insulationProcess.parameters.phases[displayedPhaseIndex].time : {value: 0}

                        anchors {
                            top: parent.bottom
                            topMargin: 14
                            horizontalCenter: parent.horizontalCenter
                        }

                        //DavidTest
                        width: 70 /*105*/
                        height: 30
                        text: /*"Press Stop"*/
                            {
                                var nb = param.value * (1 - (insulationProcess && insulationProcess.parameters ? insulationProcess.stepPercent : 0));
                                if (!isUnderVoltage) nb = param.value;
                                return config.autoTr + qsTr("%1 s").arg(Number(nb).toFixed(1));
                            }
                        textColor: enabled ? (pressed ? UiConfig.colors.fg_pressed : UiConfig.colors.fg_active) : "#fff"
                        font.pixelSize: 16
                        enabled: !isUnderVoltage && canChangeParameters && !remoteaccess.interfaceIsConnected

                        helpText: config.autoTr + qsTr("This button opens a keypad to edit this phase duration.")

                        startRelated: true

                        onClicked: {rzMsg = popup().editParam(param); disableButtons();}

                        visible: true

                        Connections {
                            target: insulationProcess.parameters.phases[1].time
                            onValueChanged: {
                                // Si la phase est une phase de maintien et qu'on la paramète à 0s alors une message d'erreur est affiché
                                if (insulationProcess.parameters.phases[1].time.value < 0.1) {
                                    rzMsg = popup().msg(qsTr("Value error"), qsTr("Holding phase can't last 0s"), [qsTr("Ok")]);
                                    disableButtons();
                                    insulationProcess.parameters.phases[1].time.value = 0.1;
                                }
                            }
                        }
                    }

                    Button { // Finished
                        id :end_btn
                        anchors {
                            top: parent.bottom
                            topMargin: 14
                            horizontalCenter: parent.horizontalCenter
                        }
                        width: 105
                        height: 30
                        text: ""
                        textColor: "#fff"
                        enabled: false

                        visible: false

                        //MARTIAL
                        SequentialAnimation {
                            id: anim
                            running: end_btn.visible
                            loops: Animation.Infinite
                            PropertyAnimation { target: end_btn; property: "text"; to: "Press Stop"; duration: 500 }
                            PropertyAnimation { target: end_btn; property: "text"; to: ""; duration: 500 }
                        }
                    }
                }

                Repeater {
                    model: insulationProcess && insulationProcess.parameters ? 3 : 0
                    delegate: MouseArea {
                        property real w: (graph_auto.width - 20) / (insulationProcess && insulationProcess.parameters ? 3 : 3)
                        anchors.bottom: graph_auto.bottom
                        x: index * w + 11
                        width: w
                        height: graph_auto.height + 35
                        onClicked: editPhase = index + 1

                        Text {
                            anchors {
                                top: parent.bottom
                                topMargin: -30
                                left: parent.left
                                right: parent.right
                            }
                            text: index + 1
                            color: index == displayedPhaseIndex ? "#e8e8f0" : "#807c90"
                            horizontalAlignment: Text.AlignHCenter
                            Behavior on color { ColorAnimation {} }
                        }

                        Image {
                            anchors {
                                bottom: parent.bottom
                                bottomMargin: 2
                                right: parent.right
                            }
                            source: "separator.png"
                            visible: index != (insulationProcess ? 3 : 3) - 1
                        }
                    }
                }
                //DavidTest
                InsulationGraph {
                    anchors.fill: parent

                    mode: insulationProcess.parameters.mode.value
                    nbPhases: 3
                    valuePhase1: insulationProcess && insulationProcess.parameters.voltage ? insulationProcess.parameters.voltage.value : 0
                    valuePhase2: insulationProcess && insulationProcess.parameters.voltage ? insulationProcess.parameters.voltage.value : 0
                    valuePhase3: 0

                    stepStatus1: graphzone_auto.visible ? (insulationProcess ? insulationProcess.phases[0].status : InsulationProcess.OFF) : InsulationProcess.OFF
                    stepStatus2: graphzone_auto.visible ? (insulationProcess ? insulationProcess.phases[1].status : InsulationProcess.OFF) : InsulationProcess.OFF
                    stepStatus3:graphzone_auto.visible ?  (insulationProcess ? insulationProcess.phases[2].status : InsulationProcess.OFF) : InsulationProcess.OFF


                    phasePercent: graphzone_auto.visible ? (insulationProcess ? insulationProcess.stepPercent : 0) : 0
                    currentPhase: graphzone_auto.visible ? (insulationProcess ? insulationProcess.currentPhase : -1 ) : -1

//                    stepStatus1: InsulationProcess.PASS
//                    stepStatus2: InsulationProcess.PASS
//                    stepStatus3: InsulationProcess.PASS

//                    phasePercent: 1
//                    currentPhase: 3
                }
            }
        }

        /*************************
        * Graph zone - permanent *
        *************************/
        Item {
            id: graphzone_permanent

            height: graph_permanent.height + 60 + 30
            visible: insulationProcess && insulationProcess.parameters ? (insulationProcess.parameters.mode.value === ParamInsulation.Permanent) : false

            anchors {
                left: parent.left
                right: parent.right
                bottom: parent.bottom
            }

            Item {
                id: graph_permanent

                anchors {
                    left: parent.left
                    right: parent.right
                    bottom: parent.bottom
                    margins: 14
                    bottomMargin: 60
                }

                height: 150

                Rectangle {
                    anchors.fill: parent
                    anchors.rightMargin: 2
                    radius: 14
                    color: "#2a2939"
                }

                Button {
                    anchors {
                        top: parent.bottom
                        topMargin: 4
                        right: parent.right
                    }
                    srcImage: "next.png"
                    rectVisible: false
                    width: 32
                    opacity: (!isUnderVoltage && editPhase < 2 ? 1 : 0)
                    onClicked: editPhase = Math.min(editPhase + 1, 3)
                    Behavior on opacity { NumberAnimation { duration: 100 } }
                }

                Button {
                    anchors {
                        top: parent.bottom
                        topMargin: 4
                        left: parent.left
                    }
                    srcImage: "prev.png"
                    rectVisible: false
                    width: 32
                    opacity: (!isUnderVoltage && editPhase > 1 ? 1 : 0)
                    onClicked: editPhase = Math.max(editPhase - 1, 1)
                    Behavior on opacity { NumberAnimation { duration: 100 } }
                }

                Rectangle {
                    id: rect_surbrillant
                    color: "#323140"
                    radius: 14
                    property real w: (parent.width - 20) / 3
                    x: displayedPhaseIndex < 2 ? displayedPhaseIndex * w : (displayedPhaseIndex-1) * w
                    width: w  * (displayedPhaseIndex === 0 ? 1 : 2) + 20
                    height: parent.height

                    Behavior on x {
                        enabled: displayedPhaseIndex >= 0
                        NumberAnimation {
                            duration: 800
                            easing.type: Easing.OutExpo
                        }
                    }

                    Button { // Duration
                        id : rise_duration_btn
                        property variant param: insulationProcess && insulationProcess.parameters && displayedPhaseIndex === 0 ? insulationProcess.parameters.phases[0].time : {value: 0}

                        anchors {
                            top: parent.bottom
                            topMargin: 14
                            horizontalCenter: parent.horizontalCenter
                        }

                        width: 95
                        height: 30
                        text: {
                            var dur = "";
                            if (!isUnderVoltage) {
                                dur = Number(param.value).toFixed(1) + " s";
                            }
                            else dur = insulationProcess && insulationProcess.parameters ? insulationProcess.durationText : "";
                            return config.autoTr + dur;
                        }

                        textColor: enabled ? (pressed ? UiConfig.colors.fg_pressed : UiConfig.colors.fg_active) : "#fff"
                        font.pixelSize: 16
                        enabled: !isUnderVoltage && canChangeParameters && !remoteaccess.interfaceIsConnected

                        helpText: config.autoTr + qsTr("Open the edition of rise time.")

                        startRelated: true

                        onClicked: {rzMsg = popup().editParam(param); disableButtons();}

                        visible: !isUnderVoltage ? (displayedPhaseIndex === 0) : true
                    }
                }

                Repeater {
                    model: insulationProcess && insulationProcess.parameters ? 2 : 0
                    delegate: MouseArea {
                        property real w: (graph_permanent.width - 20) / 3
                        anchors.bottom: graph_permanent.bottom
                        x: index * w + 11
                        width: (index+1)*w
                        height: graph_permanent.height + 35
                        onClicked: editPhase = index + 1

                        Text {
                            anchors {
                                top: parent.bottom
                                topMargin: -30
                                left: parent.left
                                leftMargin: index === 1 ? w : w/2
                                right: parent.right
                            }
                            text: insulationProcess.running ? "" : index + 1
                            color: index == displayedPhaseIndex ? "#e8e8f0" : "#807c90"
                            Behavior on color { ColorAnimation {} }
                        }

                        Image {
                            anchors {
                                bottom: parent.bottom
                                bottomMargin: 2
                                right: parent.right
                            }
                            source: "separator.png"
                            visible: index != (insulationProcess ? 2 : 2) - 1
                        }
                    }
                }

                InsulationGraph {
                    id: graph
                    anchors.fill: parent

                    mode: insulationProcess.parameters.mode.value
                    nbPhases: 3
                    valuePhase1: insulationProcess && insulationProcess.parameters.voltage ? insulationProcess.parameters.voltage.value : 0
                    valuePhase2: insulationProcess && insulationProcess.parameters.voltage ? insulationProcess.parameters.voltage.value : 0
                    valuePhase3:  0

                    stepStatus1: graphzone_permanent.visible ? (insulationProcess ? insulationProcess.phases[0].status : InsulationProcess.OFF) : InsulationProcess.OFF
                    stepStatus2: graphzone_permanent.visible ? (insulationProcess ? insulationProcess.phases[1].status : InsulationProcess.OFF) : InsulationProcess.OFF
                    stepStatus3: graphzone_permanent.visible ? (insulationProcess ? insulationProcess.phases[1].status : InsulationProcess.OFF) : InsulationProcess.OFF
                    phasePercent: graphzone_permanent.visible ? (insulationProcess ? insulationProcess.stepPercent : 0) : 0
                    currentPhase: graphzone_permanent.visible ? (insulationProcess ? insulationProcess.graphiqPhase : -1) : 0
                }
            }
        }

        /*****************
        * Result message *
        *****************/
        TestStatus {
            anchors {
                top: parent.top
                left: parent.left
                right: parent.right
            }
            height: 70
            //DavidTest
            state: insulationProcess ? insulationProcess.status: "" /*InsulationProcess.FAIL*/
            errorText: insulationProcess ? insulationProcess.errorText : ""
        }
    }

    /*******************
    * Live report zone *
    *******************/
    MeasureCarousselGndBond {
        id: livereport_internal

        anchors {
            top: parent.top
            bottom: parent.bottom
            left: parent.left
            leftMargin: 359
            right: parent.right
        }
        //DavidTest
        u: insulationProcess ? (insulationProcess.voltageText ? insulationProcess.voltageText: "") : ""
        r: insulationProcess ? (insulationProcess.resistanceText ? insulationProcess.resistanceText: "") : ""
        i: insulationProcess ? (insulationProcess.currentText ? insulationProcess.currentText: "") : ""

        uunit: insulationProcess ? (insulationProcess.voltageUnit ? insulationProcess.voltageUnit : "") : ""
        runit: insulationProcess ? (insulationProcess.resistanceUnit ? insulationProcess.resistanceUnit : "" ) : ""
        iunit: insulationProcess ? (insulationProcess.currentUnit ? insulationProcess.currentUnit : "") : ""

//        u: "0"
//        r: "1,33"
//        i: "0,752"

//        uunit: "V"
//        runit: "TΩ"
//        iunit: "nA"

        ulast: ""
        rlast: insulationProcess ? insulationProcess.errorText : ""
        ilast: insulationProcess ? insulationProcess.errorText : ""

        ulength: insulationProcess ? (insulationProcess.voltageTextLength ? insulationProcess.voltageTextLength :3) :3
        rlength: insulationProcess ? (insulationProcess.resistanceTextLength ? insulationProcess.resistanceTextLength :4) :4
        ilength: insulationProcess ? (insulationProcess.currentTextLength ? insulationProcess.currentTextLength :4) :4

        filter: insulationProcess ? (insulationProcess.parameters.filter.value === ParamInsulation.CAPACITIVE ? "Capa.png" :  "") :""
    }

    Connections {
        target: insulationProcess
        onStatusChanged : {
            if (insulationProcess.status === InsulationProcess.OFF || insulationProcess.status === PicoammeterProcess.NORMAL) {
                end_btn.visible = false;
                duration_btn.visible = true;
            }
        }
        onFinished : {
            //Si le status est à OFF quand on reçoit le signal Fin de Test c'est que l'utilisateur à appuyer sur STOP
            //Pas besoin du message "Press Stop" dans ce cas
            if(insulationProcess.status !== InsulationProcess.OFF) {
                duration_btn.visible = false;
                end_btn.visible = true;
            }
        }
    }

    function disableButtons(){
        hal.setStartLight(false);
        hal.setStopLight(false);
    }
}
