import QtQuick 2.4
import Horus 1.0

   Item {
       id:item
       property string errorText: ""
       property bool painted: false

    Row {
        id: row
        anchors.centerIn: parent

        anchors.verticalCenterOffset: 25

        state: parent.state
        spacing: 10

        Canvas {
            id: teststatus

            property string text: ""
            property string code: ""
            property bool onoff
            property color color
            property color shadow

            visible: false
            implicitWidth: metrics.width + 30
            implicitHeight: metrics.height + 45

            renderStrategy: Canvas.Threaded

            onPaint: {
                visible = false;
                item.painted = false;
                var ctx = getContext("2d");
                ctx.reset();
                ctx.font = "40px Days";
                ctx.save();
                ctx.shadowColor = shadow
                ctx.shadowOffsetX = 0;
                ctx.shadowOffsetY = 0;
                //Modif LN 12/02/2020 : l'utilisation d'un shadowBlur génère un temps de 50 à 150ms pour le traçage de la courbe
                //                      temps durant lequel les autres signaux de l'appli ne sont pas pris en compte
                //                      (Ex: signal buttonStopPressed n'est pris en compte qu'après traçage de la courbe et ne permet pas
                //                      une bonne prise en compte d'un arrêt d'urgence)
//                ctx.shadowBlur = 10;
                    ctx.fillText(text,10,50);
                    ctx.restore();
                    ctx.lineWidth = 1.5;
                    ctx.strokeStyle = "#ffffff"
                    ctx.fillStyle = color
                    ctx.fillText(text,10,50);
                    ctx.strokeText(text,10,50)

                    ctx.font = "40px Days";
                    ctx.fillText(text,10,50);
                    ctx.restore();
                    ctx.lineWidth = 1.5;
                    ctx.strokeStyle = "#ffffff"
                    ctx.fillStyle = color
                    ctx.font = "40px Days";
                    ctx.fillText(text,10,50);
                    ctx.strokeText(text,10,50);
            }
            onPainted: {
                visible = true;
                item.painted = true;
             }

            onTextChanged: requestPaint()

            TextMetrics {
                id: metrics
                text: teststatus.text
                font.pixelSize: 40
            }
        }

        Rectangle{
            //Utile car on centre la sentence et lorsque l'image clignote le centrage est modifié sans ce rectangle
            id:image_spot
            anchors.verticalCenter: parent.verticalCenter
            anchors.verticalCenterOffset: -15
            color: "transparent"
            width: 55
            height: 55
            Image {
                id: image
                anchors.fill: parent
                fillMode: Image.PreserveAspectFit
                source: "warning.png"
                visible: false
            }
        }

        states: [
            State {
                name: InsulationProcessPhaseReport.PASS // PASS
                PropertyChanges {
                    target: teststatus
                    text: config.autoTr + qsTr(" \u2713 PASS")
                    color: config.resultPassColor
                    shadow: config.resultPassColor
                }
                PropertyChanges {
                    target: image_spot
                    visible: false
                }
            },
            State {
                name: InsulationProcessPhaseReport.FAIL // FAIL
                PropertyChanges {
                    target: teststatus
                    text: config.autoTr + qsTr(" \u2715 FAIL")
                    color: config.resultFailColor
                    shadow: config.resultFailColor
                }
                PropertyChanges {
                    target: image_spot
                    visible: false
                }
            },
            State {
                name: InsulationProcessPhaseReport.ERROR // ERROR
                PropertyChanges {
                    target: teststatus
                    text: config.autoTr +  qsTr(" \u2715 ERROR")
                    code: config.autoTr + errorText
                    onoff: true
                    color: config.resultErrorColor
                    shadow: config.resultErrorColor
                }
                PropertyChanges {
                    target: image_spot
                    visible: false
                }
            },
            State {
                name: InsulationProcessPhaseReport.NORMAL // RUNNING
                PropertyChanges {
                    target: teststatus
                    text: config.autoTr + qsTr("RUNNING")
                    code: config.autoTr + errorText
                    onoff: true
                    color: "#ffd43b"
                    shadow: "#ff903c1f"
                }
                PropertyChanges {
                    target: image_spot
                    visible: true
                }
                //DavidTest
                PropertyChanges {
                    target: image
                    visible: hal.dangerLights && item.painted /*false*/
                }
            },
            State {
                name: InsulationProcessPhaseReport.OFF // OFF
                PropertyChanges {
                    target: teststatus
                    text: ""
                    visible: false
                }
                PropertyChanges {
                    target: image_spot
                    visible: false
                }
            }
        ]
    }
}
