import QtQuick 2.2
import Horus 1.0
import "../HorusComponents"

Item {
    property bool canChangeParameters: config.acl.value <= ParamGlobal.ADMINISTRATOR
    property bool canChangeProgram: config.acl.value <= ParamGlobal.TECHNICIAN

    ReportZone {
        id: reportZone
        anchors {
            top: parent.top
            left: parent.left
            leftMargin: 5
        }
        insulationProcess: process
        isUnderVoltage: page.isUnderVoltage
    }

    /*********************************
    * Right bar (params, list, help) *
    *********************************/
    RightBar {
        id: rightbar
        anchors {
            top: parent.top
            right: parent.right
            rightMargin: -10
        }
        enabled_help: !isUnderVoltage && !remoteaccess.interfaceIsConnected
        enabled_list: !isUnderVoltage && canChangeProgram && !remoteaccess.interfaceIsConnected
        enabled_settings: !isUnderVoltage && canChangeParameters && !remoteaccess.interfaceIsConnected
        stopMessage_visible: isUnderVoltage && process.finished

        startStopRelated: true
    }


    /*****************
    * Parameters row *
    *****************/
    Row {
        id: bottomrow

        anchors {
            left: parent.left
            bottom: parent.bottom
            bottomMargin: -10
        }

        spacing: 14

        ErrorButton { // Time
            property variant param: insulation.mode

            textTitle: config.autoTr + qsTr("Time")

             //DavidTest
            text: /*"0.0s"*/
            {
                if (param.value === ParamInsulation.Permanent) {
                    return param.text;
                }
                else {
                    var i, remaining = 0;
                    if (process.currentPhase > 0)
                        remaining = insulation.phases[process.currentPhase-1].time.value * (1 - process.stepPercent);
                    for (i = process.currentPhase || 1; i < 3; ++i)
                        remaining += insulation.phases[i].time.value
                    return config.autoTr + qsTr("%1 s").arg(Number(remaining).toFixed(1));
                }
            }
            color: param.value === ParamInsulation.Permanent ? UiConfig.colors.fg_inactive : "#fff"
            enabled: false
            visible: isUnderVoltage
        }

        ErrorButton { // Time
            property variant param: insulation.mode

            textTitle: config.autoTr + qsTr("Time")
            text: param.text
            enabled: canChangeParameters && param.modifiable && !remoteaccess.interfaceIsConnected
            visible: !isUnderVoltage
            helpText: qsTr("This button opens a list of the modes available for the megohmmeter function")

            onClicked: {msg = popup().editParam(param); disableButtons();}
        }

        ErrorButton { // Voltage
            id: param_voltage
            property variant param: insulation.voltage

            textTitle: "VDC"
            text: param.text

            enabled: !isUnderVoltage && canChangeParameters && param.modifiable && !remoteaccess.interfaceIsConnected

            helpText:qsTr("This button opens a keypad to edit the current value of your megohmmeter test")

            onClicked: {msg = popup().editParam(param); disableButtons();}
        }

        ErrorButton { // Rmin
            id: param_rMin

            property variant param: insulation.rMin

            textTitle: config.autoTr + qsTr("Rmin")
            text: param.text
            enabled: !isUnderVoltage && canChangeParameters && param.modifiable && !remoteaccess.interfaceIsConnected

            helpText:qsTr("This button opens a keypad to edit the minimum resistance value and unit of your megohmmeter test")

            onClicked: { msg = popup().editParam(param); disableButtons();console.log("rminMax = ", param.max," et insulation.rMin = ",insulation.rMin.max);}

            state: {
                var st = "";
                for (var i = 0; i < 3; ++i) {
                    if (process.phases[i].rMinStatus == InsulationProcessPhaseReport.ERROR) st = "error";
                    else if (process.phases[i].rMinStatus == InsulationProcessPhaseReport.FAIL) st = "fail";
                }
                return st;
            }
        }

        //DavidTest
        ErrorButton { // R max
            id: param_rMax
            property variant param: insulation.rMax


            textTitle: config.autoTr + qsTr("Rmax")
            text: param.text
            enabled: !isUnderVoltage && canChangeParameters && param.modifiable && !remoteaccess.interfaceIsConnected

            helpText:qsTr("This button opens a keypad to edit the maximum resistance value of your megohmmeter test")

            onClicked: {msg = popup().editParam(param); disableButtons();}

            state: {
                var st = "";
                for (var i = 0; i < 3; ++i) {
                    if (process.phases[i].rMaxStatus == InsulationProcessPhaseReport.ERROR) st = "error";
                    else if (process.phases[i].rMaxStatus == InsulationProcessPhaseReport.FAIL) st = "fail";
                }
                return st;
//                return "fail";
            }
        }

    }

    Connections {
        target: msg
        onClose: {
            //Dans le cas d'une double popup la condition popup.isOpened pose problème, on la contourne ici sachant qu'elle n'est qu'une sécurité
            hal.setStartLight(!remoteaccess.interfaceIsConnected && hal.safetyLoop /*&& !popup().isOpened()*/);
            hal.setStopLight(false);
        }
    }

    Connections {
        //Permet de ne pas rallumer le bouton start lors de l'ouverture de la pop up d'erreur lié au temps de maintien grace au booleen visible de cette page
        target: reportZone.rzMsg
        onClose: {
            //Dans le cas d'une double popup la condition popup.isOpened pose problème, on la contourne ici sachant qu'elle n'est qu'une sécurité
            hal.setStartLight(!remoteaccess.interfaceIsConnected && hal.safetyLoop && visible);
            hal.setStopLight(false);
        }
    }

    Component.onCompleted: {
        //On force un update pour que même l'instance de Paraminsulation créé au démarrage ait ses limites mises à jour
        insulation.updateComp();
    }

    function disableButtons(){
        hal.setStartLight(false);
        hal.setStopLight(false);
    }

}
