import QtQuick 2.2
import QtQuick.Controls 1.0
import Horus 1.0
import "../HorusComponents"


Page {
    id: insulationParameters

    property variant insulation: insulationLoader.data

    title: config.autoTr + qsTr("MΩ")
    headerButton {
        text: insulationLoader.filename
        onClicked: {
            popup().editText(
                qsTr("Filename"),
                insulationLoader.filename,
                function (name) {
                    if (name !== undefined) {
                        if (insulationLoader.exists(name)) {
                            popup().msg(qsTr("Warning"), qsTr("There is already a configuration named \"%1\". Do you want to overwrite it ?").arg(insulationLoader.data.sanitizeName(name)), [qsTr("Overwrite"), qsTr("Cancel")], function(nr) {
                                if (nr === 0) {
                                    insulationLoader.data.copyToStorage(name);
                                    config.insulationConfig = name;
                                    return true;
                                } else if (nr === 1) {
                                    return true;
                                }
                                return false;
                            }, /* replace: */ true);
                            return false;
                        }
                        else {
                            popup().msg(qsTr("Rename"), qsTr("Do you want to rename \"%1\" or do you want to duplicate \"%1\" and rename it ?").arg(config.insulationConfig), [qsTr("Rename"), qsTr("Duplicate & Rename")], function(nr) {
                                if (nr === 1) {
                                    insulationLoader.data.copyToStorage(name);
                                    config.insulationConfig = name;
                                    return true;
                                } else if (nr === 0) {
                                    insulationLoader.data.copyToStorage(name);
                                    insulationLoader.remove(config.insulationConfig);
                                    config.insulationConfig = name;
                                    return true;
                                }
                                return false;
                            }, /* replace: */ true)
                        }
                    }
                    return (true);
                }, false, "^[a-zA-Z0-9_-]{1,100}$");
        }
    }

    ParamInsulationLoader {
        id: insulationLoader
        filename: config.insulationConfig
    }

    Loader {
        id: innerpage
        anchors {
            top: parent.top
            bottom: parent.bottom
            left: parent.left
            right: rightColumn.left
            rightMargin: 10
        }
        source: /*insulation.mode.value === ParamInsulation.Auto ?*/ "auto.qml" /*: "manual.qml"*/ // TODO: mettre le mode permanent
    }

    Column {
        id: rightColumn

        anchors {
            top: parent.top
            right: parent.right
            rightMargin: -10
        }

        spacing: 10

        ButtonList {
            helpText: config.autoTr + qsTr("This button opens file list parameters.")

            onClicked: {
                var nb = 0;
                for (nb in insulationLoader.filesList) {
                    if (insulationLoader.filesList[nb] == config.insulationConfig)
                        break;
                    nb++;
                }
                msg = popup().manageFiles(qsTr("Change settings"), insulationLoader.filesList, nb, insulationLoader,
                function(nl) {
                    if (nl !== undefined) {
                        config.insulationConfig = nl;
                    }
                },
                function(nr) {
                    return true;
                });
                disableButtons();

            }
        }

        ButtonHelp {
            helpText: config.autoTr + qsTr("This button opens help.")
        }

        ButtonPlay {
            helpText: config.autoTr + qsTr("This button opens live report back")
            onClicked: back_page()
        }
    }
}




