import QtQuick 2.2
import Horus 1.0
import "../HorusComponents"

Image {
    property var megohmmeterProcess
    property bool isUnderVoltage

    property int editPhase: 1
    property int displayedPhaseIndex: megohmmeterProcess ? (megohmmeterProcess.currentPhase || editPhase) - 1 : -1

    property var rzMsg: null

    source: "bg_central.png"

    Item {
        anchors {
            top: parent.top
            bottom: parent.bottom
            left: parent.left
        }
        width: 359

        /********************
        * Graph zone - auto *
        ********************/
        Item {
            id: graphzone_auto
            height: graph_auto.height + 60 + 30
            visible: megohmmeterProcess && megohmmeterProcess.parameters ? (megohmmeterProcess.parameters.mode.value === ParamMegohmmeter.Auto) : false

            anchors {
                left: parent.left
                right: parent.right
                bottom: parent.bottom
            }

            Item {
                id: graph_auto

                anchors {
                    left: parent.left
                    right: parent.right
                    bottom: parent.bottom
                    margins: 14
                    bottomMargin: 60
                }

                height: 150

                Rectangle {
                    anchors.fill: parent
                    anchors.rightMargin: 2
                    radius: 14
                    color: "#2a2939"
                }

                Button {
                    anchors {
                        top: parent.bottom
                        topMargin: 4
                        right: parent.right
                    }
                    srcImage: "next.png"
                    rectVisible: false
                    width: 32
                    opacity: (!isUnderVoltage && editPhase < 3 ? 1 : 0)
                    onClicked: editPhase = Math.min(editPhase + 1, 3)
                    Behavior on opacity { NumberAnimation { duration: 100 } }
                }

                Button {
                    anchors {
                        top: parent.bottom
                        topMargin: 4
                        left: parent.left
                    }
                    srcImage: "prev.png"
                    rectVisible: false
                    width: 32
                    opacity: (!isUnderVoltage && editPhase > 1 ? 1 : 0)
                    onClicked: editPhase = Math.max(editPhase - 1, 1)
                    Behavior on opacity { NumberAnimation { duration: 100 } }
                }

                Rectangle {
                    color: "#323140"
                    radius: 14
                    property real w: (parent.width - 20) / /*(megohmmeterProcess && megohmmeterProcess.parameters ? 3 : 3)*/3
                    x: displayedPhaseIndex * w
                    width: w + 20
                    height: parent.height

                    Behavior on x {
                        enabled: displayedPhaseIndex >= 0
                        NumberAnimation {
                            duration: 800
                            easing.type: Easing.OutExpo
                        }
                    }

                    Button { // Duration
                        id : duration_btn
                        property variant param: megohmmeterProcess && megohmmeterProcess.parameters && displayedPhaseIndex >= 0 &&  displayedPhaseIndex < 3? megohmmeterProcess.parameters.phases[displayedPhaseIndex].time : {value: 0}

                        anchors {
                            top: parent.bottom
                            topMargin: 14
                            horizontalCenter: parent.horizontalCenter
                        }

                        width: 70
                        height: 30
                        text: {
                            var nb = param.value * (1 - (megohmmeterProcess && megohmmeterProcess.parameters ? megohmmeterProcess.stepPercent : 0));
                            if (!isUnderVoltage) nb = param.value;
                            return config.autoTr + qsTr("%1 s").arg(Number(nb).toFixed(1));
                        }
                        textColor: enabled ? (pressed ? UiConfig.colors.fg_pressed : UiConfig.colors.fg_active) : "#fff"
                        font.pixelSize: 16
                        enabled: !isUnderVoltage && canChangeParameters  && !remoteaccess.interfaceIsConnected

                        helpText: config.autoTr + qsTr("This button opens a keypad to edit this phase duration.")

                        startRelated: true

                        onClicked: {rzMsg = popup().editParam(param); disableButtons();}

                        visible: true

                        Connections {
                            target: megohmmeterProcess.parameters.phases[1].time
                            onValueChanged: {
                                // Si la phase est une phase de maintien et qu'on la paramète à 0s alors une message d'erreur est affiché
                                if (megohmmeterProcess.parameters.phases[1].time.value < 0.1) {
                                    rzMsg = popup().msg(qsTr("Value error"), qsTr("Holding phase can't last 0s"), [qsTr("Ok")]);
                                    disableButtons();
                                    megohmmeterProcess.parameters.phases[1].time.value = 0.1;
                                }
                            }
                        }
                    }

                    Button { // Finished
                        id :end_btn
                        anchors {
                            top: parent.bottom
                            topMargin: 14
                            horizontalCenter: parent.horizontalCenter
                        }
                        width: 105
                        height: 30
                        text: ""
                        textColor: "#fff"
                        enabled: false

                        visible: false

                        //MARTIAL
                        SequentialAnimation {
                            id: anim
                            running: end_btn.visible
                            loops: Animation.Infinite
                            PropertyAnimation { target: end_btn; property: "text"; to: "Press Stop"; duration: 500 }
                            PropertyAnimation { target: end_btn; property: "text"; to: ""; duration: 500 }
                        }
                    }
                }

                Repeater {
                    model: megohmmeterProcess && megohmmeterProcess.parameters ? 3 : 0
                    delegate: MouseArea {
                        property real w: (graph_auto.width - 20) / (megohmmeterProcess && megohmmeterProcess.parameters ? 3 : 3)
                        anchors.bottom: graph_auto.bottom
                        x: index * w + 11
                        width: w
                        height: graph_auto.height + 35
                        onClicked: editPhase = index + 1

                        Text {
                            anchors {
//                                top: parent.top
                                top: parent.bottom
                                topMargin: -30
                                left: parent.left
                                right: parent.right
                            }
                            text: index + 1
                            color: index == displayedPhaseIndex ? "#e8e8f0" : "#807c90"
                            horizontalAlignment: Text.AlignHCenter
                            Behavior on color { ColorAnimation {} }
                        }

                        Image {
                            anchors {
                                bottom: parent.bottom
                                bottomMargin: 2
                                right: parent.right
                            }
                            source: "separator.png"
                            visible: index != (megohmmeterProcess ? 3 : 3) - 1
                        }
                    }
                }

                MegohmmeterGraph {
                    anchors.fill: parent

                    mode: megohmmeterProcess.parameters.mode.value
                    nbPhases: 3
                    valuePhase1: megohmmeterProcess && megohmmeterProcess.parameters.voltage ? megohmmeterProcess.parameters.voltage.value : 0
                    valuePhase2: megohmmeterProcess && megohmmeterProcess.parameters.voltage ? megohmmeterProcess.parameters.voltage.value : 0
                    valuePhase3: 0

                    //DavidTest
                    stepStatus1: graphzone_auto.visible ? (megohmmeterProcess ? megohmmeterProcess.phases[0].status : MegohmmeterProcess.OFF) : MegohmmeterProcess.OFF/*MegohmmeterProcess.FAIL*/
                    stepStatus2: graphzone_auto.visible ? (megohmmeterProcess ? megohmmeterProcess.phases[1].status : MegohmmeterProcess.OFF) : MegohmmeterProcess.OFF/*MegohmmeterProcess.FAIL*/
                    stepStatus3:graphzone_auto.visible ?  (megohmmeterProcess ? megohmmeterProcess.phases[2].status : MegohmmeterProcess.OFF) : MegohmmeterProcess.OFF/*MegohmmeterProcess.FAIL*/

                    //DavidTest
                    phasePercent: graphzone_auto.visible ? (megohmmeterProcess ? megohmmeterProcess.stepPercent : 0) : 0 /*1*/
                    currentPhase: graphzone_auto.visible ? (megohmmeterProcess ? megohmmeterProcess.currentPhase : -1 ) : -1/*3*/
                }
            }
        }

        /*************************
        * Graph zone - permanent *
        *************************/
        Item {
            id: graphzone_permanent

            height: graph_permanent.height + 60 + 30
            visible: megohmmeterProcess && megohmmeterProcess.parameters ? (megohmmeterProcess.parameters.mode.value === ParamMegohmmeter.Permanent) : false

            anchors {
                left: parent.left
                right: parent.right
                bottom: parent.bottom
            }

            Item {
                id: graph_permanent

                anchors {
                    left: parent.left
                    right: parent.right
                    bottom: parent.bottom
                    margins: 14
                    bottomMargin: 60
                }

                height: 150

                Rectangle {
                    anchors.fill: parent
                    anchors.rightMargin: 2
                    radius: 14
                    color: "#2a2939"
                }

                Button {
                    anchors {
                        top: parent.bottom
                        topMargin: 4
                        right: parent.right
                    }
                    srcImage: "next.png"
                    rectVisible: false
                    width: 32
                    opacity: (!isUnderVoltage && editPhase < 2 ? 1 : 0)
                    onClicked: editPhase = Math.min(editPhase + 1, 3)
                    Behavior on opacity { NumberAnimation { duration: 100 } }
                }

                Button {
                    anchors {
                        top: parent.bottom
                        topMargin: 4
                        left: parent.left
                    }
                    srcImage: "prev.png"
                    rectVisible: false
                    width: 32
                    opacity: (!isUnderVoltage && editPhase > 1 ? 1 : 0)
                    onClicked: editPhase = Math.max(editPhase - 1, 1)
                    Behavior on opacity { NumberAnimation { duration: 100 } }
                }

                Rectangle {
                    id: rect_surbrillant
                    color: "#323140"
                    radius: 14
                    property real w: (parent.width - 20) / 3
                    x: displayedPhaseIndex < 2 ? displayedPhaseIndex * w : (displayedPhaseIndex-1) * w
                    width: w  * (displayedPhaseIndex === 0 ? 1 : 2) + 20
                    height: parent.height

                    Behavior on x {
                        enabled: displayedPhaseIndex >= 0
                        NumberAnimation {
                            duration: 800
                            easing.type: Easing.OutExpo
                        }
                    }

                    Button { // Duration
                        id : rise_duration_btn
                        property variant param: megohmmeterProcess && megohmmeterProcess.parameters && displayedPhaseIndex === 0 ? megohmmeterProcess.parameters.phases[0].time : {value: 0}

                        anchors {
                            top: parent.bottom
                            topMargin: 14
                            horizontalCenter: parent.horizontalCenter
                        }

                        width: 95
                        height: 30
                        text: {
                            var dur = "";
                            if (!isUnderVoltage) {
                                dur = Number(param.value).toFixed(1) + " s";
                            }
                            else dur = megohmmeterProcess && megohmmeterProcess.parameters ? megohmmeterProcess.durationText : "";
                            return config.autoTr + dur;
                        }

                        textColor: enabled ? (pressed ? UiConfig.colors.fg_pressed : UiConfig.colors.fg_active) : "#fff"
                        font.pixelSize: 16
                        enabled: !isUnderVoltage && canChangeParameters  && !remoteaccess.interfaceIsConnected

                        helpText: config.autoTr + qsTr("Open the edition of rise time.")

                        startRelated: true

                        onClicked: {rzMsg = popup().editParam(param); disableButtons();}

                        visible: !isUnderVoltage ? (displayedPhaseIndex === 0) : true
                    }
                }

                Repeater {
                    model: megohmmeterProcess && megohmmeterProcess.parameters ? 2 : 0
                    delegate: MouseArea {
                        property real w: (graph_permanent.width - 20) / 3
                        anchors.bottom: graph_permanent.bottom
                        x: index * w + 11
                        width: (index+1)*w
                        height: graph_permanent.height + 35
                        onClicked: editPhase = index + 1

                        Text {
                            anchors {
                                top: parent.bottom
                                topMargin: -30
                                left: parent.left
                                leftMargin: index === 1 ? w : w/2
                                right: parent.right
                            }
                            text: megohmmeterProcess.running ? "" : index + 1
                            color: index == displayedPhaseIndex ? "#e8e8f0" : "#807c90"
                            Behavior on color { ColorAnimation {} }
//                            visible: !megohmmeterProcess.running
                        }

                        Image {
                            anchors {
                                bottom: parent.bottom
                                bottomMargin: 2
                                right: parent.right
                            }
                            source: "separator.png"
                            visible: index != (megohmmeterProcess ? 2 : 2) - 1
                        }
                    }
                }

                MegohmmeterGraph {
                    id: graph
                    anchors.fill: parent

                    mode: megohmmeterProcess.parameters.mode.value
                    nbPhases: 3
                    valuePhase1: megohmmeterProcess && megohmmeterProcess.parameters.voltage ? megohmmeterProcess.parameters.voltage.value : 0
                    valuePhase2: megohmmeterProcess && megohmmeterProcess.parameters.voltage ? megohmmeterProcess.parameters.voltage.value : 0
                    valuePhase3:  0

                    stepStatus1: graphzone_permanent.visible ? (megohmmeterProcess ? megohmmeterProcess.phases[0].status : MegohmmeterProcess.OFF) : MegohmmeterProcess.OFF
                    stepStatus2: graphzone_permanent.visible ? (megohmmeterProcess ? megohmmeterProcess.phases[1].status : MegohmmeterProcess.OFF) : MegohmmeterProcess.OFF
                    stepStatus3: graphzone_permanent.visible ? (megohmmeterProcess ? megohmmeterProcess.phases[1].status : MegohmmeterProcess.OFF) : MegohmmeterProcess.OFF
                    phasePercent: graphzone_permanent.visible ? (megohmmeterProcess ? megohmmeterProcess.stepPercent : 0) : 0
                    currentPhase: graphzone_permanent.visible ? (megohmmeterProcess ? megohmmeterProcess.graphiqPhase : -1) : 0
                }
            }
        }

        /*****************
        * Result message *
        *****************/
        TestStatus {
            anchors {
                top: parent.top
                left: parent.left
                right: parent.right
            }
            height: 70
            state: megohmmeterProcess ? megohmmeterProcess.status: ""
            errorText: megohmmeterProcess ? megohmmeterProcess.errorText : ""
        }
    }

    /*******************
    * Live report zone *
    *******************/
    MeasureCarousselGndBond {
        id: livereport_internal

        anchors {
            top: parent.top
            bottom: parent.bottom
            left: parent.left
            leftMargin: 359
            right: parent.right
        }
        //DavidTest
        u: megohmmeterProcess ? (megohmmeterProcess.voltageText ? megohmmeterProcess.voltageText: "") : "" /*"1500"*/
        r: megohmmeterProcess ? (megohmmeterProcess.resistanceText ? megohmmeterProcess.resistanceText: "") : "" /*"7777"*/
        i: megohmmeterProcess ? (megohmmeterProcess.currentText ? megohmmeterProcess.currentText: "") : "" /*"163"*/

        uunit: megohmmeterProcess ? (megohmmeterProcess.voltageUnit ? megohmmeterProcess.voltageUnit : "") : ""
        runit: megohmmeterProcess ? (megohmmeterProcess.resistanceUnit ? /*(megohmmeterProcess.parameters.megohmkm.value === ParamMegohmmeter.ON ? "MΩ.km" : */megohmmeterProcess.resistanceUnit/*)*/ : "") : "" /*"TΩ"*/
        iunit: megohmmeterProcess ? (megohmmeterProcess.currentUnit ? megohmmeterProcess.currentUnit : "") : "" /*"pA"*/

        ulast: ""
        rlast: megohmmeterProcess ? megohmmeterProcess.errorText : ""
        ilast: megohmmeterProcess ? megohmmeterProcess.errorText : ""

        ulength: megohmmeterProcess ? (megohmmeterProcess.voltageTextLength ? megohmmeterProcess.voltageTextLength :3) :3
        rlength: megohmmeterProcess ? (megohmmeterProcess.resistanceTextLength ? megohmmeterProcess.resistanceTextLength :4) :4
        ilength: megohmmeterProcess ? (megohmmeterProcess.currentTextLength ? megohmmeterProcess.currentTextLength :4) :4

        filter: megohmmeterProcess ? (megohmmeterProcess.parameters.filter.value === ParamMegohmmeter.CAPA1 ? "Cable.png" : (megohmmeterProcess.parameters.filter.value === ParamMegohmmeter.CAPA2 ? "Capa.png" : "")) :""

        currentLimitation: config.currentMax1500 < 0.004
    }

    Connections {
        target: megohmmeterProcess
        onStatusChanged : {
            if (megohmmeterProcess.status === MegohmmeterProcess.OFF || megohmmeterProcess.status === PicoammeterProcess.NORMAL) {
                end_btn.visible = false;
                duration_btn.visible = true;
            }
        }
        onFinished : {
            //Si le status est à OFF quand on reçoit le signal Fin de Test c'est que l'utilisateur à appuyer sur STOP
            //Pas besoin du message "Press Stop" dans ce cas
            if(megohmmeterProcess.status !== MegohmmeterProcess.OFF) {
                duration_btn.visible = false;
                end_btn.visible = true;
            }
        }
    }

    function disableButtons(){
        hal.setStartLight(false);
        hal.setStopLight(false);
    }
}
