import QtQuick 2.2
import Horus 1.0
import "../HorusComponents"

Item {
    property bool canChangeParameters: config.acl.value <= ParamGlobal.ADMINISTRATOR
    property bool canChangeProgram: config.acl.value <= ParamGlobal.TECHNICIAN
    property var msg: null

    ReportZone {
        id: reportZone
        anchors {
            top: parent.top
            left: parent.left
            leftMargin: 5
        }
        megohmmeterProcess: process
        isUnderVoltage: page.isUnderVoltage
    }

    /*********************************
    * Right bar (params, list, help) *
    *********************************/
    RightBar {
        id: rightbar
        anchors {
            top: parent.top
            right: parent.right
            rightMargin: -10
        }
        enabled_help: !isUnderVoltage && !remoteaccess.interfaceIsConnected
        enabled_list: !isUnderVoltage && canChangeProgram && !remoteaccess.interfaceIsConnected
        enabled_settings: !isUnderVoltage && canChangeParameters && !remoteaccess.interfaceIsConnected
        stopMessage_visible: isUnderVoltage && process.finished

        startStopRelated: true

    }


    /*****************
    * Parameters row *
    *****************/
    Row {
        id: bottomrow

        anchors {
            horizontalCenter: parent.horizontalCenter
            bottom: parent.bottom
            bottomMargin: -10
        }

        spacing: 14

        ErrorButton { // Time
            property variant param: megohmmeter.mode

            textTitle: config.autoTr + qsTr("Time")
            text: {
                if (param.value === ParamMegohmmeter.Permanent) {
                    return param.text;
                }
                else {
                    var i, remaining = 0;
                    if (process.currentPhase > 0)
                        remaining = megohmmeter.phases[process.currentPhase-1].time.value * (1 - process.stepPercent);
                    for (i = process.currentPhase || 1; i < 3; ++i)
                        remaining += megohmmeter.phases[i].time.value
                    return config.autoTr + qsTr("%1 s").arg(Number(remaining).toFixed(1));
                }
            }

            startRelated: true

            color: param.value === ParamMegohmmeter.Permanent ? UiConfig.colors.fg_inactive : "#fff"
            enabled: false
            visible: isUnderVoltage
        }

        ErrorButton { // Time
            property variant param: megohmmeter.mode

            textTitle: config.autoTr + qsTr("Time")
            text: param.text
            enabled: canChangeParameters && param.modifiable && !remoteaccess.interfaceIsConnected
            visible: !isUnderVoltage
            helpText: qsTr("This button opens a list of the modes available for the megohmmeter function")

            startRelated: true

            onClicked: {msg = popup().editParam(param); disableButtons();}
        }

        ErrorButton { // Voltage
            id: param_voltage
            property variant param: megohmmeter.voltage

            textTitle: "VDC"
            text: param.text

            enabled: !isUnderVoltage && canChangeParameters && param.modifiable && !remoteaccess.interfaceIsConnected

            helpText:qsTr("This button opens a keypad to edit the voltage value of your megohmmeter test")

            startRelated: true

            onClicked: {msg = popup().editParam(param); disableButtons();}
        }

        ErrorButton { // Rmin
            id: param_rMin

            property variant param: megohmmeter.rMin

            textTitle: config.autoTr + qsTr("Rmin")
            //DavidTest
            text: param.text
            enabled: !isUnderVoltage && canChangeParameters && param.modifiable && !remoteaccess.interfaceIsConnected

            helpText:qsTr("This button opens a keypad to edit the minimum resistance limit of your megohmmeter test")


            startRelated: true

            onClicked: {msg = popup().editParam(param); disableButtons();}

            state: {
                var st = /*"fail"*/"";
                for (var i = 0; i < 3; ++i) {
                    if (process.phases[i].rMinStatus == MegohmmeterProcessPhaseReport.ERROR) st = "error";
                    else if (process.phases[i].rMinStatus == MegohmmeterProcessPhaseReport.FAIL) st = "fail";
                }
                return st;
            }
        }

        ErrorButton { // R max
            id: param_rMax
            property variant param: megohmmeter.rMax


            textTitle: config.autoTr + qsTr("Rmax")
            text: param.text
            enabled: !isUnderVoltage && canChangeParameters && param.modifiable && !remoteaccess.interfaceIsConnected

            helpText:qsTr("This button opens a keypad to edit the maximum resistance limit of your megohmmeter test")

            startRelated: true

            onClicked: {msg = popup().editParam(param); disableButtons();}

            state: {
                var st = "";
                for (var i = 0; i < 3; ++i) {
                    if (process.phases[i].rMaxStatus == MegohmmeterProcessPhaseReport.ERROR) st = "error";
                    else if (process.phases[i].rMaxStatus == MegohmmeterProcessPhaseReport.FAIL) st = "fail";
                }
                return st;
            }
        }

        ErrorButton { // Range
            id: param_range
            property variant param: megohmmeter.range

            textTitle: config.autoTr + qsTr("Range")
            text: param.text

            enabled: !isUnderVoltage && canChangeParameters && param.modifiable && !remoteaccess.interfaceIsConnected

            helpText:qsTr("This button indicate which range is applied during the test")

            /*
                Version modifiée par LN le 25/01/2017
                Modification : * Suppression de l'ouverture d'une pop-up pour le paramétrage du paramètre zéro.
                               * Ajout des modifications des paramètres du ErrorButton afin de mettre en exergue
                                  le paramètre de tarage quand il est actif.
            */


            startRelated: true

            onClicked: {msg = popup().editParam(param); disableButtons();}

            state: {
                var st = "";
                    if (process.rangeStatus === MegohmmeterProcessPhaseReport.ERROR) st = "error";
                    else if (process.rangeStatus === MegohmmeterProcessPhaseReport.FAIL) st = "fail";
                return st;
            }

            Connections {
                target: megohmmeter.range
                onEnumNamesChanged: {
                    if (megohmmeter.range.value !== ParamMegohmmeter.AUTO && !remoteaccess.interfaceIsConnected) {
                        disableButtons();
                        msg = popup().editParam(megohmmeter.range);
                        popup().msg(qsTr("Ranges changed"), qsTr("Ranges have changed. Please select the desired range again."), [qsTr("Ok")]);
                    }
                }
            }
        }

    }

    Connections {
        target: msg
        onClose: {
            //Dans le cas d'une double popup la condition popup.isOpened pose problème, on la contourne ici sachant qu'elle n'est qu'une sécurité
            hal.setStartLight(!remoteaccess.interfaceIsConnected && hal.safetyLoop /*&& !popup().isOpened()*/);
            hal.setStopLight(false);
        }
    }

    Connections {
        //Permet de ne pas rallumer le bouton start lors de l'ouverture de la pop up d'erreur lié au temps de maintien grace au booleen visible de cette page
        target: reportZone.rzMsg
        onClose: {
            //Dans le cas d'une double popup la condition popup.isOpened pose problème, on la contourne ici sachant qu'elle n'est qu'une sécurité
            hal.setStartLight(!remoteaccess.interfaceIsConnected && hal.safetyLoop && visible);
            hal.setStopLight(false);
        }
    }

    function disableButtons(){
        hal.setStartLight(false);
        hal.setStopLight(false);
    }
}
