import QtQuick 2.0
import Horus 1.0
import "../HorusComponents"

Page {
    id: page
    property bool isUnderVoltage: process.running
    msg: null

    title: config.autoTr + /*qsTr("Megohmmeter")*/ qsTr("MΩ")
    navigationBtnEnable: !isUnderVoltage
    headerButton {
        text: megohmmeterLoader.filename
        enabled: !isUnderVoltage && (config.acl.value <= ParamGlobal.ADMINISTRATOR) && !remoteaccess.interfaceIsConnected
        startRelated: true
        onClicked: {
//            hal.startButtonPressed();
            msg = popup().editText(
                qsTr("Filename"),
                megohmmeterLoader.filename,
                function (name) {
                    if (name !== undefined) {
                        if (megohmmeterLoader.exists(name)) {
                            msg = popup().msg(qsTr("Warning"), qsTr("There is already a configuration named \"%1\". Do you want to overwrite it ?").arg(megohmmeterLoader.data.sanitizeName(name)), [qsTr("Overwrite"), qsTr("Cancel")], function(nr) {
                                if (nr === 0) {
                                    megohmmeterLoader.data.copyToStorage(name);
                                    config.megohmmeterConfig = name;
                                    return true;
                                } else if (nr === 1) {
                                    return true;
                                }
                                return false;
                            }, /* replace: */ true);
                            return false;
                        }
                        else {
                            msg = popup().msg(qsTr("Rename"), qsTr("Do you want to rename \"%1\" or do you want to duplicate \"%1\" and rename it ?").arg(config.megohmmeterConfig), [qsTr("Rename"), qsTr("Duplicate & Rename")], function(nr) {
                                if (nr === 1) {
                                    megohmmeterLoader.data.copyToStorage(name);
                                    config.megohmmeterConfig = name;
                                    return true;
                                } else if (nr === 0) {
                                    megohmmeterLoader.data.copyToStorage(name);
                                    megohmmeterLoader.remove(config.megohmmeterConfig);
                                    config.megohmmeterConfig = name;
                                    return true;
                                }
                                return false;
                            }, /* replace: */ true)
                        }
                    }
                    return (true);
                }, false, "^[a-zA-Z0-9_-]{1,100}$");
            disableButtons();
        }
    }

    Connections {
        target: remoteaccess
        onModeMegohmmeterChanged: {
            if (!remoteaccess.modeMegohmmeter && page.visible)
                back_page();
        }
        onFunctionsDeactivated: {
            if (!remoteaccess.modeMegohmmeter && page.visible)
                back_page();
        }
    }

    property var process: remoteaccess.modeMegohmmeter ? remoteaccess.megohmmeterProcess : processQml
    MegohmmeterProcess{
        id: processQml
        parameters: megohmmeterLoader.data
        canbusMegohmmeter: canbus.can1500
        halObj: hal
        configObj: config
        inhibit: !page.visible || popup().isOpened() || remoteaccess.modeMegohmmeter
        property bool startEnable: false

        onCommunicationError: {
            if(!process.finished) {
                page.msg = popup().msg(qsTr("Communication Failed"), qsTr("MΩ function stopped responding. Please restart the machine for safety.\nContact our service if it happens again."), [qsTr("Ok")], function(nr) {
                    if (nr === 0) {
                        return true;
                    }
                });
            }
            else {
                page.msg = popup().msg(qsTr("Start Failed"), qsTr("The test failed to start. Try again to launch the test."), [qsTr("Ok")], function(nr) {
                    if (nr === 0) {
                        return true;
                    }
                });
            }

            disableButtons();
        }

        onInterrupted: {
            measure_stop();
            page.msg = popup().msg(qsTr("Test aborted"), qsTr("The test has been aborted"), [qsTr("Ok")], function(nr) {
                if (nr === 0) return true;
                else return false;
            });

        }
        Connections {
            target: hal
            onStartButtonPressed: {
                if (!remoteaccess.interfaceIsConnected && !process.inhibit) {
                    if (!hal.safetyLoop) {
                        securityLoopWatcher.open();
                    }
                    else if (!process.readyToStart() && page.msg == null && process.invalidParameters() !== "") {
                        page.msg = popup().msg(qsTr("Test invalid"), qsTr("Some parameters are invalid:\n%1").arg(process.invalidParameters()), [qsTr("Ok")], function(nr) {
                            if (nr === 0) {
                                return true;
                            }
                        });
                        disableButtons();
                    }
                    else {
                        timer.running = true;
                    }


                    if (config.acl.value === ParamGlobal.SERVICE) {
                        //ArmindoTest
        //                    process.measure_start();
                        process.close_HoldingLoop();
                    }
                }
            }
            onStopButtonPressed: {
//                console.log("onStopButtonPressed: running = ", process.running, " et finished = ", process.finished);
                if (process.running && !process.finished) {
//                    securityLoopWatcher.enable = false;
                    //ArmindoTest
                    process.cmd_Discharge();
//                    console.log("onStopButtonPressed: measure_stop et open pop-up");
                    //LCIETest
//                    process.measure_stop();
//                    page.msg = popup().msg(qsTr("Test aborted"), qsTr("The test has been aborted"), [qsTr("Ok")], function(nr) {
//                        if (nr === 0) return true;
//                        else return false;
//                    });
                }
                //ArmindoTest
                else {
//                    console.log("onStopButtonPressed: measure_stop mais pas de pop-up");

                    process.measure_stop();
                    if(page.msg) {
//                        console.log("onStopButtonPressed: par contre on ferme la pop-up");
                        page.msg.close();
                    }
                }
                hal.setStartLight(!process.inhibit && !remoteaccess.interfaceIsConnected && hal.safetyLoop && !(process.running && !process.finished));
                hal.setStopLight(process.running && !process.finished);
//                console.log("onStopButtonPressed: END");
            }
            onStartButtonReleased: {
                timer.running = false;
                if(process.startEnable || !hal.safetyLoop){
                    process.startEnable = false;
                }
                else if (!process.running && page.msg == null && !remoteaccess.interfaceIsConnected && config.acl.value !== ParamGlobal.SERVICE && !process.inhibit) {
                    page.msg = popup().tempo(qsTr("Launch a test"), qsTr("Press start for 1s"), 2000);
                    disableButtons();
                }
            }
        }

        Timer {
            id:timer
            interval: 1000
            running: false
            repeat: false
            onTriggered: {
                process.startEnable = true;
                //ArmindoTest
                process.close_HoldingLoop();
//                process.measure_start();
            }
        }
    }

    SecurityLoopWatcher {
        id: securityLoopWatcher
        process: remoteaccess.modeMegohmmeter ? remoteaccess.megohmmeterProcess : processQml
    }

    Loader {
        property variant megohmmeter : megohmmeterLoader.data
        anchors.fill: parent

        focus: true

        // Pour le mode permanent on a les même paramétrages que pour le mode auto
        source: "auto.qml"

        ParamMegohmmeterLoader {
            id: megohmmeterLoader
            filename: config.megohmmeterConfig
        }
    }
    Component.onCompleted: {
        paramupdater.megohmmeter.enable = true;
        hal.setStartLight(!remoteaccess.interfaceIsConnected && hal.safetyLoop && !process.inhibit);
        hal.setStopLight(false);
    }
    Component.onDestruction:{
        paramupdater.megohmmeter.enable = false;
        hal.setStartLight(false);
        hal.setStopLight(false);
    }

    onVisibleChanged: {
        hal.setStartLight(visible && !remoteaccess.interfaceIsConnected && hal.safetyLoop);
        hal.setStopLight(false);
    }

    Connections {
        target: msg
        onClose: {
            hal.setStartLight(visible && !remoteaccess.interfaceIsConnected && hal.safetyLoop && !process.inhibit);
            hal.setStopLight(isUnderVoltage);
        }
    }

    onIsUnderVoltageChanged: {
        if(isUnderVoltage) remoteaccess.disableRemoteAccess();
        else remoteaccess.enableRemoteAccess();
    }

    function disableButtons(){
        hal.setStartLight(false);
        hal.setStopLight(false);
    }
}
