import QtQuick 2.2
import Horus 1.0

Canvas {
    id: idCanvas

    property int nbPhases: 3

    property int mode: ParamPicoammeter.Auto

    property int currentPhase: 1
    property real phasePercent: 0

    property int valuePhase1: 0
    property int valuePhase2: 0
    property int valuePhase3: 0

    property variant stepColor: [neutralColor, neutralColor, neutralColor]
    property color neutralColor: "#e8e8f0"
    property color fadedColor: "#807c90"

    property int stepStatus1: PicoammeterProcessPhaseReport.NORMAL
    property int stepStatus2: PicoammeterProcessPhaseReport.NORMAL
    property int stepStatus3: PicoammeterProcessPhaseReport.NORMAL

    property int lineWidth: 8
    property int margins: 10

    property int _max: 1
    property variant _points: [0,0,0]

    antialiasing: true

    function recalcPoints() {
        var max = 0;
        max = Math.max(max, valuePhase1);
        max = Math.max(max, valuePhase2);
        max = Math.max(max, valuePhase3);
        if (!max) max = 1;
        _max = max;

        if (mode === ParamPicoammeter.Auto) {
            _points = [
                        0,
                        valuePhase1 / _max * (height - 2 * margins),
                        valuePhase2 / _max * (height - 2 * margins),
                        valuePhase3 / _max * (height - 2 * margins),
                    ];
        }
        else if (mode === ParamPicoammeter.Permanent) {
//            //console.log("PicoammeterGraph.qml: recalcPoints: mode Permanent: valuePhase1 = ", valuePhase1," valuePhase 2 = ",valuePhase2, " valuePhase3 = ", valuePhase3);

            _points = [
                        0,
                        valuePhase1 / _max * (height - 2 * margins),
                        valuePhase2 / _max * (height - 2 * margins),
                        valuePhase2 / _max * (height - 2 * margins), // Pour le mode permanent la phase 2 et 3 sont une seule et même phase que l'on sépare uniquement pour la tr   nsition graphique
                    ];
        }
    }

    function drawpath(ctx, phase, percent) {
        if (percent === undefined)
            percent = 1;
        if (percent === 0)
            percent = 0.001;
        phase = phase - 1;

        var xspace = nbPhases ? (width - 2 * margins) / nbPhases : 0;
//        //console.log("PicoammeterGraph.qml: drawpath: xspace = ", xspace);
        ctx.beginPath();

        if (mode === ParamPicoammeter.Auto || phase < 2) {
//            //console.log("PicoammeterGraph.qml: drawpath: mode === ParamPicoammeter.Auto || phase < 2 : percent = ", percent," et xspace = ", xspace);
//            ctx.beginPath();
            ctx.moveTo(margins + xspace * phase, height - margins - _points[phase]);
            ctx.lineTo(margins + xspace * phase + xspace * percent, height - margins - _points[phase] - ((_points[phase + 1] - _points[phase]) * percent));
        }

        else {
//            //console.log("PicoammeterGraph: phase 3 : percent = ",percent);
            if (percent === 1 ) {
                for (var j=1; j<=3; j++) {
                    ctx.moveTo(margins + xspace * phase + j*30, height - margins - _points[phase]);
                    ctx.lineTo(margins + xspace * phase + j*30 + 5, height - margins - _points[phase]);
                }
            }
            else {
                var i = 0;
                if (percent < 0.4) i = 1;
                else if (percent < 0.7) i = 2;
                else i = 3;
//                //console.log("PicoammeterGraph: percent = ", percent, ", i = ", i);
                ctx.moveTo(margins + xspace * phase + i*30, height - margins - _points[phase]);
                ctx.lineTo(margins + xspace * phase + i*30 + 5, height - margins - _points[phase]);
            }
        }
    }

    function updatecolor(idx, status) {
        var c = neutralColor;
//        //console.log("PicoammeterGraph: updatecolor with status = ", status);
        if (status === PicoammeterProcessPhaseReport.FAIL){
//            //console.log("La phase est FAIL");
            c = config.resultFailColor;}
        else if (status === PicoammeterProcessPhaseReport.ERROR){
//            //console.log("La phase est ERROR");
            c = config.resultErrorColor;}
        else if (status === PicoammeterProcessPhaseReport.PASS){
//            //console.log("La phase est PASS");
            c = config.resultPassColor;}
        if (stepColor)
            stepColor[idx] = c;
    }

    onWidthChanged: updateTimer.start()
    onHeightChanged: { recalcPoints(); updateTimer.start(); }
    onNbPhasesChanged: { recalcPoints(); updateTimer.start(); }
    onCurrentPhaseChanged: updateTimer.start()
    onPhasePercentChanged: updateTimer.start();
    onModeChanged: {recalcPoints(); updateTimer.start();}
    onValuePhase1Changed: { recalcPoints(); updateTimer.start(); }
    onValuePhase2Changed: { recalcPoints(); updateTimer.start(); }
    onValuePhase3Changed: { recalcPoints(); updateTimer.start(); }
    onStepStatus1Changed: { /*//console.log("onStepStatus1Changed");*/
                            updatecolor(0, stepStatus1); updateTimer.start(); }
    onStepStatus2Changed: { /*//console.log("onStepStatus2Changed");*/
                            updatecolor(1, stepStatus2); updateTimer.start();}
    onStepStatus3Changed: { /*//console.log("onStepStatus3Changed");*/
                            updatecolor(2, stepStatus3); updateTimer.start(); }

    onPaint: {
        var ctx = idCanvas.getContext('2d');
        ctx.reset();

        // Display background
        ctx.save();
        ctx.lineWidth = lineWidth/2;
        ctx.lineCap = "round";
        ctx.strokeStyle = fadedColor;
        for (var i = 1; i <= nbPhases; ++i) {
            drawpath(ctx, i);
            ctx.stroke();
        }
        ctx.restore();

        // Display color
        ctx.save();
        ctx.lineWidth = lineWidth;
        ctx.lineCap = "round";
        ctx.strokeStyle = fadedColor;
        ctx.shadowOffsetX = 0;
        ctx.shadowOffsetY = 0;
        //Modif LN 12/02/2020 : l'utilisation d'un shadowBlur génère un temps de 50 à 150ms pour le traçage de la courbe
        //                      temps durant lequel les autres signaux de l'appli ne sont pas pris en compte
        //                      (Ex: signal buttonStopPressed n'est pris en compte qu'après traçage de la courbe et ne permet pas
        //                      une bonne prise en compte d'un arrêt d'urgence)
//        ctx.shadowBlur = 3;

        for (var j = 1; j <= currentPhase; ++j) {
            ctx.strokeStyle = stepColor[j-1];
            ctx.shadowColor = stepColor[j-1];
            drawpath(ctx, j, (j === currentPhase) ? phasePercent : 1);
            ctx.stroke();
        }

        ctx.restore();

    }

    Component.onCompleted: {
        updatecolor(0, stepStatus1);
        updatecolor(1, stepStatus2);
        updatecolor(2, stepStatus3);
        updateTimer.start();
        //DavidTest
//        recalcPoints();
    }

    Timer {
        id: updateTimer
        interval: 50
        onTriggered: parent.requestPaint()
    }
}
