import QtQuick 2.2
import Horus 1.0
import "../HorusComponents"

Image {
    property var picoammeterProcess
    property bool isUnderVoltage

    property int editPhase: 1
    property int displayedPhaseIndex: picoammeterProcess ? (picoammeterProcess.currentPhase || editPhase) - 1 : -1

    property var rzMsg: null

    source: "bg_central.png"

    Item {
        anchors {
            top: parent.top
            bottom: parent.bottom
            left: parent.left
        }
        width: 359

        /********************
        * Graph zone - auto *
        ********************/
        Item {
            id: graphzone_auto
            height: graph_auto.height + 60 + 30
            visible: picoammeterProcess && picoammeterProcess.parameters ? (picoammeterProcess.parameters.mode.value === ParamPicoammeter.Auto) : false

            anchors {
                left: parent.left
                right: parent.right
                bottom: parent.bottom
            }

            Item {
                id: graph_auto

                anchors {
                    left: parent.left
                    right: parent.right
                    bottom: parent.bottom
                    margins: 14
                    bottomMargin: 60
                }

                height: 150

                Rectangle {
                    anchors.fill: parent
                    anchors.rightMargin: 2
                    radius: 14
                    color: "#2a2939"
                }

                Button {
                    anchors {
                        top: parent.bottom
                        topMargin: 4
                        right: parent.right
                    }
                    srcImage: "next.png"
                    rectVisible: false
                    width: 32
                    opacity: (!isUnderVoltage && editPhase < 3 ? 1 : 0)
                    onClicked: editPhase = Math.min(editPhase + 1, 3)
                    Behavior on opacity { NumberAnimation { duration: 100 } }
                }

                Button {
                    anchors {
                        top: parent.bottom
                        topMargin: 4
                        left: parent.left
                    }
                    srcImage: "prev.png"
                    rectVisible: false
                    width: 32
                    opacity: (!isUnderVoltage && editPhase > 1 ? 1 : 0)
                    onClicked: editPhase = Math.max(editPhase - 1, 1)
                    Behavior on opacity { NumberAnimation { duration: 100 } }
                }

                Rectangle {
                    color: "#323140"
                    radius: 14
                    property real w: (parent.width - 20) / /*(picoammeterProcess && picoammeterProcess.parameters ? 3 : 3)*/3
                    x: displayedPhaseIndex * w
                    width: w + 20
                    height: parent.height

                    Behavior on x {
                        enabled: displayedPhaseIndex >= 0
                        NumberAnimation {
                            duration: 800
                            easing.type: Easing.OutExpo
                        }
                    }

                    Button { // Duration
                        id : duration_btn
                        property variant param: picoammeterProcess && picoammeterProcess.parameters && displayedPhaseIndex >= 0 &&  displayedPhaseIndex < 3? picoammeterProcess.parameters.phases[displayedPhaseIndex].time : {value: 0}

                        anchors {
                            top: parent.bottom
                            topMargin: 14
                            horizontalCenter: parent.horizontalCenter
                        }

                        width: 70
                        height: 30
                        text: /*"1 s"*/{
                            var nb = param.value * (1 - (picoammeterProcess && picoammeterProcess.parameters ? picoammeterProcess.stepPercent : 0));
                            if (!isUnderVoltage) nb = param.value;
                            return config.autoTr + qsTr("%1 s").arg(Number(nb).toFixed(1));
                        }
                        textColor: enabled ? (pressed ? UiConfig.colors.fg_pressed : UiConfig.colors.fg_active) : "#fff"
                        font.pixelSize: 16
                        enabled: !isUnderVoltage && canChangeParameters && !remoteaccess.interfaceIsConnected

                        helpText: config.autoTr + qsTr("This button opens a keypad to edit this phase duration.")

                        startRelated: true

                        onClicked: {rzMsg = popup().editParam(param); disableButtons();}

                        visible: true

                        Connections {
                            target: picoammeterProcess.parameters.phases[1].time
                            onValueChanged: {
                                // Si la phase est une phase de maintien et qu'on la paramète à 0s alors une message d'erreur est affiché
                                if (picoammeterProcess.parameters.phases[1].time.value < 0.1) {
                                    rzMsg = popup().msg(qsTr("Value error"), qsTr("Holding phase can't last 0s"), [qsTr("Ok")]);
                                    disableButtons();
                                    picoammeterProcess.parameters.phases[1].time.value = 0.1;
                                }
                            }
                        }
                    }

                    Button { // Finished
                        id :end_btn
                        anchors {
                            top: parent.bottom
                            topMargin: 14
                            horizontalCenter: parent.horizontalCenter
                        }
                        width: 105
                        height: 30
                        text: ""
                        textColor: "#fff"
                        enabled: false

                        visible: false

                        SequentialAnimation {
                            id: anim
                            running: end_btn.visible
                            loops: Animation.Infinite
                            PropertyAnimation { target: end_btn; property: "text"; to: "Press Stop"; duration: 500 }
                            PropertyAnimation { target: end_btn; property: "text"; to: ""; duration: 500 }
                        }
                    }
                }

                Repeater {
                    model: picoammeterProcess && picoammeterProcess.parameters ? 3 : 0
                    delegate: MouseArea {
                        property real w: (graph_auto.width - 20) / (picoammeterProcess && picoammeterProcess.parameters ? 3 : 3)
                        anchors.bottom: graph_auto.bottom
                        x: index * w + 11
                        width: w
                        height: graph_auto.height + 35
                        onClicked: editPhase = index + 1

                        Text {
                            anchors {
                                top: parent.bottom
                                topMargin: -30
                                left: parent.left
                                right: parent.right
                            }
                            text: index + 1
                            color: index == displayedPhaseIndex ? "#e8e8f0" : "#807c90"
                            horizontalAlignment: Text.AlignHCenter
                            Behavior on color { ColorAnimation {} }
                        }

                        Image {
                            anchors {
                                bottom: parent.bottom
                                bottomMargin: 2
                                right: parent.right
                            }
                            source: "separator.png"
                            visible: index != (picoammeterProcess ? 3 : 3) - 1
                        }
                    }
                }

                PicoammeterGraph {
                    anchors.fill: parent

                    mode: picoammeterProcess.parameters.mode.value
                    nbPhases: 3
                    valuePhase1: picoammeterProcess && picoammeterProcess.parameters.voltage ? picoammeterProcess.parameters.voltage.value : 0
                    valuePhase2: picoammeterProcess && picoammeterProcess.parameters.voltage ? picoammeterProcess.parameters.voltage.value : 0
                    valuePhase3: 0

                    //DavidTest
                    stepStatus1: graphzone_auto.visible ? (picoammeterProcess ? picoammeterProcess.phases[0].status : PicoammeterProcess.OFF) : PicoammeterProcess.OFF /*PicoammeterProcess.PASS*/
                    stepStatus2: graphzone_auto.visible ? (picoammeterProcess ? picoammeterProcess.phases[1].status : PicoammeterProcess.OFF) : PicoammeterProcess.OFF /*PicoammeterProcess.PASS*/
                    stepStatus3: graphzone_auto.visible ? (picoammeterProcess ? picoammeterProcess.phases[2].status : PicoammeterProcess.OFF) : PicoammeterProcess.OFF /*PicoammeterProcess.PASS*/

                    phasePercent: graphzone_auto.visible ? (picoammeterProcess ? picoammeterProcess.stepPercent : 0) : 0 /*0.5*/
                    currentPhase: graphzone_auto.visible ? (picoammeterProcess ? picoammeterProcess.currentPhase : -1) : -1 /*2*/
                }
            }
        }

        /*************************
        * Graph zone - permanent *
        *************************/
        Item {
            id: graphzone_permanent

            height: graph_permanent.height + 60 + 30
            visible: picoammeterProcess && picoammeterProcess.parameters ? (picoammeterProcess.parameters.mode.value === ParamPicoammeter.Permanent) : false

            anchors {
                left: parent.left
                right: parent.right
                bottom: parent.bottom
            }

            Item {
                id: graph_permanent

                anchors {
                    left: parent.left
                    right: parent.right
                    bottom: parent.bottom
                    margins: 14
                    bottomMargin: 60
                }

                height: 150

                Rectangle {
                    anchors.fill: parent
                    anchors.rightMargin: 2
                    radius: 14
                    color: "#2a2939"
                }

                Button {
                    anchors {
                        top: parent.bottom
                        topMargin: 4
                        right: parent.right
                    }
                    srcImage: "next.png"
                    rectVisible: false
                    width: 32
                    opacity: (!isUnderVoltage && editPhase < 2 ? 1 : 0)
                    onClicked: editPhase = Math.min(editPhase + 1, 3)
                    Behavior on opacity { NumberAnimation { duration: 100 } }
                }

                Button {
                    anchors {
                        top: parent.bottom
                        topMargin: 4
                        left: parent.left
                    }
                    srcImage: "prev.png"
                    rectVisible: false
                    width: 32
                    opacity: (!isUnderVoltage && editPhase > 1 ? 1 : 0)
                    onClicked: editPhase = Math.max(editPhase - 1, 1)
                    Behavior on opacity { NumberAnimation { duration: 100 } }
                }

                Rectangle {
                    id: rect_surbrillant
                    color: "#323140"
                    radius: 14
                    property real w: (parent.width - 20) / 3
                    x: displayedPhaseIndex < 2 ? displayedPhaseIndex * w : (displayedPhaseIndex-1) * w
                    width: w  * (displayedPhaseIndex === 0 ? 1 : 2) + 20
                    height: parent.height

                    Behavior on x {
                        enabled: displayedPhaseIndex >= 0
                        NumberAnimation {
                            duration: 800
                            easing.type: Easing.OutExpo
                        }
                    }

                    Button { // Duration
                        id : rise_duration_btn
                        property variant param: picoammeterProcess && picoammeterProcess.parameters && displayedPhaseIndex === 0 ? picoammeterProcess.parameters.phases[0].time : {value: 0}

                        anchors {
                            top: parent.bottom
                            topMargin: 14
                            horizontalCenter: parent.horizontalCenter
                        }

                        width: 95
                        height: 30
                        text: {
                            var dur = "";
                            if (!isUnderVoltage) {
                                dur = Number(param.value).toFixed(1) + " s";
                            }
                            else dur = picoammeterProcess && picoammeterProcess.parameters ? picoammeterProcess.durationText : "";
                            return config.autoTr + dur;
                        }

                        textColor: enabled ? (pressed ? UiConfig.colors.fg_pressed : UiConfig.colors.fg_active) : "#fff"
                        font.pixelSize: 16
                        enabled: !isUnderVoltage && canChangeParameters && !remoteaccess.interfaceIsConnected

                        helpText: config.autoTr + qsTr("Open the edition of rise time.")

                        startRelated: true

                        onClicked: {rzMsg = popup().editParam(param); disableButtons();}

                        visible: !isUnderVoltage ? (displayedPhaseIndex === 0) : true
                    }
                }

                Repeater {
                    model: picoammeterProcess && picoammeterProcess.parameters ? 2 : 0
                    delegate: MouseArea {
                        property real w: (graph_permanent.width - 20) / 3
                        anchors.bottom: graph_permanent.bottom
                        x: index * w + 11
                        width: (index+1)*w
                        height: graph_permanent.height + 35
                        onClicked: editPhase = index + 1

                        Text {
                            anchors {
                                top: parent.bottom
                                topMargin: -30
                                left: parent.left
                                right: parent.right
                                leftMargin: index === 1 ? w : w/2
                            }
                            text: index + 1
                            color: index == displayedPhaseIndex ? "#e8e8f0" : "#807c90"
                            Behavior on color { ColorAnimation {} }
                        }

                        Image {
                            anchors {
                                bottom: parent.bottom
                                bottomMargin: 2
                                right: parent.right
                            }
                            source: "separator.png"
                            visible: index != (picoammeterProcess ? 2 : 2) - 1
                        }
                    }
                }

                PicoammeterGraph {
                    id: graph
                    anchors.fill: parent

                    mode: picoammeterProcess.parameters.mode.value
                    nbPhases: 3
                    valuePhase1: picoammeterProcess && picoammeterProcess.parameters.voltage ? picoammeterProcess.parameters.voltage.value : 0
                    valuePhase2: picoammeterProcess && picoammeterProcess.parameters.voltage ? picoammeterProcess.parameters.voltage.value : 0
                    valuePhase3:  0

                    stepStatus1: graphzone_permanent.visible ? (picoammeterProcess ? picoammeterProcess.phases[0].status : PicoammeterProcess.OFF) : PicoammeterProcess.OFF
                    stepStatus2: graphzone_permanent.visible ? (picoammeterProcess ? picoammeterProcess.phases[1].status : PicoammeterProcess.OFF) : PicoammeterProcess.OFF
                    stepStatus3: graphzone_permanent.visible ? (picoammeterProcess ? picoammeterProcess.phases[1].status : PicoammeterProcess.OFF) : PicoammeterProcess.OFF

                    phasePercent: graphzone_permanent.visible ? (picoammeterProcess ? picoammeterProcess.stepPercent : 0) : 0
                    currentPhase: graphzone_permanent.visible ? (picoammeterProcess ? picoammeterProcess.graphiqPhase : -1) : -1

                    // Animation permettant d'animer la phase 3 du test permanent (3 points successifs)
//                    SequentialAnimation {
//                        running: picoammeterProcess.graphiqPhase === 3
//                        NumberAnimation { target: graph; property: "phasePercent"; from: 0; to: 1; duration: 2000; loops: Animation.Infinite}
//                    }
                }
            }
        }

        /*****************
        * Result message *
        *****************/
        TestStatus {
            anchors {
                top: parent.top
                left: parent.left
                right: parent.right
            }
            height: 70
            //DavidTest
            state: picoammeterProcess ? picoammeterProcess.status: "" /*MegohmmeterProcess.NORMAL*/
            errorText: picoammeterProcess ? picoammeterProcess.errorText : ""
        }
    }

    /*******************
    * Live report zone *
    *******************/
    MeasureCarousselGndBond {
        id: livereport_internal

        anchors {
            top: parent.top
            bottom: parent.bottom
            left: parent.left
            leftMargin: 359
            right: parent.right
        }
        //DavidTest
        u: picoammeterProcess ? (picoammeterProcess.voltageText ? picoammeterProcess.voltageText: "") : "" /*"1500"*/
        r: picoammeterProcess ? (picoammeterProcess.resistanceText ? picoammeterProcess.resistanceText: "") : "" /*"9,22"*/
        i: picoammeterProcess ? (picoammeterProcess.currentText ? picoammeterProcess.currentText: "") : "" /*"163"*/

        uunit: picoammeterProcess ? (picoammeterProcess.voltageUnit ? picoammeterProcess.voltageUnit : "") : ""
        runit: picoammeterProcess ? (picoammeterProcess.resistanceUnit ? picoammeterProcess.resistanceUnit : "") : "" /*"MΩ"*/
        iunit: picoammeterProcess ? (picoammeterProcess.currentUnit ? picoammeterProcess.currentUnit : "") : "" /*"pA"*/

        ulast: ""
        rlast: picoammeterProcess ? picoammeterProcess.errorText : ""
        ilast: picoammeterProcess ? picoammeterProcess.errorText : ""

        ulength: picoammeterProcess ? (picoammeterProcess.voltageTextLength ? picoammeterProcess.voltageTextLength :3) :3
        rlength: picoammeterProcess ? (picoammeterProcess.resistanceTextLength ? picoammeterProcess.resistanceTextLength :4) :4
        ilength: picoammeterProcess ? (picoammeterProcess.currentTextLength ? picoammeterProcess.currentTextLength :4) :4

        //Cette variable permet d'agencer les variables du caroussel comme souhaité. L'ordre par défaut est [u,r,i]. C'est dans cet ordre que l'on peut renseigner la variable order avec les nouvelles position souhaitée (comprise dans [1,3])
        order: [3,2,1]

        filter: picoammeterProcess ? (picoammeterProcess.parameters.filter.value === ParamPicoammeter.CAPA1 ? "Cable.png" : (picoammeterProcess.parameters.filter.value === ParamPicoammeter.CAPA2 ? "Capa.png" : "")) :""

        currentLimitation: config.currentMax1500 <= 0.004
    }

    Connections {
        target: picoammeterProcess
        onStatusChanged : {
            if(picoammeterProcess.status === PicoammeterProcess.OFF || picoammeterProcess.status === PicoammeterProcess.NORMAL) {
                end_btn.visible = false;
                duration_btn.visible = true;
            }
        }
        onFinished : {
            //Si le status est à OFF quand on reçoit le signal Fin de Test c'est que l'utilisateur à appuyer sur STOP
            //Pas besoin du message "Press Stop" dans ce cas
            if(picoammeterProcess.status !== PicoammeterProcess.OFF) {
                duration_btn.visible = false;
                end_btn.visible = true;
            }
        }
    }

    function disableButtons(){
        hal.setStartLight(false);
        hal.setStopLight(false);
    }
}
