import QtQuick 2.2
import Horus 1.0
import "../HorusComponents"

Item {
    property bool canChangeParameters: config.acl.value <= ParamGlobal.ADMINISTRATOR
    property bool canChangeProgram: config.acl.value <= ParamGlobal.TECHNICIAN
    property var msg: null

    ReportZone {
        id: reportZone
        anchors {
            top: parent.top
            left: parent.left
            leftMargin: 5
        }
        picoammeterProcess: process
        isUnderVoltage: page.isUnderVoltage
    }

    /*********************************
    * Right bar (params, list, help) *
    *********************************/
    RightBar {
        id: rightbar
        anchors {
            top: parent.top
            right: parent.right
            rightMargin: -10
        }
        enabled_help: !isUnderVoltage && !remoteaccess.interfaceIsConnected
        enabled_list: !isUnderVoltage && canChangeProgram && !remoteaccess.interfaceIsConnected
        enabled_settings: !isUnderVoltage && canChangeParameters && !remoteaccess.interfaceIsConnected
        stopMessage_visible: isUnderVoltage && process.finished

        startStopRelated: true
    }


    /*****************
    * Parameters row *
    *****************/
    Row {
        id: bottomrow

        anchors {
            horizontalCenter: parent.horizontalCenter
            bottom: parent.bottom
            bottomMargin: -10
        }

        spacing: 14

        ErrorButton { // Time
            property variant param: picoammeter.mode

            textTitle: config.autoTr + qsTr("Time")
            text: {
                if (param.value === ParamPicoammeter.Permanent) {
                    return param.text;
                }
                else {
                    var i, remaining = 0;
                    if (process.currentPhase > 0)
                        remaining = picoammeter.phases[process.currentPhase-1].time.value * (1 - process.stepPercent);
                    for (i = process.currentPhase || 1; i < 3; ++i)
                        remaining += picoammeter.phases[i].time.value
                    return config.autoTr + qsTr("%1 s").arg(Number(remaining).toFixed(1));
                }
            }

            startRelated: true

            color: param.value === ParamPicoammeter.Permanent ? UiConfig.colors.fg_inactive : "#fff"
            enabled: false
            visible: isUnderVoltage
        }

        ErrorButton { // Time
            property variant param: picoammeter.mode

            textTitle: config.autoTr + qsTr("Time")
            text: param.text
            enabled: canChangeParameters && param.modifiable && !remoteaccess.interfaceIsConnected
            visible: !isUnderVoltage
            helpText: qsTr("This button opens a list of the modes available for the picoammeter function")

            startRelated: true

            onClicked: {msg = popup().editParam(param); disableButtons();}
        }

        ErrorButton { // Voltage
            id: param_voltage
            property variant param: picoammeter.voltage

            textTitle: "VDC"
            //DavidTest
            text: picoammeter.alim.value === ParamPicoammeter.External ? "Vext" : param.text /*"1500 V"*/

            enabled: !isUnderVoltage && canChangeParameters && param.modifiable && !remoteaccess.interfaceIsConnected

            helpText:qsTr("This button opens a keypad to edit the voltage value of your picoammeter test")

            startRelated: true

            onClicked: {msg = popup().editParam(param); disableButtons();}
        }

        ErrorButton { // I min
            id: param_iMin

            property variant param: picoammeter.iMin

            textTitle: config.autoTr + qsTr("Imin")
            text: param.text
            enabled: !isUnderVoltage && canChangeParameters && param.modifiable && !remoteaccess.interfaceIsConnected

            helpText:qsTr("This button opens a keypad to edit the minimum current limit of your picoammeter test")

            startRelated: true

            onClicked:{msg = popup().editParam(param); disableButtons();}

            state: {
                var st = "";
                for (var i = 0; i < 3; ++i) {
                    if (process.phases[i].iMinStatus == PicoammeterProcessPhaseReport.ERROR) st = "error";
                    else if (process.phases[i].iMinStatus == PicoammeterProcessPhaseReport.FAIL) st = "fail";
                }
                return st;
            }
        }

        ErrorButton { // I max
            id: param_iMax
            property variant param: picoammeter.iMax


            textTitle: config.autoTr + qsTr("Imax")
            text: param.text
            enabled: !isUnderVoltage && canChangeParameters && param.modifiable && !remoteaccess.interfaceIsConnected

            helpText:qsTr("This button opens a keypad to edit the maximum current limit of your picoammeter test")

            startRelated: true

            onClicked: {msg = popup().editParam(param); disableButtons();}

            state: {
                var st = /*"fail"*/"";
                for (var i = 0; i < 3; ++i) {
                    if (process.phases[i].iMaxStatus == PicoammeterProcessPhaseReport.ERROR) st = "error";
                    else if (process.phases[i].iMaxStatus == PicoammeterProcessPhaseReport.FAIL) st = "fail";
                }
                return st;
            }
        }

        ErrorButton { // Range
            id: param_grounded
            property variant param: picoammeter.range

            textTitle: config.autoTr + qsTr("Range")
            text: param.text

            enabled: !isUnderVoltage && canChangeParameters && param.modifiable && !remoteaccess.interfaceIsConnected

            helpText:qsTr("This button indicate which range is applied during the test")

            startRelated: true

            onClicked: {msg = popup().editParam(param); disableButtons();}

            state: {
                var st = "";
                if (process.rangeStatus === PicoammeterProcessPhaseReport.ERROR) st = "error";
                else if (process.rangeStatus === PicoammeterProcessPhaseReport.FAIL) st = "fail";
                return st;
            }
        }

    }

    Connections {
        target: msg
        onClose: {
            //Dans le cas d'une double popup la condition popup.isOpened pose problème, on la contourne ici sachant qu'elle n'est qu'une sécurité
            hal.setStartLight(!remoteaccess.interfaceIsConnected && hal.safetyLoop /*&& !popup().isOpened()*/);
            hal.setStopLight(false);
        }
    }


    Connections {
        //Permet de ne pas rallumer le bouton start lors de l'ouverture de la pop up d'erreur lié au temps de maintien grace au booleen visible de cette page
        target: reportZone.rzMsg
        onClose: {
            hal.setStartLight(!remoteaccess.interfaceIsConnected && hal.safetyLoop && visible);
            hal.setStopLight(false);
        }
    }

    function disableButtons(){
        hal.setStartLight(false);
        hal.setStopLight(false);
    }
}
