import QtQuick 2.0
import Horus 1.0
import "../HorusComponents"

Page {
    title: config.autoTr + (extra.restore ? qsTr("Backup/Restore") : qsTr("Export"))

    ImportExportHelper {
        id: ieh
        dir: extra.dir
    }

    Column {
        anchors {
            top: parent.top
            right: parent.right
            rightMargin: -10
        }
        spacing: 10
        ButtonHelp {
        }
        ButtonSort {
            property int lastsort: 0
            onClicked: {
                popup().choose(
                            qsTr("Sort by"),
                            [
                                "Name ASC", "Name DESC",
                                "Date ASC", "Date DESC",
                            ],
                            lastsort,
                            function(nr) {
                                if (nr !== undefined) {
                                    var algo = ImportExportHelper.ALGO_NAME;
                                    var desc = false;
                                    if (nr == 2 || nr == 3)
                                        algo = ImportExportHelper.ALGO_MODIFIED
                                    if (nr == 1 || nr == 3)
                                        desc = true;
                                    ieh.sort(algo, desc);
                                    lastsort = nr;
                                }
                                return true;
                            });
            }
        }
    }

    Image {
        id: bgImg
        x: 5
        source: "background.png"

        Rectangle { // left part
            width: 331
            height: 376
            color: "transparent"
            border.width: leftDrop.containsDrag * 4
            border.color: "#fff"
            radius: 14

            Text {
                id: leftTitle
                anchors {
                    top: parent.top
                    topMargin: 10
                    horizontalCenter: parent.horizontalCenter
                }
                text: config.model.model
                font.pixelSize: 30
                color: "#fff"
            }
            ListView {
                id: leftListView
                anchors {
                    top: leftTitle.bottom
                    left: parent.left
                    bottom: parent.bottom
                    right: parent.right
                    margins: 10
                }

                clip: true
                model: ieh.localModel
                interactive: !dragElement.dragOn

                delegate: ListEntry {
                    label: modelData.name
                    visible: modelData.local
                    selected: localBtn.pressed && !dragElement.dragOn

                    MouseArea {
                        id: localBtn
                        anchors.fill: parent
                        drag.axis: Drag.XAxis
                        drag.minimumX: bgImg.x
                        drag.maximumX: bgImg.width - bgImg.x - parent.width
                        drag.target: dragElement;
                        drag.threshold: 2

                        drag.onActiveChanged: {
                            if (!drag.active)
                                dragElement.Drag.drop();
                            dragElement.dragOn = drag.active;
                        }

                        onPressed: {
                            var abs = parent.mapToItem(dragElement.parent, 0, 0, parent.width, parent.height);
                            dragElement.x = abs.x;
                            dragElement.y = abs.y;
                            dragElement.width = abs.width;
                            dragElement.height = abs.height;
                            dragElement.label = parent.label;
                            dragElement.entry = modelData;
                            dragElement.Drag.keys = ["horus/local"];
                        }
                    }
                }
                VScrollBar {
                    anchors {
                        top: parent.top
                        bottom: parent.bottom
                        left: parent.left
                    }
                    scrollArea: parent
                }
            }
            DropArea {
                id: leftDrop
                anchors.fill: parent
                keys: ["horus/remote"]
                onDropped: {
                    var title = qsTr("Restore");
                    var dropped = drop.source;

                    //Si le fichier est présent sur la cible
                    if(drop.source.entry.local && drop.source.entry.remote) {
                        popup().msg(qsTr("Warning"), qsTr("A file \"%1\" already exists on target. If you continue you will overwrite it.").arg(drop.source.entry.name), [qsTr("Continue"), qsTr("Cancel")], function(nr) {
                            if (nr === 0) {
                                if (!dropped.entry.restore())
                                    popup().msg(title, qsTr("An error occured during operation. Please check your files or retry."), [qsTr("Ok")], function(nr) {
                                        if (nr === 0) {
                                            return true;
                                        }
                                    }, true);
                                else
                                    popup().msg(title, qsTr("Copy finished with success."), [qsTr("Ok")], function(nr) {
                                            return true;
                                    }, true);
                                return true;
                            }
                            if(nr ===1){
                                return true;
                            }
                        });
                    }

                    else {
                    if (!drop.source.entry.restore())
                            popup().msg(title, qsTr("An error occured during operation. Please check your files or retry."), [qsTr("Ok")], function(nr) {
                                if (nr === 0) {
                                    return true;
                                }
                            });
                        else
                            popup().msg(title, qsTr("Copy finished with success."), [qsTr("Ok")], function(nr) {
                                    return true;
                            });
                    }
                }
            }
        }

        Rectangle { // right part
            x: 345
            width: 331
            height: 376
            color: "transparent"
            border.width: rightDrop.containsDrag * 4
            border.color: "#fff"
            radius: 14
            Text {
                id: rightTitle
                anchors {
                    top: parent.top
                    topMargin: 10
                    horizontalCenter: parent.horizontalCenter
                }
                text: config.autoTr + qsTr("USB key")
                color: "#fff"
                font.pixelSize: 30
            }
            ListView {
                id: rightListView
                anchors {
                    top: rightTitle.bottom
                    left: parent.left
                    bottom: parent.bottom
                    right: parent.right
                    margins: 10
                }

                clip: true
                model: ieh.remoteModel
                interactive: !dragElement.dragOn

                delegate: ListEntry {
                    label: modelData.name
                    visible: modelData.remote
                    enabled: extra.restore
                    selected: remoteBtn.pressed && !dragElement.dragOn

                    MouseArea {
                        id: remoteBtn
                        anchors.fill: parent
                        enabled: parent.enabled
                        drag.axis: Drag.XAxis
                        drag.minimumX: bgImg.x
                        drag.maximumX: bgImg.width - bgImg.x - parent.width
                        drag.target: dragElement;
                        drag.threshold: 2

                        drag.onActiveChanged: {
                            if (!drag.active)
                                dragElement.Drag.drop();
                            dragElement.dragOn = drag.active;
                        }

                        onPressed: {
                            var abs = parent.mapToItem(dragElement.parent, 0, 0, parent.width, parent.height);
                            dragElement.x = abs.x;
                            dragElement.y = abs.y;
                            dragElement.width = abs.width;
                            dragElement.height = abs.height;
                            dragElement.label = parent.label;
                            dragElement.entry = modelData;
                            dragElement.Drag.keys = ["horus/remote"];
                        }
                    }
                }
                VScrollBar {
                    anchors {
                        top: parent.top
                        bottom: parent.bottom
                        left: parent.left
                    }
                    scrollArea: parent
                }
            }
            DropArea {
                id: rightDrop
                anchors.fill: parent
                keys: ["horus/local"]
                onDropped: {
                    var title = extra.restore ? qsTr("Backup") : qsTr("Export");
                    var dropped = drop.source;
                    var dir = ieh.dir;
//                    console.log("dropped on RightDrop: drop.source.entry.local = ", drop.source.entry.local, " drop.source.entry.remote = " , drop.source.entry.remote);


                    //Si le fichier est présent sur la cible
                    if(drop.source.entry.local && drop.source.entry.remote) {
                        popup().msg(qsTr("Warning"), qsTr("A file \"%1\" already exists on target. If you continue you will overwrite it.").arg(drop.source.entry.name), [qsTr("Continue"), qsTr("Cancel")], function(nr) {
                            if (nr === 0) {
                                if (!dropped.entry.backup())
                                    popup().msg(title, qsTr("An error occured during operation. Please check your files or retry."), [qsTr("Ok")], function(nr) {
                                        if (nr === 0) {
                                            return true;
                                        }
                                    }, true);
                                else {
                                    if (!extra.restore)
                                        popup().msg(title, qsTr("Copy finished with success.\nDo you want to delete the file on the machine? (Recommended to avoid memory saturation)"), [qsTr("Yes"), qsTr("No")], function(nr) {
                                            if (nr === 1) {
                                                return true;
                                            }
                                            if (nr === 0) {
                                                dropped.entry.deleteLocal();
                                                return true;
                                            }
                                        }, true);

                                    else
                                    popup().msg(title, qsTr("Copy finished with success."), [qsTr("Ok")], function(nr) {
                                            return true;
                                    }, true);
                                }
                                return true;
                            }
                            if(nr ===1){
                                return true;
                            }
                        });
                    }

                    else {
//                        popup().msg(qsTr("Warning"), qsTr("A file \"%1\" already exists on target. If you continue you will overwrite it.").arg(drop.source.entry.name), [qsTr("Continue"), qsTr("Cancel")], function(nr) {
//                            if (nr === 0) {
                                if (!dropped.entry.backup()) {
                                    popup().msg(title, qsTr("An error occured during operation. Please check your files or retry."), [qsTr("Ok")], function(nr) {
                                        if (nr === 0) {
                                            return true;
                                        }
                                    }, true);
                                }
                                else {
                                    if (!extra.restore) {
                                        popup().msg(title, qsTr("Copy finished with success.\nDo you want to delete the file on the machine? (Recommended to avoid memory saturation)"), [qsTr("Yes"), qsTr("No")], function(nr) {
                                            if (nr === 1) {
                                                return true;
                                            }
                                            if (nr === 0) {
                                                dropped.entry.deleteLocal();
                                                return true;
                                            }
                                        });
                                    }

                                    else {
                                        popup().msg(title, qsTr("Copy finished with success."), [qsTr("Ok")], function(nr) {
                                            if (nr === 0) {
                                                return true;
                                            }
                                        });
                                    }
                                }
                                return true;
                            }
                    }
                }
        }
    }

    ListEntry {
        id: dragElement
        property bool dragOn: false
        property variant entry
        selected: true
        visible: dragOn
        height: 55

        Drag.active: dragOn
        Drag.hotSpot.x: width / 2
        Drag.hotSpot.y: height / 2
    }
}
