import QtQuick 2.0
import Horus 1.0
import "../HorusComponents"

Page {
    title: config.autoTr + qsTr("Backup & Restore")

    ButtonHelp {
        id: helpbutton
        anchors {
            top: parent.top
            right: parent.right
            rightMargin: -10
        }
    }

    ImportExportHelper {
        id: ieh
        dir: ""
    }

    ListSettings {
        id: ls
        property bool mounted: ieh.isStoragePresent()

        anchors {
            top: parent.top
            left: parent.left
            bottom: parent.bottom
            right: helpbutton.left
            rightMargin: 10
        }

        /****************
        * Store results *
        ****************/
        ListSettingsElement {
            label: config.autoTr + qsTr("Store results")
            Inter {
                width: 250
                height: 50
                interOn: config.resultsStore
                onInterOnChanged: {
                    config.resultsStore = interOn;
                    interOn = Qt.binding(function() { return config.resultsStore; });
                }
            }
        }

        /***********************
        * Frequency of storage *
        ***********************/
//        ListSettingsElement {
//            label: config.autoTr + qsTr("Type :")
//            visible: config.resultsStore
//            button {
//                text: config.resultsStoreType.text
//                onClicked: {
//                    popup().editParam(config.resultsStoreType)
//                }
//            }
//        }

        ListSettingsElement {
            label: config.autoTr + qsTr("Data logging")
            visible: config.resultsStore
            Inter {
                width: 250
                height: 50
                interOn: config.dataLogging
                onInterOnChanged: {
                    config.dataLogging = interOn;
                    interOn = Qt.binding(function() { return config.dataLogging; });
                }
            }
        }


        ListSettingsElement {
            visible: config.resultsStore
            label: config.autoTr + qsTr("Period :")
            button {
                enabled: (config.resultsStore && config.dataLogging)
                text: config.resultsStorePeriod.value + "s"
                onClicked: popup().editParam(config.resultsStorePeriod)
            }
        }

//        ListSettingsElement {
//            visible: config.resultsStore
//            label: config.autoTr + qsTr("Period :")
//            button {
//                enabled: (config.resultsStore && config.resultsStoreType.value === ParamGlobal.ON_PERIOD)
//                text: config.resultsStorePeriod.value + "s"
//                onClicked: popup().editParam(config.resultsStorePeriod)
//            }
//        }

        /*******************
        * USB mount/umount *
        *******************/
        ListSettingsElement {
            label: config.autoTr + qsTr("USB Memory")
            button {
                property string mounttext: ls.mounted ? qsTr("Eject") : qsTr("Install")
                text: mounttext
                onClicked: {
                    var ok;
                    if (ls.mounted)
                        ok = ieh.umount();
                    else
                        ok = ieh.mount();
                    if (!ok)
                        popup().msg(mounttext, qsTr("An error occured during the operation."), [qsTr("Ok")], function(nr) {
                            if (nr === 0) {
                                return true;
                            }
                        });
                    ls.mounted = ieh.isStoragePresent()
                }
            }
        }

        /********************
        * Global parameters *
        ********************/
        ListSettingsElement {
            label: config.autoTr + qsTr("Global parameters")
            visible: ls.mounted
            button {
                text: config.autoTr + qsTr("Backup/Restore")
                dstLink: "save_export"
                dstExtra: {"restore": true, "dir": "global/parameters/", "stopAtDot": true}
            }
        }

        /*******************
        * Hipot parameters *
        *******************/
        ListSettingsElement {
            label: config.autoTr + qsTr("Hipot parameters")
            visible: ls.mounted && config.model.optionHipot
            button {
                text: config.autoTr + qsTr("Backup/Restore")
                dstLink: "save_export"
                dstExtra: {"restore": true, "dir": "hipot/parameters/", "stopAtDot": true}
            }
        }

        /****************
        * Hipot results *
        ****************/
        ListSettingsElement {
            label: config.autoTr + qsTr("Hipot results")
            visible: ls.mounted && config.model.optionHipot
            button {
                text: config.autoTr + qsTr("Export")
                dstLink: "save_export"
                dstExtra: {"restore": false, "dir": "hipot/results/", "stopAtDot": true}
            }
        }

        /*******************
        * GndBond parameters *
        *******************/
        ListSettingsElement {
            label: config.autoTr + qsTr("GndBond parameters")
            visible: ls.mounted && config.model.optionGndBond
            button {
                text: config.autoTr + qsTr("Backup/Restore")
                dstLink: "save_export"
                dstExtra: {"restore": true, "dir": "gndbond/parameters/", "stopAtDot": true}
            }
        }

        /****************
        * GndBond results *
        ****************/
        ListSettingsElement {
            label: config.autoTr + qsTr("GndBond results")
            visible: ls.mounted && config.model.optionGndBond
            button {
                text: config.autoTr + qsTr("Export")
                dstLink: "save_export"
                dstExtra: {"restore": false, "dir": "gndbond/results/", "stopAtDot": true}
            }
        }

        /*******************
        * Insulation parameters *
        *******************/
        ListSettingsElement {
//            label: config.autoTr + qsTr("Insulation parameters")
            label: config.autoTr + qsTr("Megohmmeter parameters")
            visible: ls.mounted && config.model.optionInsulation
            button {
                text: config.autoTr + qsTr("Backup/Restore")
                dstLink: "save_export"
                dstExtra: {"restore": true, "dir": "megohmmeter/parameters/", "stopAtDot": true}
            }
        }

        /****************
        * Insulation results *
        ****************/
        ListSettingsElement {
//            label: config.autoTr + qsTr("Insulation results")
            label: config.autoTr + qsTr("Megohmmeter results")
            visible: ls.mounted && config.model.optionInsulation
            button {
                text: config.autoTr + qsTr("Export")
                dstLink: "save_export"
                dstExtra: {"restore": false, "dir": "megohmmeter/results/", "stopAtDot": true}
            }
        }

        /**************************
        * Megohmmeter parameters *
        **************************/
        ListSettingsElement {
            label: config.autoTr + qsTr("Megohmmeter parameters")
            visible: ls.mounted && config.model.optionMOhm
            button {
                text: config.autoTr + qsTr("Backup/Restore")
                dstLink: "save_export"
                dstExtra: {"restore": true, "dir": "megohmmeter/parameters/", "stopAtDot": true}
            }
        }

        /***********************
        * Megohmmeter results *
        ***********************/
        ListSettingsElement {
            label: config.autoTr + qsTr("Megohmmeter results")
            visible: ls.mounted && config.model.optionMOhm
            button {
                text: config.autoTr + qsTr("Export")
                dstLink: "save_export"
                dstExtra: {"restore": false, "dir": "megohmmeter/results/", "stopAtDot": true}
            }
        }

        /*************************
        * Picoammeter parameters *
        *************************/
        ListSettingsElement {
            label: config.autoTr + qsTr("Picoammeter parameters")
            visible: ls.mounted && config.model.optionPA
            button {
                text: config.autoTr + qsTr("Backup/Restore")
                dstLink: "save_export"
                dstExtra: {"restore": true, "dir": "picoammeter/parameters/", "stopAtDot": true}
            }
        }

        /****************
        * Picoammeter results *
        ****************/
        ListSettingsElement {
            label: config.autoTr + qsTr("Picoammeter results")
            visible: ls.mounted && config.model.optionPA
            button {
                text: config.autoTr + qsTr("Export")
                dstLink: "save_export"
                dstExtra: {"restore": false, "dir": "picoammeter/results/", "stopAtDot": true}
            }
        }

        /********************************
        * Sequence Parameters and Files *
        *********************************/
        ListSettingsElement {
            id: seqbtn
            label: config.autoTr + qsTr("Sequence parameters and files")
            visible: ls.mounted
            button {
                text: config.autoTr + qsTr("Backup/Restore")
                onClicked: {
                    popup().choose(seqbtn.label, [qsTr("Parameters"), qsTr("Files")], -1, function(nr) {
                        if (nr === 0)
                            change_page ("save_export", {"restore": true, "dir": "sequence/parameters/", "stopAtDot": true});
                        else if (nr === 1)
                            change_page ("save_export", {"restore": true, "dir": "sequence/files/", "stopAtDot": false});
                        return true;
                    });
                }
            }
        }

        /*******************
        * Sequence Results *
        ********************/
        ListSettingsElement {
            label: config.autoTr + qsTr("Sequence results")
            visible: ls.mounted
            button {
                text: config.autoTr + qsTr("Export")
                dstLink: "save_export"
                dstExtra: {"restore": false, "dir": "sequence/results/", "stopAtDot": true}
            }
        }

        /**********
        * Service *
        **********/
        ListSettingsElement {
            id: servicebtn
            label: config.autoTr + qsTr("Service")
            visible: ls.mounted && config.acl.value <= ParamGlobal.SERVICE
            button {
                text: config.autoTr + qsTr("Export")
                onClicked: {
                    popup().choose(servicebtn.label, [qsTr("Usage log"), qsTr("Hipot counter"), qsTr("Gndbond counter")/*, qsTr("Insulation counter")*/, qsTr("Megohmmeter counter"), qsTr("Picoammeter counter")], -1, function(nr) {
                        if (nr === 0) {
                            ieh.dir = "global/log_sefelec/";
                            for (var i in ieh.localModel) {
                                if (ieh.localModel[i].name == "usage.log") {
                                    ieh.localModel[i].backup();
                                    break;
                                }
                            }
                        } else if (nr === 1) {
                            ieh.dir = "hipot/";
                            for (var i in ieh.localModel) {
                                if (ieh.localModel[i].name == "counter") {
                                    ieh.localModel[i].backup();
                                    break;
                                }
                            }

                        } else if (nr === 2) {
                            ieh.dir = "gndbond/";
                            for (var i in ieh.localModel) {
                                if (ieh.localModel[i].name == "counter") {
                                    ieh.localModel[i].backup();
                                    break;
                                }
                            }
                        }

                        else if (nr === 3) {
                            ieh.dir = "megohmmeter/";
                            for (var i in ieh.localModel) {
                                if (ieh.localModel[i].name == "counter") {
                                    ieh.localModel[i].backup();
                                    break;
                                }
                            }
                        }

                        else if (nr === 4) {
                            ieh.dir = "megohmmeter/";
                            for (var i in ieh.localModel) {
                                if (ieh.localModel[i].name == "counter") {
                                    ieh.localModel[i].backup();
                                    break;
                                }
                            }
                        }

                        else if (nr === 5) {
                            ieh.dir = "picoammeter/";
                            for (var i in ieh.localModel) {
                                if (ieh.localModel[i].name == "counter") {
                                    ieh.localModel[i].backup();
                                    break;
                                }
                            }
                        }
                        return true;
                    });
                }
            }
        }
    }
}
