import QtQuick 2.0
import Horus 1.0
import "../HorusComponents"

Page {
    id: page
    property bool canChangeParameters: config.acl.value <= ParamGlobal.ADMINISTRATOR && (sequenceModel ? !sequenceModel.isPlaying : true) && (!sequenceLoader.loading) && !remoteaccess.interfaceIsConnected
    property bool canChangeProgram: config.acl.value <= ParamGlobal.TECHNICIAN && (sequenceModel ? !sequenceModel.isPlaying : true) && (!sequenceLoader.loading)
    msg: null

    title: config.autoTr + qsTr("Sequence")
    navigationBtnEnable: (sequenceModel ? !sequenceModel.isPlaying : true) && (!sequenceLoader.loading)
    headerButton {
        text: sequenceLoader.filename
        enabled: (config.acl.value <= ParamGlobal.ADMINISTRATOR) && (sequenceModel ? !sequenceModel.isPlaying : true) && (!sequenceLoader.loading) && !remoteaccess.interfaceIsConnected
        onClicked: {
            msg = popup().editText(
                        qsTr("Filename"),
                        sequenceLoader.filename,
                        function (name) {
                            if (name !== undefined) {
                                if (sequenceLoader.exists(name)) {
                                    msg = popup().msg(qsTr("Warning"), qsTr("There is already a configuration named \"%1\". Do you want to overwrite it ?").arg(sequenceLoader.data.sanitizeName(name)), [qsTr("Overwrite"), qsTr("Cancel")], function(nr) {
                                        if (nr === 0) {
                                            sequenceLoader.data.copyToStorage(name);
                                            config.sequenceConfig = name;
                                            return true;
                                        } else if (nr === 1) {
                                            return true;
                                        }
                                        return false;
                                    }, /* replace: */ true);
                                    return false;
                                } else {
                                    msg = popup().msg(qsTr("Rename"), qsTr("Do you want to rename \"%1\" or do you want to duplicate \"%1\" and rename it ?").arg(config.sequenceConfig), [qsTr("Rename"), qsTr("Duplicate & Rename")], function(nr) {
                                        if (nr === 1) {
                                            sequenceLoader.data.copyToStorage(name);
                                            config.sequenceConfig = name;
                                            return true;
                                        } else if (nr === 0) {
                                            sequenceLoader.data.copyToStorage(name);
                                            sequenceLoader.remove(config.sequenceConfig);
                                            config.sequenceConfig = name;
                                            return true;
                                        }
                                        return false;
                                    }, /* replace: */ true)
                                }
                            }
                            return (true);
                        }, false, "^[a-zA-Z0-9_-]+$");
            disableButtons();
        }
    }

    Connections {
        target: remoteaccess
        onModeSequenceChanged: {
            if (!remoteaccess.modeSequence && page.visible)
                back_page();
        }
        onFunctionsDeactivated: {
            if (page.visible)
                back_page();
        }
    }

    /****************
    * Sequence data *
    ****************/
    property var sequenceLoader: remoteaccess.modeSequence ? remoteaccess.sequenceLoader : sequenceLoaderQml
    property var sequenceModel: sequenceLoader.data
    SequenceLoader {
//        id: sequenceLoader
        id: sequenceLoaderQml
        halObj: hal
        configObj: config
        property bool playEnable: false
    }

    Timer {
        interval: 10
        repeat: false
        running: true
        onTriggered: {
            if (!remoteaccess.modeSequence) {
                sequenceLoader.filename = Qt.binding(function() { return config.sequenceConfig; });
                hal.setStartLight(visible && !remoteaccess.interfaceIsConnected && hal.safetyLoop && !sequenceModel.checkIntegrity().length);
//                sequenceModel.halObj = hal;
//                sequenceModel.configObj = config;
            }
        }
    }
    Connections {
        target: hal
        onStartButtonPressed: {
            if (page.visible && !popup().isOpened()) {
                sequenceModel.selectionClear();
                var errors = sequenceModel.checkIntegrity()
                if (errors.length > 0) {
                    page.msg = popup().pushPopup(Qt.resolvedUrl("nocheckpopup.qml"), {"errors": errors});
                    disableButtons();
                }
                else if (!hal.safetyLoop)
                    securityLoopWatcher.open();
                else if (sequenceModel.count > 0)
                    timer.running = true;
            }
        }
        onStopButtonPressed: {
            sequenceModel.abort();
            if (sequenceModel.isPlaying && !sequenceModel.isFinished) {
//                sequenceModel.abort();
                page.msg = popup().msg(qsTr("Sequence aborted"), qsTr("The Sequence has been aborted"), [qsTr("Ok")], function(nr) {
                    if (nr === 0) {
                        return true;
                    }
                });
                disableButtons();
            }
            else {
                hal.setStartLight(visible && !remoteaccess.interfaceIsConnected && hal.safetyLoop && !sequenceModel.checkIntegrity().length);
                hal.setStopLight(false);
            }
        }
        onStartButtonReleased: {
            timer.running = false;
            //console.log("!sequenceModel.isPlaying ",!sequenceModel.isPlaying, " && page.msg == null ", page.msg == null," && !remoteaccess.interfaceIsConnected ",!remoteaccess.interfaceIsConnected, " && config.acl.value !== ParamGlobal.SERVICE ", config.acl.value !== ParamGlobal.SERVICE, " && sequenceModel.checkIntegrity().length", sequenceModel.checkIntegrity().length);
            //console.log("sequenceLoaderQml.playEnable ",sequenceLoaderQml.playEnable, " && !hal.safetyLoop ", !hal.safetyLoop);
            if(sequenceLoaderQml.playEnable || !hal.safetyLoop){
                //console.log("PlayEnable et safety loop closed");
                sequenceLoaderQml.playEnable = false;
            }
            else if (!sequenceModel.isPlaying && page.msg == null && !remoteaccess.interfaceIsConnected && config.acl.value !== ParamGlobal.SERVICE && !sequenceModel.checkIntegrity().length){
                //console.log("Press 1s");
                page.msg = popup().tempo(qsTr("Launch a test"), qsTr("Press start for 1s"), 2000);
                disableButtons();
            }
        }
    }

    Timer {
        id:timer
        interval: 1000
        running: false
        repeat: false
        onTriggered: {
            sequenceLoaderQml.playEnable = true;
            sequenceModel.play();
        }
    }


    SecurityLoopWatcherSequence {
        id: securityLoopWatcher
        sequence: sequenceModel
    }

    /***************
    * Display Zone *
    ***************/
    Loader {
        id : displayZone
        anchors.fill: parent
        source: sequenceModel && sequenceModel.isPlaying ? "liveshow.qml" : "editlist.qml"
    }

    Component.onCompleted: {
//        //console.log("page_sequence: onCompleted");
        hal.setStartLight(visible && !remoteaccess.interfaceIsConnected && hal.safetyLoop && !sequenceModel.checkIntegrity().length);
        hal.setStopLight(false);
    }
    Component.onDestruction:{
//        //console.log("page_sequence: onDestruction");
        hal.setStartLight(false);
        hal.setStopLight(false);
    }

    onVisibleChanged: {
//        //console.log("page_sequence: onVisibleChanged");      
        hal.setStartLight(visible && !remoteaccess.interfaceIsConnected && hal.safetyLoop && !sequenceModel.checkIntegrity().length);
        hal.setStopLight(false);

    }

    Connections {
        target: msg
        onClose: {
            //console.log("page_sequence: msg onClose: !sequenceModel.checkIntegrity().length = ", !sequenceModel.checkIntegrity().length);
            hal.setStartLight(visible && !remoteaccess.interfaceIsConnected && hal.safetyLoop && !sequenceModel.checkIntegrity().length);
            hal.setStopLight(sequenceModel.isPlaying);
        }
    }

    Connections {
        target: sequenceModel
        onIsPlayingChanged: {
            //console.log("page_sequence:editlist.qml: onIsPlayingChanged: ", sequenceModel.isPlaying);
            hal.setStartLight(visible && !sequenceModel.isPlaying && !remoteaccess.interfaceIsConnected && hal.safetyLoop && !sequenceModel.checkIntegrity().length && msg === null);
//            hal.setStopLight(false);
            hal.setStopLight(sequenceModel.isPlaying);

            if(sequenceModel.isPlaying) remoteaccess.disableRemoteAccess();
            else remoteaccess.enableRemoteAccess();
        }
    }

    function disableButtons(){
//        //console.log("page_sequence: disablebuttons");
        hal.setStartLight(false);
        hal.setStopLight(false);
    }

}
