import QtQuick 2.0
import "../../HorusComponents"
import "../../page_gndbond_live"

Item {
    id: main
    width: if (parent) parent.width
    implicitHeight: 285
    property bool displayBg: true

    /*******
    * View *
    *******/

    ListView {
        id: lv

        clip: true

        orientation: ListView.Vertical

        property int edited: -1
        anchors {
            top: parent.top
            bottom: parent.bottom
            left: parent.left
            leftMargin: 10
            right: parent.right
            rightMargin: 10
            topMargin: 5

        }

        model: step.pointsList

        delegate:
            MouseArea {
                id: dragArea
                height: content.height + 4
                anchors {
                    left: parent.left
                    right: parent.right
                }

                Item{
                    id : content

                    anchors {
                        horizontalCenter: parent.horizontalCenter
                        verticalCenter: parent.verticalCenter
                    }

                    width: dragArea.width;
                    height: inner.height

                    Item {
                        id: inner

                        height: graphBox.height
                        width: parent.width

                        /*********
                        * Number *
                        *********/
                        Text {
                            id: indexBox
                            anchors.left: parent.left
                            anchors.leftMargin: -15
                            anchors.verticalCenter: parent.verticalCenter
                            width: 80
                            height: 65

                            color: "#b0b0b9"
                            text: (index + 1) + "/" + step.pointsList.count
                            font.bold: true
                            verticalAlignment: Text.AlignVCenter
                            horizontalAlignment: Text.AlignHCenter
                            font.pixelSize: 24
                            fontSizeMode: Text.Fit
                            wrapMode: Text.Wrap
                        }


                        /********
                        * Graph *
                        *********/
                        Item {
                            id: graphBox
                            anchors {
                                left: indexBox.right
                                leftMargin: -40
                                verticalCenter: indexBox.verticalCenter
                            }
                            width: parent.width
                            implicitHeight: 323



                            ReportZone {
                                anchors {
                                        verticalCenter: parent.verticalCenter
                                        horizontalCenter: parent.horizontalCenter
                                }
                                scale: 0.85
                                displayBg: main.displayBg
                                gndbondProcess: model ? model.process : undefined
                                isUnderVoltage: true
                                Component.onCompleted: {
//                                    //console.log("gndbondMultiPoints_live.qml : step.playPoint = ", step.playPoint);
                                    gndbondProcess.halObj = hal;
                                    gndbondProcess.configObj = config;
                                    gndbondProcess.canbusGndBond = canbus.gndbond;
                                    paramupdater.gndbond.setEnable(true, step.programName);
                                }
                            }
                        }
                 }
             }
        }
        Connections {
            target : step
            onRemainingPointsChanged : {
                if (step.remainingPoints >= 0) {
                    autoscrollTimer.startDown();
                }
                 else {
                autoscrollTimer.stop();
                }
            }
        }
    }

    Timer {
        id: autoscrollTimer
        property bool _up: false
        property int _absy: lv.mapToItem(main, 0, 0, 0, 0).y;
        function startUp() {
            _up = true;
            start();
        }
        function startDown() {
            _up = false;
            start();
        }
        interval: 20
        repeat: true
        onTriggered: {
            var speed = 30;
            if (_up) {
                if (lv.contentY > speed) {
                    lv.contentY -= speed;
                } else {
                    stop();
                }
            } else {
                if (lv.contentY < ((lv.contentHeight/step.points) * (step.playPoint))+20) {
                    lv.contentY += speed;
                    lv.returnToBounds();

                } else {
                    stop();
                }
            }
        }
    }

    VScrollBar {
        id:scroll
        anchors {
            top: parent.top
            bottom: parent.bottom
            right: parent.left
            topMargin: 10
            rightMargin: 5
        }
        scrollArea: lv
    }

}


