import QtQuick 2.2
import Horus 1.0
import "../HorusComponents"

Page {
    title: config.autoTr + qsTr("Interface")
    saveImgVisible: false

    ButtonHelp {
        id: helpbutton
        anchors {
            top: parent.top
            right: parent.right
            rightMargin: -10
        }
    }

    ListSettings {
        id : ls
        property string ipregex: "^(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\\.(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\\.(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\\.(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)$"
        function validateIpAddress(ipaddress)
        {
            return (new RegExp(ipregex).test(ipaddress));
        }

        anchors {
            top: parent.top
            left: parent.left
            bottom: parent.bottom
            right: helpbutton.left
            rightMargin: 10
        }

        /************
        * Interface *
        ************/
        ListSettingsElement {
            label: config.autoTr + qsTr("Interface :")
            List {
                id: idListInterface
                width: 250
                maxElementToDisplay: 4
                currentElement : config.currentInterface.value
                model: config.currentInterface.enumNames
                onCurrentElementChanged: config.currentInterface.value = currentElement
            }
        }

        /*******
        * GPIB *
        *******/
        ListSettingsGroup {
            visible: (idListInterface.currentElement === ParamGlobal.RS232_GPIB && config.isGpibOptionActive())
            ListSettingsElement {
                showGroup: false
                label: config.autoTr + qsTr("Address :")
                button {
                    text: config.gpibAddress.value
                    onClicked: popup().editParam(config.gpibAddress)
                }
            }
        }

        /********
        * RS232 *
        ********/
        ListSettingsGroup {
            visible: (idListInterface.currentElement === ParamGlobal.RS232_GPIB && !config.isGpibOptionActive())
            ListSettingsElement {
                showGroup: false
                label: config.autoTr + qsTr("Baudrate :")
                List {
                    width: 250
                    maxElementToDisplay: 4
                    currentElement : config.rs232Baudrate.value
                    model: config.rs232Baudrate.enumNames
                    onCurrentElementChanged: config.rs232Baudrate.value = currentElement
                }
            }
        }

        /******
        * PLC *
        ******/


//        ListSettingsGroup {
//            visible: (idListInterface.currentElement === ParamGlobal.PLC)
//            ListSettingsElement {
//                showGroup: false
//                label: config.autoTr + qsTr("Mode :")
//                List {
//                    width: 250
//                    maxElementToDisplay: 4
//                    currentElement : config.plcMode.value
//                    model: config.plcMode.enumNames
//                    onCurrentElementChanged: config.plcMode.value = currentElement
//                }
//            }
//        }

        /***********
        * Ethernet *
        ***********/
        ListSettingsGroup {
            visible: (idListInterface.currentElement == ParamGlobal.ETHERNET)
            ListSettingsElement {
                showGroup: false
                label: config.autoTr + qsTr("IP address :")
                button {
                    text: config.ethDhcp ? hal.ethIp : config.ethIp
                    enabled:  !config.ethDhcp
                    onClicked: {
                        popup().editText(qsTr("New Ip"), config.ethIp, function(ip) {
                            if (ip === undefined)
                                return true;
                            if (ls.validateIpAddress(ip)){
                                config.ethIp = ip;
                                hal.setEthNetwork(config.ethDhcp,config.ethIp,config.ethNetmask);
                                return true;
                            }
                            return false;
                        }, false, ls.ipregex);
                    }
                }
            }
            ListSettingsElement {
                showGroup: false
                label: config.autoTr + qsTr("Network mask :")
                button {
                    text: config.ethDhcp ? hal.ethNetmask : config.ethNetmask
                    enabled:  !config.ethDhcp
                    onClicked: {
                        popup().editText(qsTr("New Netmask"), config.ethNetmask, function(netmask) {
                            if (netmask === undefined)
                                return true;
                            if (ls.validateIpAddress(netmask)){
                                config.ethNetmask = netmask;
                                hal.setEthNetwork(config.ethDhcp,config.ethIp,config.ethNetmask);
                                return true;
                            }
                            return false;
                        }, false, ls.ipregex);
                    }
                }
            }

            ListSettingsElement {
                showGroup: false
                label: config.autoTr + qsTr("White list :")
                button{
                    text: qsTr("Erase")
                    enabled: config.acl.value <= ParamGlobal.ADMINISTRATOR
                    onClicked: {
                        popup().msg(qsTr("Erase white list"), qsTr("Do you really want to erase all the Ip addresses registered on the white list?"),  [qsTr("Yes"), qsTr("No")], function(nr) {
                            if (nr === 0){

                                if (config.adminPwdEmpty()) {
                                    remoteaccess.clearAddList();
                                    popup().msg(qsTr("WhiteList cleared"), qsTr("The white list has been cleared"), [qsTr("Ok")], function(nr) {
                                        if (nr === 0) {
                                            return true;
                                        }
                                        }, true);
                                    return true;
                                }

                                popup().editText(qsTr("Please enter admin password"), "", function(pass) {
                                if (pass === undefined) {
                                    return true;
                                }

                                if (config.checkPassword(1, pass)) {
                                    remoteaccess.clearAddList();
                                    popup().msg(qsTr("WhiteList cleared"), qsTr("The white list has been cleared"), [qsTr("Ok")], function(nr) {
                                        if (nr === 0) {
                                            return true;
                                        }
                                        }, true);
                                    return true;
                                }

                                else {
                                    popup().msg(qsTr("Wrong password"), qsTr("The password is invalid"), [qsTr("Ok")], function(nr) {
                                        if (nr === 0) {
                                            return true;
                                        }
                                        });
                                    }

                                    return false ;
                                 }, true);

                                return true;
                            }
                            else {
                                return true;
                            }
                                }
                        ,popupmgr.get(1) ? true : false);
                    }
                }
            }
        }

        /***********
        * USB NET *
        ***********/
        ListSettingsGroup {
            visible: (idListInterface.currentElement == ParamGlobal.USB)
            ListSettingsElement {
                showGroup: false
                label: config.autoTr + qsTr("IP address :")
                button {
                    text: config.usbIp
                    onClicked: {
                        popup().editText(qsTr("New Ip"), config.usbIp, function(ip) {
                            if (ip === undefined)
                                return true;
                            if (ls.validateIpAddress(ip)){
                                config.usbIp = ip;
                                hal.setUsbNetwork(config.usbIp,config.usbNetmask);
                                return true;
                            }
                            return false;
                        }, false, ls.ipregex);
                    }
                }
            }
            ListSettingsElement {
                showGroup: false
                label: config.autoTr + qsTr("Network mask :")
                button {
                    text: config.usbNetmask
                    onClicked: {
                        popup().editText(qsTr("New Netmask"), config.usbNetmask, function(netmask) {
                            if (netmask === undefined)
                                return true;
                            if (ls.validateIpAddress(netmask)){
                                config.usbNetmask = netmask;
                                hal.setUsbNetwork(config.usbIp,config.usbNetmask);
                                return true;
                            }
                            return false;
                        }, false, ls.ipregex);
                    }
                }
            }

            ListSettingsElement {
                showGroup: false
                label: config.autoTr + qsTr("White list :")
                button{
                    text: qsTr("Erase")
                    onClicked: {
                        popup().msg(qsTr("Erase white list"), qsTr("Do you really want to erase all the Ip addresses registered on the white list?"),  [qsTr("Yes"), qsTr("No")], function(nr) {
                            if (nr === 0){
                                console.log("remoteaccess.clearwhiteList(true); ");
                                remoteaccess.clearAddList();
                                return true;
                            }
                            else {
                                return true;
                            }
                                }
                        ,popupmgr.get(1) ? true : false);
                    }
                }
            }
        }

        /*******
        * WIFI *
        *******/
//        ListSettingsElement {
//            visible: (idListInterface.currentElement == ParamGlobal.WIFI) && (!hal.wifiIsEnable)
//            label: config.autoTr + qsTr("Device not ready :")
//            button {
//                text: qsTr("Retry");
//                enabled: !hal.wifiIsEnable
//                onClicked: {
//                    hal.startWlan(config.wifiName,config.wifiPass,config.wifiIp,config.wifiNetmask);
//                }
//            }
//        }
//        ListSettingsGroup {
//            visible: (idListInterface.currentElement == ParamGlobal.WIFI) && (hal.wifiIsEnable)
//            ListSettingsElement {
//                showGroup: false
//                label: config.autoTr + qsTr("Nom :")
//                button {
//                    text: config.wifiName
//                    enabled: hal.wifiIsEnable
//                    onClicked: {
//                        popup().editText(qsTr("Name"), config.wifiName, function(name) {
//                            if (name === undefined)
//                                return true;

//                            config.wifiName = name;
//                            hal.startWlan(config.wifiName,config.wifiPass,config.wifiIp,config.wifiNetmask);
//                            return true;
//                        });
//                    }
//                }
//            }
//            ListSettingsElement {
//                showGroup: false
//                label: config.autoTr + qsTr("Clef WPA2 :")
//                button {
//                    text: config.wifiPass
//                    onClicked: {
//                        popup().editText(qsTr("pass"), config.wifiPass, function(pass) {
//                            if (pass === undefined)
//                                return true;

//                            config.wifiPass = pass;
//                            hal.startWlan(config.wifiName,config.wifiPass,config.wifiIp,config.wifiNetmask);
//                            return true;
//                        });
//                    }
//                }
//            }
//            ListSettingsElement {
//                showGroup: false
//                label: config.autoTr + qsTr("IP address :")
//                button {
//                    text: config.wifiIp
//                    enabled: hal.wifiIsEnable
//                    onClicked: {
//                        popup().editText(qsTr("New Ip"), config.wifiIp, function(ip) {
//                            if (ip === undefined)
//                                return true;
//                            if (ls.validateIpAddress(ip)){
//                                config.wifiIp = ip;
//                                hal.startWlan(config.wifiName,config.wifiPass,config.wifiIp,config.wifiNetmask);
//                                return true;
//                            }
//                            return false;
//                        }, false, ls.ipregex);
//                    }
//                }
//            }
//            ListSettingsElement {
//                showGroup: false
//                label: config.autoTr + qsTr("Network mask :")
//                button {
//                    text: config.wifiNetmask
//                    enabled: hal.wifiIsEnable
//                    onClicked: {
//                        popup().editText(qsTr("New Netmask"), config.wifiNetmask, function(netmask) {
//                            if (netmask === undefined)
//                                return true;
//                            if (ls.validateIpAddress(netmask)){
//                                config.wifiNetmask = netmask;
//                                hal.startWlan(config.wifiName,config.wifiPass,config.wifiIp,config.wifiNetmask);
//                                return true;
//                            }
//                            return false;
//                        }, false, ls.ipregex);
//                    }
//                }
//            }
//        }
//        ListSettingsElement {
//            visible: [ParamGlobal.ETHERNET, ParamGlobal.USB, ParamGlobal.WIFI].indexOf(idListInterface.currentElement) >= 0
//            label: config.autoTr + qsTr("VNC :")
//            Inter {
//                width: 250
//                height: 50
//                interOn : config.wifiVnc
//                onInterOnChanged: {
//                    config.wifiVnc = interOn;
//                    hal.setVnc(config.wifiVnc);
//                }
//            }
//        }

//        ListSettingsElement {
//            showGroup: false
//            label: config.autoTr + qsTr("White list :")
//            button{
//                text: qsTr("Erase")
//                onClicked: {
//                    popup().msg(qsTr("Erase white list"), qsTr("Do you really want to erase all the Ip addresses registered on the white list?"),  [qsTr("Yes"), qsTr("No")], function(nr) {
//                        if (nr === 0){
//                            console.log("remoteaccess.clearwhiteList(true); ");
//                            remoteaccess.clearAddList();
//                            return true;
//                        }
//                        else {
//                            return true;
//                        }
//                            }
//                    ,popupmgr.get(1) ? true : false);
//                }
//            }
//        }
    }
}
