import QtQuick 2.2
import Horus 1.0
import "../HorusComponents"

Page {
    title: config.autoTr + qsTr("General settings")
    saveImgVisible: false

    ButtonHelp {
        id: helpbutton
        anchors {
            top: parent.top
            right: parent.right
            rightMargin: -10
        }
    }

    ListSettings {
        anchors {
            top: parent.top
            left: parent.left
            bottom: parent.bottom
            right: helpbutton.left
            rightMargin: 10
        }

        /***********
        * Language *
        ***********/
        ListSettingsElement {
            label: config.autoTr + qsTr("Language")
            button {
                text: config.language ? config.languages[config.languageToIndex(config.language)] : " "
                onClicked: {
                    popup().choose(
                                qsTr("Language"),
                                config.languages,
                                config.languageToIndex(config.language),
                                function(nr) {
                                    if (nr !== undefined) {
                                        config.language = config.languagesCodes[nr];
                                    }
                                    return true;
                                });
                }
            }
        }

        /**********
        * Display *
        **********/
        ListSettingsElement {
            label: config.autoTr + qsTr("Display :")
            button {
                text: config.autoTr + qsTr("Settings")
                dstLink: "settings_display"
            }
        }

        /********
        * Sound *
        ********/
        ListSettingsElement {
            label: config.autoTr + qsTr("Sound :")
            button {
                text: config.autoTr + qsTr("Settings")
                dstLink: "settings_sound"
            }
        }

        /************
        * Time/date *
        ************/
        ListSettingsElement {
            label: config.autoTr + qsTr("Time - Date :")
            button {
                text: config.autoTr + qsTr("Settings")
                dstLink: "settings_timedate"
                data: [Timer {
                    interval: 1000;
                    running: true;
                    repeat: true
                    triggeredOnStart: true

                    onTriggered: {
                        parent.text = Qt.formatTime(new Date(), "hh:mm") + " - " + Qt.formatDate(new Date(), config.dateFormat);
                    }
                }]
            }
        }

        /*********
        * Access *
        *********/
        ListSettingsElement {
            label: config.autoTr + qsTr("Access :")
            button {
                text: config.acl.text
                dstLink: "settings_password"
            }
        }

        /************
        * Interface *
        ************/
        ListSettingsElement {
            label: config.autoTr + qsTr("Interface :")
            button {
                text: config.currentInterface.text
                dstLink: "settings_interface"
            }
        }

        /****************
        * Screen Mirror *
        ****************/
//        ListSettingsElement {
//            label: config.autoTr + qsTr("Screen Mirror :")
//            button {
//                text: config.vncInterface.text
//                dstLink: "settings_vnc"
//            }
//        }

        /*********
        * System *
        *********/
        ListSettingsElement {
            label: config.autoTr + qsTr("System :")
            button {
                text: config.autoTr + qsTr("About")
                dstLink: "settings_system"
            }
        }

        /**********
        * Restore *
        **********/
        ListSettingsElement {
            label: config.autoTr + qsTr("Restore :")
            button {
                text: config.autoTr + qsTr("Default")
                enabled: config.acl.value <= ParamGlobal.ADMINISTRATOR
                onClicked: {
                    popup().msg(
                                qsTr("Restore"),
                                qsTr("Do you really want to restore defaults parameters ?"),
                                [qsTr("Restore"), qsTr("Cancel")],
                                function (nr) {
                                    if (nr == 0) {
                                        config.resetToDefaults();

                                        //TODO: Tester cet ajout et vérifier que cela règle le bug
                                        remoteaccess.testGpibOption();
                                    }
                                    return true; // Close popup
                                });
                }
            }
        }

//        /*********************
//        * External Generator *
//        **********************/

//        ListSettingsElement {
//            label: config.autoTr + qsTr("Power Supply :")
//            button {
//                text: config.powerSupply.text
//                enabled: config.acl.value <= ParamGlobal.ADMINISTRATOR
//                dstLink: "settings_generator"
//            }
//        }

        /*****************
        * Wipe user data *
        *****************/
        ListSettingsElement {
            label: config.autoTr + qsTr("User data:")
            visible: config.acl.value === ParamGlobal.SERVICE
            button {
                text: config.autoTr + qsTr("Wipe")
                onClicked: {
                    popup().msg(
                                qsTr("Wipe user data"),
                                qsTr("You will delete all data generated by users and reboot the system. Do you really want to wipe user data ?"),
                                [qsTr("Wipe"), qsTr("Cancel")],
                                function (nr) {
                                    if (nr == 0) {
                                        hal.wipeUserData();
                                    }
                                    return true; // Close popup
                                });
                }
            }
        }
    }
}
