import QtQuick 2.0
import Horus 1.0
import "../HorusComponents"

Page {
    title: config.autoTr + qsTr("Password")
    saveImgVisible: false

    ButtonHelp {
        id: helpbutton
        anchors {
            top: parent.top
            right: parent.right
            rightMargin: -10
        }
    }

    ListSettings {
        id: ls
        property bool canChangePasswords: config.acl.value <= ParamGlobal.ADMINISTRATOR

        anchors {
            top: parent.top
            left: parent.left
            bottom: parent.bottom
            right: helpbutton.left
            rightMargin: 10
        }

        /*******
        * User *
        *******/
        ListSettingsElement {
            label: config.autoTr + qsTr("User :")
            List {
                width: 250
                model: config.acl.enumNames
                maxElementToDisplay: 4
                currentElement: config.acl.value

                onCurrentElementChanged: {
                    if (currentElement > config.acl.value) {
                        config.acl.value = currentElement;
                    } else if (currentElement < config.acl.value) {
                        popup().editText(qsTr("Password required"), "", function(pass) {
                            if (pass !== undefined && config.checkPassword(currentElement, pass)) {
                                config.acl.value = currentElement;
                            } else {
                                popup().msg(qsTr("Wrong password"), qsTr("The password is invalid"), [qsTr("Ok")], function(nr) {
                                    if (nr === 0) {
                                        return true;
                                    }
                                }, true);
                                currentElement = config.acl.value;
                                return true;
                            }
                            return true;
                        });
                    }
                }
            }
        }

        /************************
        * Change admin password *
        ************************/
        ListSettingsElement {
            label: config.autoTr + qsTr("Administrator :")
            button {
                text: config.autoTr + qsTr("Change password")
                enabled: ls.canChangePasswords
                onClicked: {

                    popup().msg(qsTr("Current password"), qsTr("Please enter the current administrator password"), [qsTr("Ok")], function(nr) {
                        if (nr === 0) {
                            popup().editText(qsTr("Current password"), "", function(pass) {
                            if (pass === undefined) {
                                return true;
                            }

                            if (config.checkPassword(1, pass)) {
                                popup().msg(qsTr("New password"), qsTr("Please enter the new password"), [qsTr("Ok")], function(nr) {
                                    popup().editText(qsTr("New password"), "", function(pass) {
                                        if (pass === undefined) return true;
                                        config.setPassword(ParamGlobal.ADMINISTRATOR, pass);
                                        popup().msg(qsTr("Password successfully changed"), qsTr("The password has been successfully changed"), [qsTr("Ok")], function(nr) {
                                            return true;
                                            }, true);
                                        return true;
                                    },true);
                                    },true);
                                return true;
                            }

                            else {
                                popup().msg(qsTr("Wrong password"), qsTr("The password is invalid"), [qsTr("Ok")], function(nr) {
                                    if (nr === 0) {
                                        return true;
                                    }
                                    });
                                }

                                return true;
                             }, true);
                            return true;
                        }
                        else {
                            return true;
                        }
                        });
                }
            }
        }

        /***********************
        * Change tech password *
        ***********************/
        ListSettingsElement {
            label: config.autoTr + qsTr("Technician :")
            button {
                text: config.autoTr + qsTr("Change password")
                enabled: ls.canChangePasswords

                onClicked: {
                    popup().editText(qsTr("New password"), "", function(pass) {
                        if (pass === undefined) return true;
                        config.setPassword(ParamGlobal.TECHNICIAN, pass);
                        return true;
                    });
                }
            }
        }
    }
}
