import QtQuick 2.0
import QtMultimedia 5.0
import "../HorusComponents"

Page {
    title: config.autoTr + qsTr("Sound settings")
    saveImgVisible: false

    /** Change a URL to a more beautiful name to display
      * @param name Raw url
      * @return more readable name
      */
    function beautiful_sound_name(name) {
        name = (name.slice(name.lastIndexOf("/")+1)).replace(/\.wav$/i, "");
        if (name == "") name = qsTr("No sound");
        if (name == "Button_click") name = qsTr("Simple click");
        return name
    }

    /** Display popup of sound list
      * @param value    Initial value (default selected)
      * @param callback Function to call when a choice is done (its first parameter is choice)
      */
    function choose_sound(value, callback) {
        var sounds = config.listSounds();
        var sndlistnames = []
        var nr = 0;
        for (var i in sounds) {
            if (sounds[i] == value) nr = i;
            sndlistnames.push(beautiful_sound_name(sounds[i]));
        }
        popup().choose(qsTr("Select sound"), sndlistnames, nr, function(nr) {
            if (nr != undefined) {
                sfx.stop();
                sfx.source = sounds[nr];
                sfx.play();
                callback(sounds[nr]);
            }
            return true;
        });
    }

    SoundEffect {
        id: sfx
        volume: config.volume.value
    }

    ButtonHelp {
        id: helpbutton
        anchors {
            top: parent.top
            right: parent.right
            rightMargin: -10
        }
    }

    ListSettings {
        anchors {
            top: parent.top
            left: parent.left
            bottom: parent.bottom
            right: helpbutton.left
            rightMargin: 10
        }

        /************
        * Pass test *
        ************/
        ListSettingsElement {
            label: config.autoTr + qsTr("Pass test :")
            button {
                text: beautiful_sound_name(config.soundPass)
                onClicked: choose_sound(config.soundPass, function(file) { config.soundPass = file; });
            }
        }

        /************
        * Fail test *
        ************/
        ListSettingsElement {
            label: config.autoTr + qsTr("Fail test :")
            button {
                text: beautiful_sound_name(config.soundFail)
                onClicked: choose_sound(config.soundFail, function(file) { config.soundFail = file; });
            }
        }

        /*************
        * Error test *
        *************/
        ListSettingsElement {
            label: config.autoTr + qsTr("Error :")
            button {
                text: beautiful_sound_name(config.soundError)
                onClicked: choose_sound(config.soundError, function(file) { config.soundError = file; });
            }
        }

        /***********
        * Keyboard *
        ***********/
        ListSettingsElement {
            label: config.autoTr + qsTr("Keyboard :")
            button {
                text: beautiful_sound_name(config.soundKeyboard)
                onClicked: choose_sound(config.soundKeyboard, function(file) { config.soundKeyboard = file; });
            }
        }

        /*********
        * Volume *
        *********/
        ListSettingsElement {
            label: config.autoTr + qsTr("Master Vol :")
            button {
                text: ""
                enabled: false
                visible: true
                data: [
                    Canvas {
                        anchors.fill: parent
                        property real value: config.volume.value
                        onValueChanged: requestPaint()
                        onPaint: {
                            var ctx = getContext("2d");
                            var nbsteps = 15;
                            var separator = 5;
                            var margins = 10;

                            var _strike = (width - 2 * margins) / nbsteps
                            var _hup = (height - 2 * margins) / (width - 2 * margins)
                            var _w = _strike - separator
                            if (_strike <= 0 || _w <= 0) return;

                            ctx.reset();
                            ctx.lineWidth = 1;
                            ctx.strokeStyle = "#9d9d9d"

                            for (var i = 0; i < nbsteps; ++i) {
                                ctx.save();
                                ctx.beginPath();
                                var _x = margins + _strike * i;
                                ctx.moveTo(_x, height-margins);
                                ctx.lineTo(_x+_w, height-margins);
                                ctx.lineTo(_x+_w, height-margins-_hup*(_x+_w));
                                ctx.lineTo(_x, height-margins-_hup*_x);
                                ctx.closePath();
                                if (value > _x/width) {
                                    ctx.fillStyle = Qt.hsla((1-_x/width)*60/180, 1, 0.5, 1)
                                    ctx.fill();
                                } else {
                                    ctx.stroke();
                                }
                                ctx.restore();
                            }
                        }
                    },
                    SliderImage {
                        anchors.fill: parent
                        opacity: 0
                        onValueChanged: config.volume.value = value
                    }
                ]
            }
        }
    }
}
