import QtQuick 2.0
import Horus 1.0
import "../HorusComponents"

Page {
    title: config.autoTr + qsTr("System settings")
    saveImgVisible: false

    ButtonHelp {
        id: helpbutton
        anchors {
            top: parent.top
            right: parent.right
            rightMargin: -10
        }
    }

    ListSettings {
        anchors {
            top: parent.top
            left: parent.left
            bottom: parent.bottom
            right: helpbutton.left
            rightMargin: 10
        }

        /********
        * Model *
        ********/
        ListSettingsElement {
            label: config.autoTr + qsTr("Model :")
            button.text: config.model.model
            button.enabled: false
        }

        /****************
        * Serial number *
        ****************/
        ListSettingsElement {
            label: config.autoTr + qsTr("Serial number :")
            button.text: config.model.serialNumber
            button.enabled: false
        }

        /****************
        * Main firmware *
        ****************/
        ListSettingsElement {
            label: config.autoTr + qsTr("Main Firmware :")

            button {
                text: config.autoTr + qsTr("V") + ((config.acl.value === ParamGlobal.SERVICE ? hal.softVersion : hal.lightSoftVersion()))
                enabled: false
            }

            extraButton {
                text: config.autoTr + qsTr("Update")
                onClicked: {
                    popup().msg(
                                qsTr("Firmware update"),
                                qsTr("Insert a USB stick with the new software version.<br>Do not turn off the power during the update operation."),
                                [qsTr("Update"), qsTr("Cancel")],
                                function (nr) {
                                    if (nr == 0) {
                                        appupdt.startUpdate();
                                        return false; // Do not close popup system
                                    }
                                    return true; // Close popup
                                });
                }
                data: [
                    ApplicationUpdater {
                        id: appupdt
                        onStatusChanged: {
                            var msg = [
                                        qsTr("Firmware update will start soon", "STOPPED"),
                                        qsTr("Firmware update in progress...", "WORKING"),
                                        qsTr("Firmware update failed:<br>USB not found<br><br>Please ensure USB key is connected and its content is valid, than retry.", "FAIL_USB"),
                                        qsTr("Firmware update failed:<br>Archive not found<br><br>Please check archive name and verify its location in USB key, than retry.", "FAIL_ARCHIVE"),
                                        qsTr("Firmware update failed:<br>Invalid archive<br><br>The archive is corrupted or invalid, please download it again, than retry.", "FAIL_SCRIPT"),
                                        qsTr("First phase of update is successfull ! The system will automatically reboot in a few seconds.", "SUCCESS"),
                                        qsTr("Firmware update failed:<br>Unknown error", "FAIL_UNKNOWN"),
                                        qsTr("Firmware update failed:<br>Invalid pre-update script", "FAIL_PRESCRIPT"),
                                    ][status];
                            popup().msg(
                                        qsTr("Firmware update"),
                                        msg, [],
                                        function() {
                                            return [ApplicationUpdater.STOPPED,
                                                    ApplicationUpdater.FAIL_USB,
                                                    ApplicationUpdater.FAIL_ARCHIVE,
                                                    ApplicationUpdater.FAIL_SCRIPT,
                                                    ApplicationUpdater.FAIL_UNKNOWN,
                                                    ApplicationUpdater.FAIL_PRESCRIPT].indexOf(status) >= 0;
                                        }, /*replace*/ true);
                        }
                    }
                ]
            }
        }

        /***********
        * Firmwares *
        ***********/
        ListSettingsElement {
            label: config.autoTr + qsTr("Firmwares :")

            button {
                text: config.autoTr + config.functionsVersions;
                height: 50 * config.getNbCards();
                enabled: false
            }

            extraButton {
                text: config.autoTr + qsTr("Update")
                onClicked: {
//                    fctupdt.setCanBitrate100k(); //On change le bitrate et on redémarre la carte fonction

                    popup().msg(
                                qsTr("Firmware update"),
                                qsTr("Insert a USB stick with the new software version.<br>Do not turn off the power during the update operation."),
                                [qsTr("Update"), qsTr("Cancel")],
                                function (nr) {
                                    if (nr == 0) {
                                        fctupdt.startUpdate();
                                        return false; // Do not close popup system
                                    }
                                    else /*fctupdt.setCanBitrate1M();*/ // On remet le bitrate à la valeur de fonctionnement et on démarre la carte fonction sur sa RAM
                                    return true; // Close popup
                                });
                }
                data: [
                    FunctionUpdater {
                        id: fctupdt
                        canbusMaj: canbus.maj
                        onStatusChanged: {
                            var msg = [
                                        qsTr("Firmware update will start soon", "STOPPED"),
                                        qsTr("Firmware update in progress...", "WORKING"),
                                        qsTr("Firmware update failed:<br>USB not found<br><br>Please ensure USB key is connected and its content is valid, than retry.", "FAIL_USB"),
                                        qsTr("Firmware update failed:<br>Archive not found<br><br>Please check archive name and verify its location in USB key, than retry.", "FAIL_ARCHIVE"),
                                        qsTr("Firmware update failed:<br>Invalid archive<br><br>The archive is corrupted or invalid, please download it again, than retry.", "FAIL_SCRIPT"),
                                        qsTr("Firmware updated successfully. Please restart the machine", "SUCCESS"),
                                        qsTr("Firmware update failed:<br>Unknown error", "FAIL_UNKNOWN"),
                                        qsTr("Firmware update failed:<br>Invalid pre-update script", "FAIL_PRESCRIPT"),
                                        qsTr("Firmware update failed:<br>Memory fail ", "FAIL_CODE"),
                                        qsTr("Firmware update failed:<br>The communication with the function card failed ", "FAIL_DIALOG1")
                                    ][status];
                            popup().progessMsg(
                                        qsTr("Firmware update"),
                                        msg, [], fctupdt.progress,
                                        function(nr) {
                                            return [FunctionUpdater.STOPPED,
                                                    FunctionUpdater.FAIL_USB,
                                                    FunctionUpdater.FAIL_ARCHIVE,
                                                    FunctionUpdater.FAIL_SCRIPT,
                                                    FunctionUpdater.FAIL_UNKNOWN,
                                                    FunctionUpdater.FAIL_PRESCRIPT,
                                                    FunctionUpdater.SUCCESS,
                                                    FunctionUpdater.FAIL_MAX,
                                                    FunctionUpdater.FAIL_DIALOG1,
                                                    FunctionUpdater.FAIL_DIALOG2,
                                                    FunctionUpdater.FAIL_CODE].indexOf(status) >= 0;
                                        }, /*replace*/ true);
                        }
                    }
                ]
            }
        }

        /**************
        * BSP version *
        **************/
        ListSettingsElement {
            label: config.autoTr + qsTr("BSP version :")
            button.text: hal.bspVersion
            button.enabled: false
        }

        /**********
        * Options *
        **********/
        ListSettingsElement {
            label: config.autoTr + qsTr("Options :")
            button {
                text: config.autoTr + qsTr("Settings")
                enabled: false
            }
        }

        /********
        * Legal *
        *********/
        ListSettingsElement {
            label: config.autoTr + qsTr("Legal :")
            button {
                text: config.autoTr + qsTr("Licenses")
                enabled:  false
                onClicked : {
                    popup().legalDoc(qsTr("Legal Infos"), qsTr("licenses.txt"), [qsTr("Ok")], function(nr) {
                        return true;
                    });
                }
            }
        }
    }
}
