import QtQuick 2.0
import QtQuick.Controls 1.2
import "../HorusComponents"

Page {
    id: idTimeDate

    title: config.autoTr + qsTr("Time & Date")

    saveImgVisible: false

    property var newdate: new Date()

    /*************
    * Background *
    *************/

    ListSettingsGroup {
        height: 170
    }
    ListSettingsGroup {
        y: 195
        height: 170
    }
    ListSettingsGroup {
        x: 503
        height: 170
    }

    /*******
    * Date *
    *******/
    property bool _alternateFormat: dateformat.currentElement == 1
    Item {
        x: 10
        y: 10
        width: 500 - 20
        height: 170 - 20

        Row {
            height: parent.height
            spacing: 10

            Text {
                anchors.verticalCenter: parent.verticalCenter
                width: Math.max(110, implicitWidth)
                text: config.autoTr + qsTr("Date")
                font.pixelSize: 26
                color: "#c5c5cc"
            }
            NumberChoice {
                min: 2016
                max: 2037
                value: newdate.getFullYear()
                visible: !_alternateFormat
                nbDigits: 4
                onClicked: {
                    var d = newdate;
                    d.setFullYear(min + index);
                    newdate = d;
                }
            }
            NumberChoice {
                min: 1
                max: (new Date(newdate.getFullYear(), newdate.getMonth()+1, 0)).getDate()
                value: newdate.getDate()
                visible: _alternateFormat
                nbDigits: 2
                onClicked: {
                    var d = newdate;
                    d.setDate(1+index);
                    newdate = d;
                }
            }
            Text {
                anchors.verticalCenter: parent.verticalCenter
                width: 15
                text: "/"
                font.pixelSize: 26
                horizontalAlignment: Text.AlignHCenter
                color: "#c5c5cc"
            }
            NumberChoice {
                min: 1
                max: 12
                value: newdate.getMonth()+1
                nbDigits: 2
                onClicked: {
                    var d = newdate;
                    d.setMonth(index);
                    if (d.getMonth() != index) {
                        d.setDate(new Date(newdate.getFullYear(), index+1, 0).getDate())
                        d.setMonth(index);
                    }
                    newdate = d;
                }
            }
            Text {
                anchors.verticalCenter: parent.verticalCenter
                width: 15
                text: "/"
                font.pixelSize: 26
                horizontalAlignment: Text.AlignHCenter
                color: "#c5c5cc"
            }
            NumberChoice {
                min: 2016
                max: 2037
                value: newdate.getFullYear()
                visible: _alternateFormat
                nbDigits: 4
                onClicked: {
                    var d = newdate;
                    d.setFullYear(min + index);
                    newdate = d;
                }
            }
            NumberChoice {
                min: 1
                max: (new Date(newdate.getFullYear(), newdate.getMonth()+1, 0)).getDate()
                value: newdate.getDate()
                visible: !_alternateFormat
                nbDigits: 2
                onClicked: {
                    var d = newdate;
                    d.setDate(1+index);
                    newdate = d;
                }
            }
        }
    }

    /********
    * Heure *
    ********/
    Item {
        x: 10
        y: 195 + 10
        width: 500 - 20
        height: 170 - 20

        Row {
            height: parent.height
            spacing: 10

            Text {
                anchors.verticalCenter: parent.verticalCenter
                width: Math.max(110, implicitWidth)
                text: config.autoTr + qsTr("Hour")
                font.pixelSize: 26
                color: "#c5c5cc"
            }
            NumberChoice {
                min: 0
                max: 23
                value: newdate.getHours()
                nbDigits: 2
                onClicked: {
                    var d = newdate;
                    d.setHours(index);
                    newdate = d;
                }
            }
            Text {
                anchors.verticalCenter: parent.verticalCenter
                width: 15
                text: ":"
                horizontalAlignment: Text.AlignHCenter
                font.pixelSize: 26
                color: "#c5c5cc"
            }
            NumberChoice {
                min: 0
                max: 59
                value: newdate.getMinutes()
                nbDigits: 2
                onClicked: {
                    var d = newdate;
                    d.setMinutes(index);
                    newdate = d;
                }
            }
            Text {
                anchors.verticalCenter: parent.verticalCenter
                width: 15
                text: ":"
                horizontalAlignment: Text.AlignHCenter
                font.pixelSize: 26
                color: "#c5c5cc"
            }
            NumberChoice {
                min: 0
                max: 59
                value: newdate.getSeconds()
                nbDigits: 2
                onClicked: {
                    var d = newdate;
                    d.setSeconds(index);
                    newdate = d;
                }
            }
        }
    }

    /**************
    * Date format *
    **************/
    Column {
        x: 513
        y: 20
        width: 800 - 503 - 20
        height: 170
        Text {
            anchors.horizontalCenter: parent.horizontalCenter
            text: config.autoTr + qsTr("Format")
            font.pixelSize: 26
            color: "#c5c5cc"
        }
        List {
            id: dateformat
            anchors.horizontalCenter: parent.horizontalCenter
            width: parent.width - 20
            maxElementToDisplay: 2
            model: ListModel {
                ListElement { format: "YYYY/MM/DD" }
                ListElement { format: "DD/MM/YYYY" }
            }
            Component.onCompleted: {
                var nr = 0;
                for (var i = 0; i < model.count; ++i)
                    if (model.get(i).format == config.dateFormat.toUpperCase())
                        nr = i;
                currentElement = nr;
            }
        }
    }

    /****************
    * Right buttons *
    ****************/
    Column {
        anchors {
            bottom: parent.bottom
            bottomMargin: 20
            right: parent.right
            rightMargin: -10
        }
        spacing: 10
        ButtonHelp {
        }
        RightButton {
            picto: Qt.resolvedUrl("ok.png")
            onClicked: {
                hal.setTime(Math.floor(newdate.getTime()/1000));
                config.dateFormat = dateformat.model.get(dateformat.currentElement).format.replace(/Y|D/g, function(x) { return x.toLowerCase(); });
                back_page();
            }
        }
    }

    /***********
    * Calendar *
    ***********/
    Image {
        x: 30
        y: 110
        source: "calendar.png"
        MouseArea {
            anchors.fill: parent
            onClicked: calendar.opened = true
        }
    }
    MouseArea {
        id: calendar
        property bool opened: false
        anchors {
            top: parent.top
            bottom: parent.bottom
            right: parent.right
            rightMargin: -10
            left: parent.left
            leftMargin: -10
        }
        visible: opened
        onClicked: {
            // Do nothing
        }
        Loader {
            id: calendarLoader
            anchors.fill: parent

            asynchronous: true
            opacity: 0

            sourceComponent: Calendar {
                minimumDate: { "2016-01-01" }

                onSelectedDateChanged: {
                    var d = selectedDate;
                    d.setHours(newdate.getHours());
                    d.setMinutes(newdate.getMinutes());
                    d.setSeconds(newdate.getSeconds());
                    newdate = d;
                    calendar.opened = false;
                }

                Component.onCompleted: selectedDate = newdate
            }

            Behavior on opacity { NumberAnimation {} }

            states: [
                State {
                    when: calendarLoader.status == Loader.Ready && calendar.opened
                    PropertyChanges {
                        target: calendarLoader
                        opacity: 1
                    }
                }
            ]
        }
    }
}
